/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_nE7AjNBF);
  numBytes += sLine_init(&sLine_4UNF87Lg);
  numBytes += sLine_init(&sLine_pSiBzevn);
  numBytes += sLine_init(&sLine_6yswAXw4);
  numBytes += sLine_init(&sLine_kI36Lwhv);
  numBytes += sBiquad_init(&sBiquad_s_scOuQ7o3);
  numBytes += sLine_init(&sLine_mh28VfHe);
  numBytes += sLine_init(&sLine_6NjXB5JD);
  numBytes += sLine_init(&sLine_lGs2WsUy);
  numBytes += sLine_init(&sLine_OQTrxbYY);
  numBytes += sLine_init(&sLine_YQRLwJkl);
  numBytes += sBiquad_init(&sBiquad_s_EoWt5IRO);
  numBytes += sLine_init(&sLine_XPWVQZIl);
  numBytes += sLine_init(&sLine_lQnuE2xa);
  numBytes += sLine_init(&sLine_3cvV9DNX);
  numBytes += sLine_init(&sLine_Pj9ki11t);
  numBytes += sLine_init(&sLine_7FDlxWkq);
  numBytes += sLine_init(&sLine_rRjOaLSH);
  numBytes += sBiquad_init(&sBiquad_s_kfCumOV3);
  numBytes += sLine_init(&sLine_a8OO1WPc);
  numBytes += sLine_init(&sLine_FkAbMukd);
  numBytes += sLine_init(&sLine_ojzk8GYp);
  numBytes += sLine_init(&sLine_YlDfzkCJ);
  numBytes += sLine_init(&sLine_Sz4mQDbV);
  numBytes += sLine_init(&sLine_WYAkRqn3);
  numBytes += sBiquad_init(&sBiquad_s_4mV6cvbN);
  numBytes += sLine_init(&sLine_sXuBoD6c);
  numBytes += sLine_init(&sLine_7kYo4OEA);
  numBytes += sLine_init(&sLine_qvv0LIfe);
  numBytes += sLine_init(&sLine_pdBTayuu);
  numBytes += sLine_init(&sLine_j03RQ7Gd);
  numBytes += sBiquad_init(&sBiquad_s_zl0FEbSB);
  numBytes += sLine_init(&sLine_4WAnl3Hx);
  numBytes += sLine_init(&sLine_0VrYZ8xX);
  numBytes += sLine_init(&sLine_0UCuwmzK);
  numBytes += sLine_init(&sLine_o0diF5nh);
  numBytes += sLine_init(&sLine_cExuYMbZ);
  numBytes += sLine_init(&sLine_SEB7NTLU);
  numBytes += sBiquad_init(&sBiquad_s_MvMTKuxn);
  numBytes += sLine_init(&sLine_XHZgqOJ8);
  numBytes += sLine_init(&sLine_8zXmj8rJ);
  numBytes += sLine_init(&sLine_0gEf2msG);
  numBytes += sLine_init(&sLine_K3G1bTwJ);
  numBytes += sLine_init(&sLine_VbmMV1Iv);
  numBytes += sLine_init(&sLine_s8lLMveo);
  numBytes += sLine_init(&sLine_hf7uJsuR);
  numBytes += sLine_init(&sLine_w4V333nZ);
  numBytes += sLine_init(&sLine_yVUS7KP2);
  numBytes += sLine_init(&sLine_OcFYbir4);
  numBytes += sLine_init(&sLine_u1uZ7Cgr);
  numBytes += sLine_init(&sLine_FTM5Ho5H);
  numBytes += sLine_init(&sLine_22f0CTUb);
  numBytes += sLine_init(&sLine_WIf99Y4b);
  numBytes += sLine_init(&sLine_nvbsDWTO);
  numBytes += sEnv_init(&sEnv_fwGqfIVT, 512, 256);
  numBytes += sEnv_init(&sEnv_5U3DdtSa, 512, 256);
  numBytes += sLine_init(&sLine_b2EMDQkb);
  numBytes += sLine_init(&sLine_gMba23mZ);
  numBytes += sLine_init(&sLine_KW4ZiQVx);
  numBytes += sLine_init(&sLine_9tLdTX4g);
  numBytes += sLine_init(&sLine_7N1NZmff);
  numBytes += sLine_init(&sLine_h7V4ONbK);
  numBytes += sLine_init(&sLine_TbwI4MRu);
  numBytes += sLine_init(&sLine_cEcqeAWd);
  numBytes += sLine_init(&sLine_JfvwGcRz);
  numBytes += sLine_init(&sLine_FeQ0d7CC);
  numBytes += sLine_init(&sLine_WyNQ0yrz);
  numBytes += sLine_init(&sLine_tqg3A58Q);
  numBytes += sLine_init(&sLine_r7GBlQrH);
  numBytes += sLine_init(&sLine_Ss9tz3IV);
  numBytes += sLine_init(&sLine_wYhs9SzC);
  numBytes += sLine_init(&sLine_Nnu0GRXB);
  numBytes += sLine_init(&sLine_JymyE2bo);
  numBytes += sLine_init(&sLine_a8iMNjYU);
  numBytes += sEnv_init(&sEnv_lHYVRI4m, 512, 256);
  numBytes += sEnv_init(&sEnv_SAW8rJVa, 512, 256);
  numBytes += sLine_init(&sLine_nQmEoeQV);
  numBytes += sLine_init(&sLine_WYYBFtrE);
  numBytes += sLine_init(&sLine_xudbDZz3);
  numBytes += sLine_init(&sLine_VBQxtuB7);
  numBytes += sLine_init(&sLine_ciVf8Gqy);
  numBytes += sLine_init(&sLine_UuUPUjID);
  numBytes += sLine_init(&sLine_bkdFRWLX);
  numBytes += sLine_init(&sLine_EYFFW5nI);
  numBytes += sLine_init(&sLine_3qCUGByJ);
  numBytes += sLine_init(&sLine_wbsevmSD);
  numBytes += sLine_init(&sLine_dBuEizqD);
  numBytes += sLine_init(&sLine_IsLPGIHF);
  numBytes += sLine_init(&sLine_5roj2S4H);
  numBytes += sLine_init(&sLine_PDYyPNjp);
  numBytes += sLine_init(&sLine_lWMMjkRr);
  numBytes += sLine_init(&sLine_8Generv3);
  numBytes += sLine_init(&sLine_jIN8rqyT);
  numBytes += sLine_init(&sLine_ibcsJeSC);
  numBytes += sLine_init(&sLine_4AfD4soT);
  numBytes += sLine_init(&sLine_GtenbnZ0);
  numBytes += sEnv_init(&sEnv_hfb8Vmlq, 512, 256);
  numBytes += sEnv_init(&sEnv_ePQ3NrNN, 512, 256);
  numBytes += sLine_init(&sLine_PXf2kXQi);
  numBytes += sLine_init(&sLine_YcKNbGC1);
  numBytes += sLine_init(&sLine_uPBtGs0y);
  numBytes += sLine_init(&sLine_J5jhes6r);
  numBytes += sLine_init(&sLine_n4IeAp4t);
  numBytes += sLine_init(&sLine_Vd7R4LVj);
  numBytes += sLine_init(&sLine_3DCXxmJd);
  numBytes += sLine_init(&sLine_Wtx2Sxvu);
  numBytes += sLine_init(&sLine_xSAGery4);
  numBytes += sLine_init(&sLine_JkOsyvuP);
  numBytes += sLine_init(&sLine_opzxbEXA);
  numBytes += sLine_init(&sLine_4U8Kwxfx);
  numBytes += sLine_init(&sLine_Bg5yvH5n);
  numBytes += sLine_init(&sLine_1Nge6qYn);
  numBytes += sLine_init(&sLine_xlOegA6O);
  numBytes += sLine_init(&sLine_RRiamckx);
  numBytes += sLine_init(&sLine_vE4LH36i);
  numBytes += sLine_init(&sLine_zH77K0S2);
  numBytes += sEnv_init(&sEnv_gGYQkzT7, 512, 256);
  numBytes += sEnv_init(&sEnv_OgLlV1RM, 512, 256);
  numBytes += sLine_init(&sLine_PrOpt7jL);
  numBytes += sLine_init(&sLine_35NR8fJK);
  numBytes += sLine_init(&sLine_gzmqTdB9);
  numBytes += sLine_init(&sLine_ElEDNtg6);
  numBytes += sLine_init(&sLine_NtFbh7Rt);
  numBytes += sLine_init(&sLine_VjirR0Sb);
  numBytes += sLine_init(&sLine_VFIrwsKV);
  numBytes += sLine_init(&sLine_6Cgv9mK1);
  numBytes += sLine_init(&sLine_8QnHWCU7);
  numBytes += sLine_init(&sLine_Sn4psQGu);
  numBytes += sLine_init(&sLine_OOKxWJe5);
  numBytes += sLine_init(&sLine_HK37Y5WI);
  numBytes += sLine_init(&sLine_Ww64HgsW);
  numBytes += sLine_init(&sLine_yt2CSue8);
  numBytes += sLine_init(&sLine_61lfxhjd);
  numBytes += sLine_init(&sLine_mi0KELrd);
  numBytes += sLine_init(&sLine_CyP9rrdN);
  numBytes += sLine_init(&sLine_q8hPoXvy);
  numBytes += sLine_init(&sLine_fZZFBNFt);
  numBytes += sLine_init(&sLine_60bvo7Bk);
  numBytes += sEnv_init(&sEnv_PAicXAbZ, 512, 256);
  numBytes += sEnv_init(&sEnv_ZiSQeIXD, 512, 256);
  numBytes += sLine_init(&sLine_jbqGS0i1);
  numBytes += sLine_init(&sLine_Tbb4MeVw);
  numBytes += sLine_init(&sLine_m5UPqswg);
  numBytes += sLine_init(&sLine_EvBwhjCX);
  numBytes += sLine_init(&sLine_YSXuJS1z);
  numBytes += sLine_init(&sLine_fgttbEnW);
  numBytes += sLine_init(&sLine_pJZ5lNYz);
  numBytes += sLine_init(&sLine_4klrPboV);
  numBytes += sLine_init(&sLine_jt7xLKzT);
  numBytes += sLine_init(&sLine_m61W8DWa);
  numBytes += sLine_init(&sLine_rob0dCDQ);
  numBytes += sLine_init(&sLine_0tOnRval);
  numBytes += sLine_init(&sLine_ro7tp7N3);
  numBytes += sLine_init(&sLine_IPkJlkUN);
  numBytes += sLine_init(&sLine_7zCp5iZm);
  numBytes += sLine_init(&sLine_MsBGlAfn);
  numBytes += sLine_init(&sLine_UHwz50Br);
  numBytes += sLine_init(&sLine_wTvVF7r4);
  numBytes += sEnv_init(&sEnv_KdHqRHC6, 512, 256);
  numBytes += sEnv_init(&sEnv_I2XQ3xr7, 512, 256);
  numBytes += sLine_init(&sLine_qwbhzP3H);
  numBytes += sLine_init(&sLine_cIK03Gcc);
  numBytes += sLine_init(&sLine_gnqBl1vj);
  numBytes += sLine_init(&sLine_whUHAsJc);
  numBytes += sLine_init(&sLine_QE5Y4KNf);
  numBytes += sLine_init(&sLine_O9n9XZy6);
  numBytes += cVar_init_f(&cVar_lkDRB3zx, 0.0f);
  numBytes += cVar_init_f(&cVar_u3CzAdqn, 0.0f);
  numBytes += cVar_init_f(&cVar_aTbauSnr, 0.0f);
  numBytes += cVar_init_f(&cVar_w7piIFlG, 0.0f);
  numBytes += cVar_init_f(&cVar_ShTOKDsQ, 0.0f);
  numBytes += cVar_init_f(&cVar_Veih56ng, 1.0f);
  numBytes += cVar_init_f(&cVar_0v4LnZQk, 0.0f);
  numBytes += cVar_init_f(&cVar_0lTxK1Qg, 0.0f);
  numBytes += cVar_init_f(&cVar_6nu1nRvW, 0.0f);
  numBytes += cVar_init_f(&cVar_hVJJcVIx, 0.0f);
  numBytes += cSlice_init(&cSlice_OpRnuCUY, 1, -1);
  numBytes += cVar_init_f(&cVar_xk72vv4L, 1337.0f);
  numBytes += cVar_init_f(&cVar_Pl9BVqQU, 0.0f);
  numBytes += cIf_init(&cIf_owYZSf8Z, false);
  numBytes += cIf_init(&cIf_zZ4VqL1w, false);
  numBytes += cBinop_init(&cBinop_s4mF7vka, 0.0f); // __pow
  numBytes += cIf_init(&cIf_DotJ93uc, false);
  numBytes += cBinop_init(&cBinop_SkACZPiQ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_1kIpwxNK, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_yQTGe0qr, 0.0f);
  numBytes += cIf_init(&cIf_o7t3SwLR, false);
  numBytes += cIf_init(&cIf_M77WXrNG, false);
  numBytes += cBinop_init(&cBinop_W7vJ83NW, 0.0f); // __pow
  numBytes += cIf_init(&cIf_n5dz31Ul, false);
  numBytes += cBinop_init(&cBinop_iWioxJgd, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_0U8PezHC, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_JAqz8kRJ, 0.0f);
  numBytes += cIf_init(&cIf_1BTUepMo, false);
  numBytes += cIf_init(&cIf_EWax1nWu, false);
  numBytes += cBinop_init(&cBinop_phwwV9ZC, 0.0f); // __pow
  numBytes += cIf_init(&cIf_6QjkTGu7, false);
  numBytes += cBinop_init(&cBinop_rCBFqgQY, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_UdmfyHZX, -15.0f); // __eq
  numBytes += cIf_init(&cIf_M689YX86, false);
  numBytes += cSlice_init(&cSlice_BNxdpZsp, 1, -1);
  numBytes += cVar_init_f(&cVar_JL4AfSmY, 0.0f);
  numBytes += cSlice_init(&cSlice_KU2GlgjI, 1, -1);
  numBytes += cVar_init_f(&cVar_iaZxQvAD, 0.0f);
  numBytes += cSlice_init(&cSlice_i4ykLzbV, 1, -1);
  numBytes += cVar_init_f(&cVar_GIBK4S1F, 0.0f);
  numBytes += cSlice_init(&cSlice_XnQukGWe, 1, -1);
  numBytes += cVar_init_f(&cVar_Ak3Yk9gO, 0.313f);
  numBytes += cBinop_init(&cBinop_PK3Q3Qha, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_i451Uszm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_a8mu7GsE, 0.0f);
  numBytes += cVar_init_f(&cVar_Fs4ctBVY, 1337.0f);
  numBytes += cVar_init_f(&cVar_BkmLuNmQ, 0.3f);
  numBytes += cBinop_init(&cBinop_Vs40UCHC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XlxcAanX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sVK0BsTR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JINmM0q2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CDoViBc7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2PVGrNSV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_71ZkmEt7, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FGghuzlG, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KBwLDcNm, 0.0f);
  numBytes += cVar_init_f(&cVar_LkwdWRNS, 1337.0f);
  numBytes += cVar_init_f(&cVar_RlOrQ5DJ, 0.313f);
  numBytes += cBinop_init(&cBinop_L1rRr30S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ArA8T6XR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ua1woN1a, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5lE2tXZ7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_J5Q1elVV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Y8pUCFql, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_31YGSeVe, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_jrlqIs3r, 0.0f);
  numBytes += cVar_init_f(&cVar_CqA03vsI, 1037.0f);
  numBytes += cVar_init_f(&cVar_Q7l13FpH, 0.4f);
  numBytes += cBinop_init(&cBinop_6AHev5iw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PPgEGWWn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Tt36sCuj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FCsNMGG7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AcnqHDRZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EkR7F6bb, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_ix0SmyO0, 1, -1);
  numBytes += cVar_init_f(&cVar_5aXuahu1, 1337.0f);
  numBytes += cVar_init_f(&cVar_CE8LVBsg, 0.0f);
  numBytes += cIf_init(&cIf_BV4kv144, false);
  numBytes += cIf_init(&cIf_LtynPOBp, false);
  numBytes += cBinop_init(&cBinop_QvAlrNGy, 0.0f); // __pow
  numBytes += cIf_init(&cIf_iDT5Ugx1, false);
  numBytes += cBinop_init(&cBinop_vn3S6FAR, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Qcbsw0Fy, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_joCiCLv9, 0.0f);
  numBytes += cIf_init(&cIf_dIq6LAwI, false);
  numBytes += cIf_init(&cIf_hBro3PD1, false);
  numBytes += cBinop_init(&cBinop_ykx2zRLx, 0.0f); // __pow
  numBytes += cIf_init(&cIf_PHvg1LbA, false);
  numBytes += cBinop_init(&cBinop_Bb85VVS8, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_WUdd9F2F, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_6nIHGbXi, 0.0f);
  numBytes += cIf_init(&cIf_ovQU6i2C, false);
  numBytes += cIf_init(&cIf_jI4WGK1H, false);
  numBytes += cBinop_init(&cBinop_def7jWEM, 0.0f); // __pow
  numBytes += cIf_init(&cIf_w85ucKkY, false);
  numBytes += cBinop_init(&cBinop_B6WuvEL7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_wYTpwf7H, -15.0f); // __eq
  numBytes += cIf_init(&cIf_4FZrC2rE, false);
  numBytes += cSlice_init(&cSlice_AmRLpq0S, 1, -1);
  numBytes += cVar_init_f(&cVar_PTPhYT7j, 0.0f);
  numBytes += cSlice_init(&cSlice_8Z1fqS3Z, 1, -1);
  numBytes += cVar_init_f(&cVar_yh524koF, 0.0f);
  numBytes += cSlice_init(&cSlice_hewqubBS, 1, -1);
  numBytes += cVar_init_f(&cVar_m1N7CNDv, 0.0f);
  numBytes += cSlice_init(&cSlice_m7DlJSF3, 1, -1);
  numBytes += cVar_init_f(&cVar_Yv1S6gzQ, 0.313f);
  numBytes += cBinop_init(&cBinop_Sme2pgZA, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_4gHKnOyN, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Uaj3TLlN, 0.0f);
  numBytes += cVar_init_f(&cVar_Q0ffxxGh, 1337.0f);
  numBytes += cVar_init_f(&cVar_Y80D5wKv, 0.3f);
  numBytes += cBinop_init(&cBinop_rs2uYjdu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_70VMRexL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UvMnqyUJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jzhoXwng, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3g3KDKuP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7suhxoqv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mwkP53oO, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_0SJE0s4X, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_kqWGzasI, 0.0f);
  numBytes += cVar_init_f(&cVar_2ziHN9MQ, 1337.0f);
  numBytes += cVar_init_f(&cVar_ZZZvZC9A, 0.313f);
  numBytes += cBinop_init(&cBinop_AX6KlDYp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cs5ufY6S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E9COFy7p, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GFLxS763, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ebYb3eZ5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bu8lhzeV, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_KDHbuEfo, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_4CzvuzxV, 0.0f);
  numBytes += cVar_init_f(&cVar_tcuoHVQc, 1037.0f);
  numBytes += cVar_init_f(&cVar_LocnkqR6, 0.4f);
  numBytes += cBinop_init(&cBinop_gIuHThIv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cIvyDbQx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eZ7iWZPz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jb5NzQ86, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_p0cm5H6c, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yUzISQNe, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_YsgiZALf, 5705.6f);
  numBytes += cVar_init_f(&cVar_gBS4qxmU, 313.3f);
  numBytes += cBinop_init(&cBinop_rqUMnYef, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_wNXWm0Do, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_7T2nfac4, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_Vut5fofs, 1, -1);
  numBytes += cVar_init_f(&cVar_uH5fYp4o, 0.5f);
  numBytes += cVar_init_f(&cVar_m8SLno88, 0.0f);
  numBytes += cVar_init_f(&cVar_46D9htXF, 0.0f);
  numBytes += cIf_init(&cIf_ENRfbzcC, false);
  numBytes += cIf_init(&cIf_xaMhMUZf, false);
  numBytes += cDelay_init(this, &cDelay_42N864Ww, 10.0f);
  numBytes += cIf_init(&cIf_Ui15WaF7, false);
  numBytes += cIf_init(&cIf_WfEw0arC, false);
  numBytes += cDelay_init(this, &cDelay_3uWk24qq, 10.0f);
  numBytes += cIf_init(&cIf_oLQKYXcP, false);
  numBytes += cIf_init(&cIf_TC3VtfDJ, false);
  numBytes += cDelay_init(this, &cDelay_WTnNWNGH, 10.0f);
  numBytes += cIf_init(&cIf_v2N2FwEZ, false);
  numBytes += cIf_init(&cIf_KSrTsvto, false);
  numBytes += cDelay_init(this, &cDelay_nnj1l1Kf, 10.0f);
  numBytes += cIf_init(&cIf_qEgEX7GH, false);
  numBytes += cIf_init(&cIf_P8mwR9pl, false);
  numBytes += cDelay_init(this, &cDelay_jh3ZWr9K, 10.0f);
  numBytes += cIf_init(&cIf_2HtWsrz1, false);
  numBytes += cIf_init(&cIf_6iEnGsis, false);
  numBytes += cDelay_init(this, &cDelay_UHi0oo0q, 10.0f);
  numBytes += cIf_init(&cIf_wChrShYp, false);
  numBytes += cIf_init(&cIf_fDNVtOl9, false);
  numBytes += cDelay_init(this, &cDelay_7s2o6dfO, 10.0f);
  numBytes += cIf_init(&cIf_pDnLTxFr, false);
  numBytes += cIf_init(&cIf_eTP5nbZw, false);
  numBytes += cDelay_init(this, &cDelay_FSbkEOCQ, 10.0f);
  numBytes += cIf_init(&cIf_oQ4SvZ3T, false);
  numBytes += cIf_init(&cIf_oZ28SxDU, false);
  numBytes += cDelay_init(this, &cDelay_FSVSWrnQ, 10.0f);
  numBytes += cIf_init(&cIf_ifkYq70I, false);
  numBytes += cIf_init(&cIf_ehNQ57td, false);
  numBytes += cDelay_init(this, &cDelay_xM4H2uXX, 10.0f);
  numBytes += cIf_init(&cIf_Lg2gIrJU, false);
  numBytes += cIf_init(&cIf_wJpbNtI9, false);
  numBytes += cDelay_init(this, &cDelay_2T473vZ8, 10.0f);
  numBytes += cIf_init(&cIf_lEcaDMO2, false);
  numBytes += cIf_init(&cIf_8tbs0tyJ, false);
  numBytes += cDelay_init(this, &cDelay_LcDUXHm4, 10.0f);
  numBytes += sVarf_init(&sVarf_8gTeE0e2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_H30D3CpE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1AXl2uUE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sR6BjPDN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lSI7MdTb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DkxqZB8w, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Gxd3efmv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1Q9C7EFK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1OYbK3Za, 0.0f);
  numBytes += cSlice_init(&cSlice_EprLPIT6, 1, -1);
  numBytes += cVar_init_f(&cVar_n7KYF9IL, 1.0f);
  numBytes += cSlice_init(&cSlice_yOZtJkXt, 1, -1);
  numBytes += cVar_init_f(&cVar_ybdGSvBi, 0.0f);
  numBytes += cSlice_init(&cSlice_XFeeicXS, 1, -1);
  numBytes += cVar_init_f(&cVar_wuZwyb6I, 512.0f);
  numBytes += cSlice_init(&cSlice_pjWKRQ1x, 1, -1);
  numBytes += cVar_init_f(&cVar_x6DxKn5R, 1.0f);
  numBytes += cSlice_init(&cSlice_trUsCBHO, 1, -1);
  numBytes += cVar_init_f(&cVar_zI0NMDlQ, 1.0f);
  numBytes += cDelay_init(this, &cDelay_NS0vrtyW, 20.0f);
  numBytes += cVar_init_f(&cVar_NHJLYtzy, 0.0f);
  numBytes += cIf_init(&cIf_dem37pPp, false);
  numBytes += cIf_init(&cIf_1vN01NHK, false);
  numBytes += cBinop_init(&cBinop_c6Dl3AsG, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_S9zh4Rti, 1, -1);
  numBytes += cVar_init_f(&cVar_SBfnnluA, 0.0f);
  numBytes += sVarf_init(&sVarf_FQiKsjzf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4UTRS53P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JUnKujUR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2SyL3deN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jd7wSB2E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s36A0CoR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_shOFBqeA, 0.0f);
  numBytes += cVar_init_f(&cVar_XNBeVI8C, 0.0f);
  numBytes += cIf_init(&cIf_3hP11Upg, false);
  numBytes += cIf_init(&cIf_6vwZpG7M, false);
  numBytes += cDelay_init(this, &cDelay_a6ZbhPfx, 10.0f);
  numBytes += cIf_init(&cIf_vaYcTgsx, false);
  numBytes += cIf_init(&cIf_oqNWBPmM, false);
  numBytes += cDelay_init(this, &cDelay_qgg6xE3F, 10.0f);
  numBytes += cIf_init(&cIf_BTxolB12, false);
  numBytes += cIf_init(&cIf_t89eZYNF, false);
  numBytes += cDelay_init(this, &cDelay_hoJhBmWw, 10.0f);
  numBytes += cIf_init(&cIf_ucT8B5HJ, false);
  numBytes += cIf_init(&cIf_x8qKmdCQ, false);
  numBytes += cDelay_init(this, &cDelay_EjbT7bLq, 10.0f);
  numBytes += cIf_init(&cIf_1W57zkFo, false);
  numBytes += cIf_init(&cIf_2q04qET3, false);
  numBytes += cDelay_init(this, &cDelay_KcTeduk3, 10.0f);
  numBytes += cIf_init(&cIf_S8ltXv6a, false);
  numBytes += cIf_init(&cIf_kq1yJVCU, false);
  numBytes += cDelay_init(this, &cDelay_mSpWDjZG, 10.0f);
  numBytes += cIf_init(&cIf_pkmnnfmI, false);
  numBytes += cIf_init(&cIf_LuK1vUl4, false);
  numBytes += cDelay_init(this, &cDelay_G3x6Kd8s, 10.0f);
  numBytes += cIf_init(&cIf_9POSNZey, false);
  numBytes += cIf_init(&cIf_nARlVr7H, false);
  numBytes += cDelay_init(this, &cDelay_J46bAXiS, 10.0f);
  numBytes += cIf_init(&cIf_GQkgkWVF, false);
  numBytes += cIf_init(&cIf_qw83NmZM, false);
  numBytes += cDelay_init(this, &cDelay_TqUpXgUP, 10.0f);
  numBytes += cIf_init(&cIf_7lewKYqK, false);
  numBytes += cIf_init(&cIf_CUL5inN7, false);
  numBytes += cDelay_init(this, &cDelay_XDbXsScX, 10.0f);
  numBytes += cIf_init(&cIf_OexvmljB, false);
  numBytes += cIf_init(&cIf_HvaoTYss, false);
  numBytes += cDelay_init(this, &cDelay_wO7ZJUAt, 10.0f);
  numBytes += cIf_init(&cIf_9JL18D1s, false);
  numBytes += cIf_init(&cIf_Ke3Zd936, false);
  numBytes += cDelay_init(this, &cDelay_hZojEqi1, 10.0f);
  numBytes += sVarf_init(&sVarf_1tiMbaWq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nJwFUtvr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MHbehHQx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RB4oZln5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zgO57szG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Wp1Z1EFL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9HHnub7k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sKCYWlvh, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_FtliNFI3, 0.0f);
  numBytes += cSlice_init(&cSlice_S8byrhRF, 1, -1);
  numBytes += cVar_init_f(&cVar_MY5hBtkR, 1.0f);
  numBytes += cSlice_init(&cSlice_CfQ7cJ8K, 1, -1);
  numBytes += cVar_init_f(&cVar_ccMTpCna, 0.0f);
  numBytes += cSlice_init(&cSlice_LwXl8hF3, 1, -1);
  numBytes += cVar_init_f(&cVar_WatKAlu4, 512.0f);
  numBytes += cSlice_init(&cSlice_pIHegnmh, 1, -1);
  numBytes += cVar_init_f(&cVar_Wj5vm2nC, 1.0f);
  numBytes += cSlice_init(&cSlice_6fNjqRTS, 1, -1);
  numBytes += cVar_init_f(&cVar_f9YSoTfk, 1.0f);
  numBytes += cDelay_init(this, &cDelay_WPIwmLDK, 20.0f);
  numBytes += cVar_init_f(&cVar_oW8gJadb, 0.0f);
  numBytes += cIf_init(&cIf_rDEMtS0R, false);
  numBytes += cIf_init(&cIf_IAjkotbY, false);
  numBytes += cBinop_init(&cBinop_J7wIIjl7, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_7ywk3WBO, 1, -1);
  numBytes += cVar_init_f(&cVar_LJu62tvE, 0.0f);
  numBytes += sVarf_init(&sVarf_hFS9DBgK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uQoNTnaJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NnDpXMuU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gEZhPkav, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mvaw1tkC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_js7jiul6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EurM2HY5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jcBndMVu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TIQN5qto, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wYLxCgfY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_TnA6SR3v, 0.0f);
  numBytes += cVar_init_f(&cVar_TSE1mEHZ, 0.0f);
  numBytes += cVar_init_f(&cVar_PLK4lUSu, 0.0f);
  numBytes += cVar_init_f(&cVar_dsBqXxEO, 0.0f);
  numBytes += cVar_init_f(&cVar_EJbP2V0E, 0.0f);
  numBytes += cVar_init_f(&cVar_MwNIuobt, 1.0f);
  numBytes += cSlice_init(&cSlice_k7JCErlU, 1, -1);
  numBytes += cVar_init_f(&cVar_0lKiyXb5, 0.5f);
  numBytes += cVar_init_f(&cVar_oyEJN1qq, 0.0f);
  numBytes += cVar_init_f(&cVar_hzNZeEZ9, 0.0f);
  numBytes += cIf_init(&cIf_ugcNlgw0, false);
  numBytes += cIf_init(&cIf_omEaLMbq, false);
  numBytes += cDelay_init(this, &cDelay_OyPwS8uu, 10.0f);
  numBytes += cIf_init(&cIf_7lPvEgvp, false);
  numBytes += cIf_init(&cIf_48gq9M0Y, false);
  numBytes += cDelay_init(this, &cDelay_127ffocM, 10.0f);
  numBytes += cIf_init(&cIf_KIwAOamE, false);
  numBytes += cIf_init(&cIf_3TKUhQ9i, false);
  numBytes += cDelay_init(this, &cDelay_luLKUPmu, 10.0f);
  numBytes += cIf_init(&cIf_mNlST4g1, false);
  numBytes += cIf_init(&cIf_u40RboFW, false);
  numBytes += cDelay_init(this, &cDelay_KsNwWZKM, 10.0f);
  numBytes += cIf_init(&cIf_15AqQrOJ, false);
  numBytes += cIf_init(&cIf_oETmUffi, false);
  numBytes += cDelay_init(this, &cDelay_6FdXwlVA, 10.0f);
  numBytes += cIf_init(&cIf_gfCqCp1i, false);
  numBytes += cIf_init(&cIf_y870Iiem, false);
  numBytes += cDelay_init(this, &cDelay_0bypsYNK, 10.0f);
  numBytes += cIf_init(&cIf_Ce9kyjRL, false);
  numBytes += cIf_init(&cIf_6JXpFIwk, false);
  numBytes += cDelay_init(this, &cDelay_4wvPuvas, 10.0f);
  numBytes += cIf_init(&cIf_mfgw6FTz, false);
  numBytes += cIf_init(&cIf_JGM0nAsl, false);
  numBytes += cDelay_init(this, &cDelay_0iNS9f3A, 10.0f);
  numBytes += cIf_init(&cIf_GcvVHEXf, false);
  numBytes += cIf_init(&cIf_9SxSsJpp, false);
  numBytes += cDelay_init(this, &cDelay_fhh2TBGF, 10.0f);
  numBytes += cIf_init(&cIf_Oq64UPWw, false);
  numBytes += cIf_init(&cIf_iL8mKSYH, false);
  numBytes += cDelay_init(this, &cDelay_vqoQR9aU, 10.0f);
  numBytes += cIf_init(&cIf_iOKr0WJT, false);
  numBytes += cIf_init(&cIf_q55xwr9B, false);
  numBytes += cDelay_init(this, &cDelay_msO8IkLk, 10.0f);
  numBytes += cIf_init(&cIf_Rsu5Xms7, false);
  numBytes += cIf_init(&cIf_TBJhVeRQ, false);
  numBytes += cDelay_init(this, &cDelay_yAPGZHrK, 10.0f);
  numBytes += sVarf_init(&sVarf_31ZxpuRu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ek2nhrhC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ohwNmO95, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZWdW6P3z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G4lUm0Ka, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KOVZ7bNP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F1FSlOOp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oxdnJmEH, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_qNuRGDTa, 0.0f);
  numBytes += cSlice_init(&cSlice_oCethXBV, 1, -1);
  numBytes += cVar_init_f(&cVar_0P7w5x46, 1.0f);
  numBytes += cSlice_init(&cSlice_ZbctTepV, 1, -1);
  numBytes += cVar_init_f(&cVar_K6JJShFY, 0.0f);
  numBytes += cSlice_init(&cSlice_0hoT3EYB, 1, -1);
  numBytes += cVar_init_f(&cVar_VD7UypTz, 512.0f);
  numBytes += cSlice_init(&cSlice_mG6ACncl, 1, -1);
  numBytes += cVar_init_f(&cVar_XUf14VmT, 1.0f);
  numBytes += cSlice_init(&cSlice_V5CO36n1, 1, -1);
  numBytes += cVar_init_f(&cVar_WLNkwKVV, 1.0f);
  numBytes += cDelay_init(this, &cDelay_rWRuMW7n, 20.0f);
  numBytes += cVar_init_f(&cVar_ZWzOjBCv, 0.0f);
  numBytes += cIf_init(&cIf_LtEjdbcl, false);
  numBytes += cIf_init(&cIf_5ihWf6lM, false);
  numBytes += cBinop_init(&cBinop_cvpD0Ddn, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Bd0zlBUw, 1, -1);
  numBytes += cVar_init_f(&cVar_1SmD67xd, 0.0f);
  numBytes += sVarf_init(&sVarf_HTnyujC2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cOoGl5UQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vohM47Kn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_az21Gie7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sGKgCfY9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_knDo5zE4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_jLvvWjc6, 0.0f);
  numBytes += cVar_init_f(&cVar_FZWMwe0B, 0.0f);
  numBytes += cIf_init(&cIf_ogkRG2WS, false);
  numBytes += cIf_init(&cIf_HRwV4H6Z, false);
  numBytes += cDelay_init(this, &cDelay_IBk48Ow2, 10.0f);
  numBytes += cIf_init(&cIf_U8OktDf2, false);
  numBytes += cIf_init(&cIf_Wkc95PbG, false);
  numBytes += cDelay_init(this, &cDelay_oCGhhUYe, 10.0f);
  numBytes += cIf_init(&cIf_6dng4avu, false);
  numBytes += cIf_init(&cIf_L1aABtrQ, false);
  numBytes += cDelay_init(this, &cDelay_QGRtkO1H, 10.0f);
  numBytes += cIf_init(&cIf_Ndh3Jl6S, false);
  numBytes += cIf_init(&cIf_Mo77ZnNy, false);
  numBytes += cDelay_init(this, &cDelay_Cb9CrlpH, 10.0f);
  numBytes += cIf_init(&cIf_Zdl7ljyr, false);
  numBytes += cIf_init(&cIf_EVR3lyN1, false);
  numBytes += cDelay_init(this, &cDelay_NkbkbB9m, 10.0f);
  numBytes += cIf_init(&cIf_LjNOMeLd, false);
  numBytes += cIf_init(&cIf_hn3C2vpj, false);
  numBytes += cDelay_init(this, &cDelay_zC26uYy1, 10.0f);
  numBytes += cIf_init(&cIf_11FZQThS, false);
  numBytes += cIf_init(&cIf_lAXbFng0, false);
  numBytes += cDelay_init(this, &cDelay_F4mNksB9, 10.0f);
  numBytes += cIf_init(&cIf_vlvDfylu, false);
  numBytes += cIf_init(&cIf_RGIrLcOT, false);
  numBytes += cDelay_init(this, &cDelay_JZjSwKTl, 10.0f);
  numBytes += cIf_init(&cIf_deHFdqNr, false);
  numBytes += cIf_init(&cIf_Frf3Hve0, false);
  numBytes += cDelay_init(this, &cDelay_k1Mppwyz, 10.0f);
  numBytes += cIf_init(&cIf_RKFz05RX, false);
  numBytes += cIf_init(&cIf_KUDfVX5h, false);
  numBytes += cDelay_init(this, &cDelay_6akhOx5e, 10.0f);
  numBytes += cIf_init(&cIf_OUdsjLMW, false);
  numBytes += cIf_init(&cIf_wKwufeBE, false);
  numBytes += cDelay_init(this, &cDelay_Jhe9YFpN, 10.0f);
  numBytes += cIf_init(&cIf_GBIfOTZJ, false);
  numBytes += cIf_init(&cIf_NXLVBC0u, false);
  numBytes += cDelay_init(this, &cDelay_ajtykbrK, 10.0f);
  numBytes += sVarf_init(&sVarf_QMwirl53, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ns8VLpEf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3eUMrVRV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RYVZ87bm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5r2rRHTR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SoApFxOH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TBCrBYhl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xmGbblEH, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_bObBkbAi, 0.0f);
  numBytes += cSlice_init(&cSlice_kwDzAfgT, 1, -1);
  numBytes += cVar_init_f(&cVar_As6K0iEH, 1.0f);
  numBytes += cSlice_init(&cSlice_4Iwbhqfg, 1, -1);
  numBytes += cVar_init_f(&cVar_URpaR4cz, 0.0f);
  numBytes += cSlice_init(&cSlice_RSoLGJDt, 1, -1);
  numBytes += cVar_init_f(&cVar_d2VfAk7u, 512.0f);
  numBytes += cSlice_init(&cSlice_5roeZKve, 1, -1);
  numBytes += cVar_init_f(&cVar_iV56wZN4, 1.0f);
  numBytes += cSlice_init(&cSlice_fiBOOZZF, 1, -1);
  numBytes += cVar_init_f(&cVar_QG38e6Qb, 1.0f);
  numBytes += cDelay_init(this, &cDelay_5KrCYdJY, 20.0f);
  numBytes += cVar_init_f(&cVar_Zv6w88VD, 0.0f);
  numBytes += cIf_init(&cIf_9wQ4J2nC, false);
  numBytes += cIf_init(&cIf_G5Ur92py, false);
  numBytes += cBinop_init(&cBinop_KCiKCwsC, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_PmE6BCWx, 1, -1);
  numBytes += cVar_init_f(&cVar_0fFTshLN, 0.0f);
  numBytes += sVarf_init(&sVarf_IWRSW32p, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Xi7qWikw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nXND73cu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IEguGXWq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vmZZJ1Aj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8YULn7tN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LoRLgTd8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AAojBTOx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1yN8uM0h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_82wNNzcg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_DMMVT6q2, 0.0f);
  numBytes += cVar_init_f(&cVar_CZOLYm3G, 0.0f);
  numBytes += cVar_init_f(&cVar_CkXPNf43, 0.0f);
  numBytes += cVar_init_f(&cVar_YF7aIRrU, 0.0f);
  numBytes += cVar_init_f(&cVar_NdrEkIMR, 0.0f);
  numBytes += cVar_init_f(&cVar_pyPAyyiK, 1.0f);
  numBytes += cSlice_init(&cSlice_V3PusyTc, 1, -1);
  numBytes += cVar_init_f(&cVar_XoMMzxdz, 0.5f);
  numBytes += cVar_init_f(&cVar_rmDwOSI4, 0.0f);
  numBytes += cVar_init_f(&cVar_Q5gKQuKz, 0.0f);
  numBytes += cIf_init(&cIf_laMYLRaC, false);
  numBytes += cIf_init(&cIf_ewVSuQLj, false);
  numBytes += cDelay_init(this, &cDelay_P28vHGW0, 10.0f);
  numBytes += cIf_init(&cIf_wVsU10kP, false);
  numBytes += cIf_init(&cIf_AA80yc1h, false);
  numBytes += cDelay_init(this, &cDelay_BDceR4Cz, 10.0f);
  numBytes += cIf_init(&cIf_N8d6vH6d, false);
  numBytes += cIf_init(&cIf_Ea2ZswGk, false);
  numBytes += cDelay_init(this, &cDelay_Ip1EbKMK, 10.0f);
  numBytes += cIf_init(&cIf_exd1ea98, false);
  numBytes += cIf_init(&cIf_2wU3SwjE, false);
  numBytes += cDelay_init(this, &cDelay_pIUgBQ8P, 10.0f);
  numBytes += cIf_init(&cIf_q3bNZCvD, false);
  numBytes += cIf_init(&cIf_rL1xSIcF, false);
  numBytes += cDelay_init(this, &cDelay_QK0QLyJc, 10.0f);
  numBytes += cIf_init(&cIf_8LVfBznq, false);
  numBytes += cIf_init(&cIf_vwnrCUkL, false);
  numBytes += cDelay_init(this, &cDelay_1Ef1bZtH, 10.0f);
  numBytes += cIf_init(&cIf_blarugeb, false);
  numBytes += cIf_init(&cIf_8i3U837r, false);
  numBytes += cDelay_init(this, &cDelay_rSNd7a3W, 10.0f);
  numBytes += cIf_init(&cIf_p1Th6LHP, false);
  numBytes += cIf_init(&cIf_iuieyYbQ, false);
  numBytes += cDelay_init(this, &cDelay_JmEKGNIq, 10.0f);
  numBytes += cIf_init(&cIf_4MdDN4jN, false);
  numBytes += cIf_init(&cIf_rhKwTnFY, false);
  numBytes += cDelay_init(this, &cDelay_RPH4JvjB, 10.0f);
  numBytes += cIf_init(&cIf_OH1QAg8w, false);
  numBytes += cIf_init(&cIf_adWL0ogj, false);
  numBytes += cDelay_init(this, &cDelay_zk7erOSB, 10.0f);
  numBytes += cIf_init(&cIf_iJwJt9jH, false);
  numBytes += cIf_init(&cIf_jI7Y9CT4, false);
  numBytes += cDelay_init(this, &cDelay_wdChK4Jb, 10.0f);
  numBytes += cIf_init(&cIf_4IAhKwRp, false);
  numBytes += cIf_init(&cIf_fxCdLzQ2, false);
  numBytes += cDelay_init(this, &cDelay_2tHx3LpF, 10.0f);
  numBytes += sVarf_init(&sVarf_iH1l6iI5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MeqqWyN6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XiStgroB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jGccrMWG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YXtrraGw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rp4bco1B, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gDgdUDu8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WoEPFZYw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6om5vrlp, 0.0f);
  numBytes += cSlice_init(&cSlice_X50qkm2F, 1, -1);
  numBytes += cVar_init_f(&cVar_lHHNFtke, 1.0f);
  numBytes += cSlice_init(&cSlice_50cjeODW, 1, -1);
  numBytes += cVar_init_f(&cVar_tPNKtmQZ, 0.0f);
  numBytes += cSlice_init(&cSlice_5ix8r6ML, 1, -1);
  numBytes += cVar_init_f(&cVar_1kgrorQq, 512.0f);
  numBytes += cSlice_init(&cSlice_ftcCyCk2, 1, -1);
  numBytes += cVar_init_f(&cVar_y1GNFcy2, 1.0f);
  numBytes += cSlice_init(&cSlice_NYnLm0sW, 1, -1);
  numBytes += cVar_init_f(&cVar_9BzGnXrp, 1.0f);
  numBytes += cDelay_init(this, &cDelay_9WHYbWSG, 20.0f);
  numBytes += cVar_init_f(&cVar_Wjn1ZYak, 0.0f);
  numBytes += cIf_init(&cIf_HfnIOakb, false);
  numBytes += cIf_init(&cIf_dgl2ygea, false);
  numBytes += cBinop_init(&cBinop_5TMWnxl1, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Oiq8vS25, 1, -1);
  numBytes += cVar_init_f(&cVar_G992ZyYy, 0.0f);
  numBytes += sVarf_init(&sVarf_2wq2lcTl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_15lCwsLK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4wpipFqQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PEYIFgAF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rDOSX2dN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WqCl0lIu, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_TEmWMDZf, 0.0f);
  numBytes += cVar_init_f(&cVar_ftvqs3Tl, 0.0f);
  numBytes += cIf_init(&cIf_DD1Lr2Yp, false);
  numBytes += cIf_init(&cIf_1bZO1Nwz, false);
  numBytes += cDelay_init(this, &cDelay_CDtlT6HU, 10.0f);
  numBytes += cIf_init(&cIf_1mbHZtwj, false);
  numBytes += cIf_init(&cIf_yub2WM5O, false);
  numBytes += cDelay_init(this, &cDelay_whlmoQWJ, 10.0f);
  numBytes += cIf_init(&cIf_SHgi4gFh, false);
  numBytes += cIf_init(&cIf_XZCbU96q, false);
  numBytes += cDelay_init(this, &cDelay_qel8iniW, 10.0f);
  numBytes += cIf_init(&cIf_D6xelNNS, false);
  numBytes += cIf_init(&cIf_2pn1pjsR, false);
  numBytes += cDelay_init(this, &cDelay_ZUGwqtVo, 10.0f);
  numBytes += cIf_init(&cIf_iuwwq1Rx, false);
  numBytes += cIf_init(&cIf_mLvdD550, false);
  numBytes += cDelay_init(this, &cDelay_9PWWFuk3, 10.0f);
  numBytes += cIf_init(&cIf_Y2PlRAdX, false);
  numBytes += cIf_init(&cIf_Lgdpkj0J, false);
  numBytes += cDelay_init(this, &cDelay_TtLDTHu9, 10.0f);
  numBytes += cIf_init(&cIf_F48ZVWom, false);
  numBytes += cIf_init(&cIf_PdLACsZT, false);
  numBytes += cDelay_init(this, &cDelay_Q7HCKE40, 10.0f);
  numBytes += cIf_init(&cIf_SvK6tgjN, false);
  numBytes += cIf_init(&cIf_JbcaoR6g, false);
  numBytes += cDelay_init(this, &cDelay_1Osf4WFK, 10.0f);
  numBytes += cIf_init(&cIf_KoE42EuA, false);
  numBytes += cIf_init(&cIf_AmJfRLrT, false);
  numBytes += cDelay_init(this, &cDelay_45gVs3UX, 10.0f);
  numBytes += cIf_init(&cIf_k1UpkB5c, false);
  numBytes += cIf_init(&cIf_kFsCOqMA, false);
  numBytes += cDelay_init(this, &cDelay_FohdJn1K, 10.0f);
  numBytes += cIf_init(&cIf_z5qSNv4P, false);
  numBytes += cIf_init(&cIf_9vAH2Itj, false);
  numBytes += cDelay_init(this, &cDelay_uS77lI8X, 10.0f);
  numBytes += cIf_init(&cIf_rQodkwrb, false);
  numBytes += cIf_init(&cIf_5muQ7Oiu, false);
  numBytes += cDelay_init(this, &cDelay_dwN7IVu3, 10.0f);
  numBytes += sVarf_init(&sVarf_MTLWkihA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HQHOy7tg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PxIR2b5Z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kEO67BgH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Suli7oE6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GyFxNo2C, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PnIh6N2j, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5BB5mEQ0, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_964FGDhp, 0.0f);
  numBytes += cSlice_init(&cSlice_ooSk9xGv, 1, -1);
  numBytes += cVar_init_f(&cVar_prEbvl3L, 1.0f);
  numBytes += cSlice_init(&cSlice_Vlx6oEZv, 1, -1);
  numBytes += cVar_init_f(&cVar_P1fYvbpk, 0.0f);
  numBytes += cSlice_init(&cSlice_yL2lVgfA, 1, -1);
  numBytes += cVar_init_f(&cVar_aDmRIGLh, 512.0f);
  numBytes += cSlice_init(&cSlice_YsafdeN9, 1, -1);
  numBytes += cVar_init_f(&cVar_Ffr61hlB, 1.0f);
  numBytes += cSlice_init(&cSlice_JWu06Twb, 1, -1);
  numBytes += cVar_init_f(&cVar_VB6Polvp, 1.0f);
  numBytes += cDelay_init(this, &cDelay_9FzsyDej, 20.0f);
  numBytes += cVar_init_f(&cVar_yDZrzAo9, 0.0f);
  numBytes += cIf_init(&cIf_4RGn0Vai, false);
  numBytes += cIf_init(&cIf_mfabXTZz, false);
  numBytes += cBinop_init(&cBinop_CXiQZjsb, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Qpdl5mDs, 1, -1);
  numBytes += cVar_init_f(&cVar_lNkaGQ1k, 0.0f);
  numBytes += sVarf_init(&sVarf_F1ZUW2jn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0F2j2sB2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yj5bdqqy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_om5JlOx7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fiSmhAu7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4yn6nuf5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vowBkgeo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sBbD1Bzf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WgcZepG2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rz3kvszM, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_kC0u7Ck0, 0.0f);
  numBytes += cVar_init_f(&cVar_r3ortZYz, 0.0f);
  numBytes += cVar_init_f(&cVar_XW1ltRcI, 0.0f);
  numBytes += sVarf_init(&sVarf_0sCGcYHg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HBdPgQ7P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wD1srm5P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZClzWpid, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wNL4VH2I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vmicOfaC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_unhT3bxQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pbj8ZtwH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_udpZHkm9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WSycRcH3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uwy27Fe4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2K7bg1DA, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_fwGqfIVT);
  sEnv_free(&sEnv_5U3DdtSa);
  sEnv_free(&sEnv_lHYVRI4m);
  sEnv_free(&sEnv_SAW8rJVa);
  sEnv_free(&sEnv_hfb8Vmlq);
  sEnv_free(&sEnv_ePQ3NrNN);
  sEnv_free(&sEnv_gGYQkzT7);
  sEnv_free(&sEnv_OgLlV1RM);
  sEnv_free(&sEnv_PAicXAbZ);
  sEnv_free(&sEnv_ZiSQeIXD);
  sEnv_free(&sEnv_KdHqRHC6);
  sEnv_free(&sEnv_I2XQ3xr7);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LJwJhpce_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UhcmrRSm_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BmqkODx5_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YICwSjSu_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MCH9rAV1_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fUKGX24v_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7pDg0QHV_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hV2e27zh_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_miBBBF7D_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uVTrAmst_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IddVvtSB_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W6E4QHQO_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FIuddjoj_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aimLbmKi_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YsBTTITR_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_g5V82npg_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q1wFhD0s_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pZYoNJns_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AbeRlqnO_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bg2E6hot_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2F6vh6Gp_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ttp9x0xb_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OzfLAYZm_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_djYF8Qpb_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AgFpWaVj_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s6AEUeWt_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XZdv6egh_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gyo4guRc_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BYwnWfME_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tpTVrZEp_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GvSoWWm2_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G6bOvfkm_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eUuGSJP5_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3tI8XwSV_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pUGILzS3_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hkzNvrWn_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NaPTG91f_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nQPued1m_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8kKyuBTB_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WvhvEmgl_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Mypb7HuU_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qJJa2vsJ_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OJcrDhUd_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_po7AulnF_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qRxVtlNa_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jIyLfDSX_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KXFWF4p9_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mh5i2yIB_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qezK8EAj_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cfx63P0U_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P6zLP9TL_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GdyqTIqZ_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UYVGr75b_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s8UNzA4X_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PeZmQJGQ_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ip7RFQQ3_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7H99QTeX_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_unKbfqMe_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G4sCJGlt_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Mv9ARQQk_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SDf24oUT_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xZeAMAN3_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ONeVoWBL_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_753h6qnf_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C4JTyn9d_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ASvittRc_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZSQ6ciXo_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W4AKt57t_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2mPmhFpz_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q3ir8csx_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uDauMoqC_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nZoVS2CI_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jcgkfum5_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JfdUasy4_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BPLV0Rg0_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tyQxxXZ0_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NTTGZ7vc_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rsrY7WDX_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KTfGHUYh_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hN3eBD7G_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jh2iWba3_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rTuhpfA9_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DvNevAnj_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5RYxy0hu_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LH6njzcT_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Xo7au8FH_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HiCH4wKH_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xqXC57aC_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0Q5E17Tc_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_D6pz0zRc_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tkt9ZDz3_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AnjrXy6S_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C8pjt79n_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_lkDRB3zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3OGHN7gD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_u3CzAdqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i6zcGL1R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_aTbauSnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eLtKNQry_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_w7piIFlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CY1WPkkg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ShTOKDsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5I88WBU9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Veih56ng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iiYdL1fZ_sendMessage);
  cMsg_aPzYtAAl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_iiYdL1fZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Veih56ng, 1, m, &cVar_Veih56ng_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CbHGeD8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YdSJ2QU3_sendMessage(_c, 0, m);
  cMsg_PTB6TTGP_sendMessage(_c, 0, m);
  cMsg_P3r2k48C_sendMessage(_c, 0, m);
  cMsg_I83fhgIf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0v4LnZQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_961TeZ2h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0lTxK1Qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vqoAYv2u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_6nu1nRvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pm68mk61_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_hVJJcVIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mAaHVVfi_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_spY2f1Hu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZRvSvtKO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RVsRY7dF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ps4yfgAr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OpRnuCUY, 0, m, &cSlice_OpRnuCUY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_y0IYn0h2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_OpRnuCUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5uEndmB3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5uEndmB3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_xk72vv4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5uEndmB3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5uEndmB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Gyo4guRc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Pl9BVqQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uPjHg9uE_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_owYZSf8Z, 0, m, &cIf_owYZSf8Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_owYZSf8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qqcZ37aK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zZ4VqL1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_xVjCKMUo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_vaZvluke_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_yaFQnOr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_s4mF7vka, HV_BINOP_POW, 0, m, &cBinop_s4mF7vka_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s4mF7vka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DotJ93uc, 0, m, &cIf_DotJ93uc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_H4Q2umR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0046aFBl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FxnsGiNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zZ4VqL1w, 0, m, &cIf_zZ4VqL1w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3LSiRENf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zCxgqYvy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zCxgqYvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zZ4VqL1w, 1, m, &cIf_zZ4VqL1w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vaZvluke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_H4Q2umR4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xVjCKMUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DotJ93uc, 0, m, &cIf_DotJ93uc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0046aFBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s4mF7vka, HV_BINOP_POW, 1, m, &cBinop_s4mF7vka_sendMessage);
  cMsg_yaFQnOr4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_DotJ93uc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AwwAz6Pd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_uPjHg9uE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_owYZSf8Z, 1, m, &cIf_owYZSf8Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qqcZ37aK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b66DEuLe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e2AZISa2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VDPp7aXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3LSiRENf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FxnsGiNv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SkACZPiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DotJ93uc, 1, m, &cIf_DotJ93uc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1kIpwxNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ey9JmILC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ey9JmILC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_AwwAz6Pd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_r9nqD8gs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_VDPp7aXs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e2AZISa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SkACZPiQ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_SkACZPiQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b66DEuLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1kIpwxNK, HV_BINOP_EQ, 1, m, &cBinop_1kIpwxNK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CXOZX4JE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SkACZPiQ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_SkACZPiQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tID2iJ9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1kIpwxNK, HV_BINOP_EQ, 0, m, &cBinop_1kIpwxNK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kfaFe9xE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r9nqD8gs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_7weiVQ61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Pl9BVqQU, 0, m, &cVar_Pl9BVqQU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_yQTGe0qr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QuKmWl3V_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_o7t3SwLR, 0, m, &cIf_o7t3SwLR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_o7t3SwLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UJiTdb3h_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_M77WXrNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Vsjz60Fq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ePfWou9R_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_WamjOKBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_W7vJ83NW, HV_BINOP_POW, 0, m, &cBinop_W7vJ83NW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W7vJ83NW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n5dz31Ul, 0, m, &cIf_n5dz31Ul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kB7lyHri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ZIeiOn5e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WVDGPkQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M77WXrNG, 0, m, &cIf_M77WXrNG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a6Oq9iSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_i74wTKwT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i74wTKwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M77WXrNG, 1, m, &cIf_M77WXrNG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ePfWou9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_kB7lyHri_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vsjz60Fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_n5dz31Ul, 0, m, &cIf_n5dz31Ul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZIeiOn5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W7vJ83NW, HV_BINOP_POW, 1, m, &cBinop_W7vJ83NW_sendMessage);
  cMsg_WamjOKBa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_n5dz31Ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oS18l1su_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uMFIahdn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_QuKmWl3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o7t3SwLR, 1, m, &cIf_o7t3SwLR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UJiTdb3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cIhbDB38_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l25uz4BP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JgWseQgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a6Oq9iSK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WVDGPkQD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iWioxJgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n5dz31Ul, 1, m, &cIf_n5dz31Ul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0U8PezHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CrEB6x8Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CrEB6x8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oS18l1su_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uMFIahdn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w6P2oLXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_JgWseQgE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l25uz4BP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iWioxJgd, HV_BINOP_GREATER_THAN, 1, m, &cBinop_iWioxJgd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cIhbDB38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0U8PezHC, HV_BINOP_EQ, 1, m, &cBinop_0U8PezHC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JAJlqqng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0U8PezHC, HV_BINOP_EQ, 0, m, &cBinop_0U8PezHC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tkvmSR1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w6P2oLXh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_AIYHWR0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yQTGe0qr, 0, m, &cVar_yQTGe0qr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aV7gN6ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iWioxJgd, HV_BINOP_GREATER_THAN, 0, m, &cBinop_iWioxJgd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_JAqz8kRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OX30ErjJ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_1BTUepMo, 0, m, &cIf_1BTUepMo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_1BTUepMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fJJClKfa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EWax1nWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_B3NGuz1h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_UGLo27Lz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_BhhC4h44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_phwwV9ZC, HV_BINOP_POW, 0, m, &cBinop_phwwV9ZC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_phwwV9ZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6QjkTGu7, 0, m, &cIf_6QjkTGu7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kj3ZIqHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_LpUuX29g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eXFKm6ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EWax1nWu, 0, m, &cIf_EWax1nWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_khUVW7ly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HuNnlRm3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HuNnlRm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EWax1nWu, 1, m, &cIf_EWax1nWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UGLo27Lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_kj3ZIqHa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_B3NGuz1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_6QjkTGu7, 0, m, &cIf_6QjkTGu7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LpUuX29g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_phwwV9ZC, HV_BINOP_POW, 1, m, &cBinop_phwwV9ZC_sendMessage);
  cMsg_BhhC4h44_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_6QjkTGu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b28XpZ65_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_OX30ErjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1BTUepMo, 1, m, &cIf_1BTUepMo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fJJClKfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WWbrVMBM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ObWttMK6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sJMZMAXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_khUVW7ly_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eXFKm6ur_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rCBFqgQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6QjkTGu7, 1, m, &cIf_6QjkTGu7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UdmfyHZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l80GdCz4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_l80GdCz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_b28XpZ65_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bB7ErDeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_sJMZMAXg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ObWttMK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rCBFqgQY, HV_BINOP_GREATER_THAN, 1, m, &cBinop_rCBFqgQY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WWbrVMBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UdmfyHZX, HV_BINOP_EQ, 1, m, &cBinop_UdmfyHZX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FNh3I6tA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UdmfyHZX, HV_BINOP_EQ, 0, m, &cBinop_UdmfyHZX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_57MvdBca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bB7ErDeE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cAw7GUl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JAqz8kRJ, 0, m, &cVar_JAqz8kRJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GALiHuOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rCBFqgQY, HV_BINOP_GREATER_THAN, 0, m, &cBinop_rCBFqgQY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_M689YX86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wJ9EGM1u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zdJxsKPa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BNxdpZsp, 0, m, &cSlice_BNxdpZsp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7MkexNWH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_BNxdpZsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1v1P5mYg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1v1P5mYg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_JL4AfSmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1v1P5mYg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_1v1P5mYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_s6AEUeWt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7MkexNWH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KU2GlgjI, 0, m, &cSlice_KU2GlgjI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Ps4yfgAr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_KU2GlgjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jS5ztWOC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jS5ztWOC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_iaZxQvAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jS5ztWOC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jS5ztWOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tpTVrZEp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_y0IYn0h2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_i4ykLzbV, 0, m, &cSlice_i4ykLzbV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uDBYf96i_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_i4ykLzbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hm0rsyIv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hm0rsyIv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GIBK4S1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hm0rsyIv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hm0rsyIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XZdv6egh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uDBYf96i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XnQukGWe, 0, m, &cSlice_XnQukGWe_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XnQukGWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_D22YjLxF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_D22YjLxF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Ak3Yk9gO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_D22YjLxF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_D22YjLxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BYwnWfME_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5cu4Huep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nE7AjNBF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dWZ7K38o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4UNF87Lg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1l5HAI7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pSiBzevn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1syHy0ha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6yswAXw4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bqX3QKCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kI36Lwhv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jTfb5rvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CbbJth8d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_CbbJth8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PK3Q3Qha, HV_BINOP_DIVIDE, 1, m, &cBinop_PK3Q3Qha_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2pFs7yjm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_VPQBnMEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_kcvVI6lh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hwnGXtDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_VPQBnMEM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kcvVI6lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PK3Q3Qha, HV_BINOP_DIVIDE, 0, m, &cBinop_PK3Q3Qha_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2pFs7yjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hwnGXtDX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_PK3Q3Qha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i451Uszm, HV_BINOP_MULTIPLY, 1, m, &cBinop_i451Uszm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i451Uszm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GbYGMTT3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9r4JmUpa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_kQGgno4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_U05GjHUM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_6MH5l02F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GJBBOFa9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xngTB8e3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_LhHYVUoi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LhHYVUoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i451Uszm, HV_BINOP_MULTIPLY, 0, m, &cBinop_i451Uszm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JrKpfrtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_mJ31R3Kf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mJ31R3Kf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2N7x1R11_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NgcYkRYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a8mu7GsE, 1, m, &cVar_a8mu7GsE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_a8mu7GsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MLRbWcPC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ebtq2QBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XlxcAanX, HV_BINOP_MULTIPLY, 1, m, &cBinop_XlxcAanX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_12hsaxFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ebtq2QBM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MXvSBSs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_c5bb07ag_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c5bb07ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sVK0BsTR, HV_BINOP_MULTIPLY, 1, m, &cBinop_sVK0BsTR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q4MKBfAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JINmM0q2, HV_BINOP_MULTIPLY, 1, m, &cBinop_JINmM0q2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HKvVSvV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_q4MKBfAw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bnbc7TNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CDoViBc7, HV_BINOP_MULTIPLY, 1, m, &cBinop_CDoViBc7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JXqyQOCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_O5VcnE02_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O5VcnE02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2PVGrNSV, HV_BINOP_MULTIPLY, 1, m, &cBinop_2PVGrNSV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Fs4ctBVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zKtm0WIc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_xngTB8e3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KfeRRagA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_BkmLuNmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_JrKpfrtw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9r4JmUpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_6MH5l02F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GbYGMTT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_kQGgno4O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_U05GjHUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eUuGSJP5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GJBBOFa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_G6bOvfkm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_XeEg6FQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GvSoWWm2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2N7x1R11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_S9I4bIqT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S9I4bIqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vs40UCHC, HV_BINOP_MULTIPLY, 1, m, &cBinop_Vs40UCHC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vs40UCHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AJXMThRX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AJXMThRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XeEg6FQA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MLRbWcPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZG8dxmpt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZG8dxmpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0dwIKcCw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eegkkWa8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y7ftECF5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yy4cLv60_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LPhvmkwj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tDOYt6u5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XlxcAanX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5cu4Huep_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sVK0BsTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dWZ7K38o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_JINmM0q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1l5HAI7C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CDoViBc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1syHy0ha_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2PVGrNSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bqX3QKCP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_OepmAJZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fs4ctBVY, 0, m, &cVar_Fs4ctBVY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0ZqpOpY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BkmLuNmQ, 1, m, &cVar_BkmLuNmQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tDOYt6u5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XlxcAanX, HV_BINOP_MULTIPLY, 0, m, &cBinop_XlxcAanX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y7ftECF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CDoViBc7, HV_BINOP_MULTIPLY, 0, m, &cBinop_CDoViBc7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LPhvmkwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sVK0BsTR, HV_BINOP_MULTIPLY, 0, m, &cBinop_sVK0BsTR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eegkkWa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2PVGrNSV, HV_BINOP_MULTIPLY, 0, m, &cBinop_2PVGrNSV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yy4cLv60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JINmM0q2, HV_BINOP_MULTIPLY, 0, m, &cBinop_JINmM0q2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0dwIKcCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_KfeRRagA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a8mu7GsE, 0, m, &cVar_a8mu7GsE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zKtm0WIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BkmLuNmQ, 0, m, &cVar_BkmLuNmQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tI4JI97r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6NjXB5JD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9jnTMw0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lGs2WsUy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7uLPeAqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OQTrxbYY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MwZdBJIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YQRLwJkl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_H1B2UqwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VvtFDTeY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_VvtFDTeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_71ZkmEt7, HV_BINOP_DIVIDE, 1, m, &cBinop_71ZkmEt7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5d0HPIyE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_VumFoeBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_WmtGqNSx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C0ce2NAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_VumFoeBL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WmtGqNSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_71ZkmEt7, HV_BINOP_DIVIDE, 0, m, &cBinop_71ZkmEt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5d0HPIyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C0ce2NAQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_71ZkmEt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FGghuzlG, HV_BINOP_MULTIPLY, 1, m, &cBinop_FGghuzlG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FGghuzlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5YhYNs15_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fPL08w3V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_gKNlQpid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lCFwQEST_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_4Xj74cgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BNR0Qd6M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wI9kxEGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_uiNB6Gaz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uiNB6Gaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FGghuzlG, HV_BINOP_MULTIPLY, 0, m, &cBinop_FGghuzlG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m2AqA1wN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ShGfmjt6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ShGfmjt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p1J4Gsbo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NWPO0DuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ua1woN1a, HV_BINOP_MULTIPLY, 1, m, &cBinop_ua1woN1a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aBQAqoi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KBwLDcNm, 1, m, &cVar_KBwLDcNm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GNENqH0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5lE2tXZ7, HV_BINOP_MULTIPLY, 1, m, &cBinop_5lE2tXZ7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n2Zg4cx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rIY9yedV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rIY9yedV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J5Q1elVV, HV_BINOP_MULTIPLY, 1, m, &cBinop_J5Q1elVV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_KBwLDcNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v26Yz0oV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_LkwdWRNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OSUTD3Dm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wI9kxEGT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NipRjsxJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_RlOrQ5DJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_m2AqA1wN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fPL08w3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_4Xj74cgh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5YhYNs15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_gKNlQpid_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_lCFwQEST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hkzNvrWn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BNR0Qd6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pUGILzS3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ujpD8s9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3tI8XwSV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_p1J4Gsbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7Fsve8n6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7Fsve8n6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L1rRr30S, HV_BINOP_MULTIPLY, 1, m, &cBinop_L1rRr30S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L1rRr30S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_x475woA0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x475woA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ujpD8s9h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v26Yz0oV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EaLkd1iu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EaLkd1iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mYm3yi1o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s9JCoxRJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gkv2irbo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sdpriw3J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ArA8T6XR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tI4JI97r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ua1woN1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9jnTMw0b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5lE2tXZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7uLPeAqQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_J5Q1elVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MwZdBJIY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_nxzzrAi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RlOrQ5DJ, 1, m, &cVar_RlOrQ5DJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WKFb6lek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LkwdWRNS, 0, m, &cVar_LkwdWRNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OSUTD3Dm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RlOrQ5DJ, 0, m, &cVar_RlOrQ5DJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NipRjsxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KBwLDcNm, 0, m, &cVar_KBwLDcNm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s9JCoxRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5lE2tXZ7, HV_BINOP_MULTIPLY, 0, m, &cBinop_5lE2tXZ7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sdpriw3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ArA8T6XR, HV_BINOP_MULTIPLY, 0, m, &cBinop_ArA8T6XR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mYm3yi1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J5Q1elVV, HV_BINOP_MULTIPLY, 0, m, &cBinop_J5Q1elVV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Gkv2irbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ua1woN1a, HV_BINOP_MULTIPLY, 0, m, &cBinop_ua1woN1a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9PWOjHdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lQnuE2xa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ld1BTh5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3cvV9DNX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CJekJBwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Pj9ki11t, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iqVeEv1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7FDlxWkq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_I9leM2uM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rRjOaLSH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WN2PyMvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BmxMA9kE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_BmxMA9kE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y8pUCFql, HV_BINOP_DIVIDE, 1, m, &cBinop_Y8pUCFql_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TCl8MRLK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_duYkdk06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fTMi284U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W1A2Fd5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_duYkdk06_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fTMi284U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y8pUCFql, HV_BINOP_DIVIDE, 0, m, &cBinop_Y8pUCFql_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TCl8MRLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W1A2Fd5X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Y8pUCFql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31YGSeVe, HV_BINOP_MULTIPLY, 1, m, &cBinop_31YGSeVe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_31YGSeVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_06xHiFEh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jUuqmpFl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_qfjrLFZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dh4zeobO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_l2vEbl0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Lesd22vx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_pPAg9pNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_4eY3jIMD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4eY3jIMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31YGSeVe, HV_BINOP_MULTIPLY, 0, m, &cBinop_31YGSeVe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iHeWJm2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_wKzRjUaX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wKzRjUaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4XIXCVIc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vSIqR9DV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PPgEGWWn, HV_BINOP_MULTIPLY, 1, m, &cBinop_PPgEGWWn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xU4egnS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_98miQ92m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_98miQ92m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vSIqR9DV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hEno24NF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_S9dBvTmW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S9dBvTmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tt36sCuj, HV_BINOP_MULTIPLY, 1, m, &cBinop_Tt36sCuj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DaVCGwQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FCsNMGG7, HV_BINOP_MULTIPLY, 1, m, &cBinop_FCsNMGG7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K3w2xskc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3SiXrTNc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3SiXrTNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DaVCGwQ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_liMjGLYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jrlqIs3r, 1, m, &cVar_jrlqIs3r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TOTGI2o3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AcnqHDRZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_AcnqHDRZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Hk941o6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Sqlyq7ZS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Sqlyq7ZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EkR7F6bb, HV_BINOP_MULTIPLY, 1, m, &cBinop_EkR7F6bb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_jrlqIs3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pvXz9ttz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CqA03vsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8YQknVF3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_pPAg9pNC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_51qfJA09_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Q7l13FpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_iHeWJm2h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_06xHiFEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qfjrLFZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jUuqmpFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_l2vEbl0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_dh4zeobO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8kKyuBTB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Lesd22vx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nQPued1m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_keQpEXA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NaPTG91f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4XIXCVIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9mJaihMt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9mJaihMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6AHev5iw, HV_BINOP_MULTIPLY, 1, m, &cBinop_6AHev5iw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6AHev5iw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gJ490dWb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gJ490dWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_keQpEXA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pvXz9ttz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ThnxbyYa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ThnxbyYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TPaWLtzE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BzOLfomw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9eZ1m5Eg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SDZxs0fc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RkuWuF5u_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2dZYZDad_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PPgEGWWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9PWOjHdN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Tt36sCuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ld1BTh5z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_FCsNMGG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CJekJBwi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_AcnqHDRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iqVeEv1B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EkR7F6bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I9leM2uM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_pTFoVU05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CqA03vsI, 0, m, &cVar_CqA03vsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KSZc4HLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q7l13FpH, 1, m, &cVar_Q7l13FpH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2dZYZDad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PPgEGWWn, HV_BINOP_MULTIPLY, 0, m, &cBinop_PPgEGWWn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9eZ1m5Eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AcnqHDRZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_AcnqHDRZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RkuWuF5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tt36sCuj, HV_BINOP_MULTIPLY, 0, m, &cBinop_Tt36sCuj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BzOLfomw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EkR7F6bb, HV_BINOP_MULTIPLY, 0, m, &cBinop_EkR7F6bb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SDZxs0fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FCsNMGG7, HV_BINOP_MULTIPLY, 0, m, &cBinop_FCsNMGG7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TPaWLtzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_51qfJA09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jrlqIs3r, 0, m, &cVar_jrlqIs3r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8YQknVF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q7l13FpH, 0, m, &cVar_Q7l13FpH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_72faPyg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M689YX86, 1, m, &cIf_M689YX86_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jwrU2Xfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_wJ9EGM1u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_edmMogtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jwrU2Xfh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_gQhnkRal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M689YX86, 0, m, &cIf_M689YX86_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AwwAz6Pd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mh28VfHe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wJ9EGM1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XPWVQZIl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_b28XpZ65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a8OO1WPc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uMFIahdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_gQhnkRal_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oS18l1su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_72faPyg5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_edmMogtS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CAecwEtq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ix0SmyO0, 0, m, &cSlice_ix0SmyO0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VnIDo0ID_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ix0SmyO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pWlLVTfn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pWlLVTfn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_5aXuahu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pWlLVTfn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pWlLVTfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qJJa2vsJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CE8LVBsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zTq6NvwS_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_BV4kv144, 0, m, &cIf_BV4kv144_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_BV4kv144_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6YoDpCJ2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LtynPOBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WgjFGDqs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_LpFAEqYZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_1suFN8KN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QvAlrNGy, HV_BINOP_POW, 0, m, &cBinop_QvAlrNGy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QvAlrNGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iDT5Ugx1, 0, m, &cIf_iDT5Ugx1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SbiuPR4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_URSCLQQq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hZcmu5Fs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pjOTKltG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l3urniew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LtynPOBp, 0, m, &cIf_LtynPOBp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pjOTKltG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LtynPOBp, 1, m, &cIf_LtynPOBp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LpFAEqYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_SbiuPR4R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WgjFGDqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_iDT5Ugx1, 0, m, &cIf_iDT5Ugx1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_URSCLQQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QvAlrNGy, HV_BINOP_POW, 1, m, &cBinop_QvAlrNGy_sendMessage);
  cMsg_1suFN8KN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_iDT5Ugx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MhzwaPk2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_zTq6NvwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BV4kv144, 1, m, &cIf_BV4kv144_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6YoDpCJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5bPYEThk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w0Zev4XF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mNG8lI8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hZcmu5Fs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l3urniew_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vn3S6FAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iDT5Ugx1, 1, m, &cIf_iDT5Ugx1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Qcbsw0Fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zIGBVK7h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zIGBVK7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_MhzwaPk2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qZc1puBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_mNG8lI8w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5bPYEThk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qcbsw0Fy, HV_BINOP_EQ, 1, m, &cBinop_Qcbsw0Fy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w0Zev4XF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vn3S6FAR, HV_BINOP_GREATER_THAN, 1, m, &cBinop_vn3S6FAR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ePpAPEEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qcbsw0Fy, HV_BINOP_EQ, 0, m, &cBinop_Qcbsw0Fy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IIbylrNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qZc1puBY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_6hOUFyFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CE8LVBsg, 0, m, &cVar_CE8LVBsg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5aI34Nku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vn3S6FAR, HV_BINOP_GREATER_THAN, 0, m, &cBinop_vn3S6FAR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_joCiCLv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O6YIrhp9_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_dIq6LAwI, 0, m, &cIf_dIq6LAwI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_dIq6LAwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_i3Y2jOdi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hBro3PD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_l9Dq1QjS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_CfhQ30n3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_pgP6p8zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ykx2zRLx, HV_BINOP_POW, 0, m, &cBinop_ykx2zRLx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ykx2zRLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PHvg1LbA, 0, m, &cIf_PHvg1LbA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yxoL1Wgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_z0LO1Pp2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8KzsUmpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hBro3PD1, 0, m, &cIf_hBro3PD1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aoqqZdAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zOqmGqOc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zOqmGqOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hBro3PD1, 1, m, &cIf_hBro3PD1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CfhQ30n3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yxoL1Wgo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l9Dq1QjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_PHvg1LbA, 0, m, &cIf_PHvg1LbA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_z0LO1Pp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ykx2zRLx, HV_BINOP_POW, 1, m, &cBinop_ykx2zRLx_sendMessage);
  cMsg_pgP6p8zf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_PHvg1LbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QaJw03zH_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iYKkz2Ww_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_O6YIrhp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dIq6LAwI, 1, m, &cIf_dIq6LAwI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i3Y2jOdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GseTIjTg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_InwmGtQ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UD4aTVoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aoqqZdAY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8KzsUmpI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bb85VVS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PHvg1LbA, 1, m, &cIf_PHvg1LbA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WUdd9F2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JWnyDZq7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JWnyDZq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QaJw03zH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iYKkz2Ww_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M5nBAeBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_UD4aTVoV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_InwmGtQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bb85VVS8, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Bb85VVS8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GseTIjTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUdd9F2F, HV_BINOP_EQ, 1, m, &cBinop_WUdd9F2F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lWXGtgRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bb85VVS8, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Bb85VVS8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0tHDID7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUdd9F2F, HV_BINOP_EQ, 0, m, &cBinop_WUdd9F2F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IphzJyZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M5nBAeBX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_xkeEelMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_joCiCLv9, 0, m, &cVar_joCiCLv9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_6nIHGbXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_K7vjiW7J_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ovQU6i2C, 0, m, &cIf_ovQU6i2C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_ovQU6i2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FtnCnZvn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jI4WGK1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QEf1bcXS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uVidmbdD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_Ti4LAhQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_def7jWEM, HV_BINOP_POW, 0, m, &cBinop_def7jWEM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_def7jWEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w85ucKkY, 0, m, &cIf_w85ucKkY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_o8SnJJN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_BpuUruc4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dMQyzH9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_63K47uWe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EFYpvjt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jI4WGK1H, 0, m, &cIf_jI4WGK1H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_63K47uWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jI4WGK1H, 1, m, &cIf_jI4WGK1H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uVidmbdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_o8SnJJN5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QEf1bcXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_w85ucKkY, 0, m, &cIf_w85ucKkY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BpuUruc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_def7jWEM, HV_BINOP_POW, 1, m, &cBinop_def7jWEM_sendMessage);
  cMsg_Ti4LAhQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_w85ucKkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iTy9pe6d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_K7vjiW7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ovQU6i2C, 1, m, &cIf_ovQU6i2C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FtnCnZvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mybKMJPH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dochgj3N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SI9TOTd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dMQyzH9J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EFYpvjt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B6WuvEL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w85ucKkY, 1, m, &cIf_w85ucKkY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wYTpwf7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IsMoUNFT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IsMoUNFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_iTy9pe6d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_I0Gd2PqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_SI9TOTd6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Dochgj3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B6WuvEL7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_B6WuvEL7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mybKMJPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wYTpwf7H, HV_BINOP_EQ, 1, m, &cBinop_wYTpwf7H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jXvtqZVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I0Gd2PqD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XWvHweeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6nIHGbXi, 0, m, &cVar_6nIHGbXi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vDrRaeHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B6WuvEL7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_B6WuvEL7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B7HtuyLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wYTpwf7H, HV_BINOP_EQ, 0, m, &cBinop_wYTpwf7H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_4FZrC2rE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Yl59E52P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VeFlXUHv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AmRLpq0S, 0, m, &cSlice_AmRLpq0S_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oh6AMQ2p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_AmRLpq0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Mc1Hdg7Z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Mc1Hdg7Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PTPhYT7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Mc1Hdg7Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Mc1Hdg7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WvhvEmgl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oh6AMQ2p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8Z1fqS3Z, 0, m, &cSlice_8Z1fqS3Z_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CAecwEtq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_8Z1fqS3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_idI2tlYV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_idI2tlYV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_yh524koF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_idI2tlYV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_idI2tlYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_po7AulnF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VnIDo0ID_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hewqubBS, 0, m, &cSlice_hewqubBS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wjhdrYxX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_hewqubBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xQ3rmpiF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xQ3rmpiF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_m1N7CNDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xQ3rmpiF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xQ3rmpiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Mypb7HuU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wjhdrYxX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_m7DlJSF3, 0, m, &cSlice_m7DlJSF3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_m7DlJSF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7gEbDrfB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7gEbDrfB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Yv1S6gzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7gEbDrfB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7gEbDrfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OJcrDhUd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fEXlDHSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FkAbMukd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jO2ng8LM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ojzk8GYp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0wX3iltq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YlDfzkCJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cMR3W3iQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sz4mQDbV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Sb7i321U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WYAkRqn3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SQp3YkRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fzp5LfcS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_fzp5LfcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sme2pgZA, HV_BINOP_DIVIDE, 1, m, &cBinop_Sme2pgZA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_edI8DvMu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_AC0KeREd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Rp8ltQ0y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oIvv2eBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_AC0KeREd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Rp8ltQ0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sme2pgZA, HV_BINOP_DIVIDE, 0, m, &cBinop_Sme2pgZA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_edI8DvMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oIvv2eBM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Sme2pgZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4gHKnOyN, HV_BINOP_MULTIPLY, 1, m, &cBinop_4gHKnOyN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4gHKnOyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gFGdnO7F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YA9uB1Xu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_AgrBRdQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MEFPVx1L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_55vXPz1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qZ2kEKI4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dIcHzprE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_g8wQm680_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g8wQm680_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4gHKnOyN, HV_BINOP_MULTIPLY, 0, m, &cBinop_4gHKnOyN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EeSaZRvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_VZ11e1PZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VZ11e1PZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZPxZD2Kc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ZtkmZOmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Uaj3TLlN, 1, m, &cVar_Uaj3TLlN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Uaj3TLlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2jJThh7k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vDgSvT8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_70VMRexL, HV_BINOP_MULTIPLY, 1, m, &cBinop_70VMRexL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qNYoFTzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vDgSvT8d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ywfstRiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mRs4agV4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mRs4agV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UvMnqyUJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_UvMnqyUJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kRSM9i69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jzhoXwng, HV_BINOP_MULTIPLY, 1, m, &cBinop_jzhoXwng_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I8tz3447_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kRSM9i69_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9nZxUnFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3g3KDKuP, HV_BINOP_MULTIPLY, 1, m, &cBinop_3g3KDKuP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Iqw1nfJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ykY0ae9D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ykY0ae9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7suhxoqv, HV_BINOP_MULTIPLY, 1, m, &cBinop_7suhxoqv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Q0ffxxGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qCTRhuSA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_dIcHzprE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EjFbZs02_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Y80D5wKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_EeSaZRvW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gFGdnO7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_AgrBRdQB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YA9uB1Xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_55vXPz1a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_MEFPVx1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KXFWF4p9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_qZ2kEKI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jIyLfDSX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_uBz0qMFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qRxVtlNa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZPxZD2Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LAFfaiZ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LAFfaiZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rs2uYjdu, HV_BINOP_MULTIPLY, 1, m, &cBinop_rs2uYjdu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rs2uYjdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gGWywfuj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gGWywfuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uBz0qMFy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2jJThh7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_a9aRsFUA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a9aRsFUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Eu8wr2ay_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B93Se0J1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4Iw4Qrue_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ytD8ibng_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HR9570Zk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TcDS7T9P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_70VMRexL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fEXlDHSB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_UvMnqyUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jO2ng8LM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jzhoXwng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0wX3iltq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_3g3KDKuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cMR3W3iQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_7suhxoqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sb7i321U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_GzBdnKWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y80D5wKv, 1, m, &cVar_Y80D5wKv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YZhVZdPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q0ffxxGh, 0, m, &cVar_Q0ffxxGh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TcDS7T9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_70VMRexL, HV_BINOP_MULTIPLY, 0, m, &cBinop_70VMRexL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4Iw4Qrue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3g3KDKuP, HV_BINOP_MULTIPLY, 0, m, &cBinop_3g3KDKuP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HR9570Zk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UvMnqyUJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_UvMnqyUJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B93Se0J1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7suhxoqv, HV_BINOP_MULTIPLY, 0, m, &cBinop_7suhxoqv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ytD8ibng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jzhoXwng, HV_BINOP_MULTIPLY, 0, m, &cBinop_jzhoXwng_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Eu8wr2ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_EjFbZs02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Uaj3TLlN, 0, m, &cVar_Uaj3TLlN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qCTRhuSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y80D5wKv, 0, m, &cVar_Y80D5wKv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8PHDKXBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7kYo4OEA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iwjmfoZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qvv0LIfe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qNlOjcUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pdBTayuu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_h69tiZGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j03RQ7Gd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eoE5EaWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UcX2UxPp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_UcX2UxPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mwkP53oO, HV_BINOP_DIVIDE, 1, m, &cBinop_mwkP53oO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dD7bh885_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_raLL5G0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_QPdWQcbr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HqLCaX2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_raLL5G0f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QPdWQcbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mwkP53oO, HV_BINOP_DIVIDE, 0, m, &cBinop_mwkP53oO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dD7bh885_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HqLCaX2X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mwkP53oO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0SJE0s4X, HV_BINOP_MULTIPLY, 1, m, &cBinop_0SJE0s4X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0SJE0s4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sVjEBC8g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rdjdJeGP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_M1Rc1C4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gz4OKKqU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_7u9Y9qwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ynbUI9Xq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_VtiJqJgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_wt1qf1K7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wt1qf1K7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0SJE0s4X, HV_BINOP_MULTIPLY, 0, m, &cBinop_0SJE0s4X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i68btFJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_C9aqmLaM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C9aqmLaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DUZl6FoS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4sRYdz36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E9COFy7p, HV_BINOP_MULTIPLY, 1, m, &cBinop_E9COFy7p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6kFANchT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kqWGzasI, 1, m, &cVar_kqWGzasI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LZcHG9B4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GFLxS763, HV_BINOP_MULTIPLY, 1, m, &cBinop_GFLxS763_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7oyvTGYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_c3e9m362_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c3e9m362_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ebYb3eZ5, HV_BINOP_MULTIPLY, 1, m, &cBinop_ebYb3eZ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_kqWGzasI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sSpsj1V7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_2ziHN9MQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iyVW25kG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_VtiJqJgR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GOsJUsjT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_ZZZvZC9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_i68btFJM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rdjdJeGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_7u9Y9qwL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sVjEBC8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_M1Rc1C4b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_gz4OKKqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cfx63P0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ynbUI9Xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qezK8EAj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_uYOvhNMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mh5i2yIB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DUZl6FoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WU5hjEBA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WU5hjEBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AX6KlDYp, HV_BINOP_MULTIPLY, 1, m, &cBinop_AX6KlDYp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AX6KlDYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xrwyFxhy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xrwyFxhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uYOvhNMb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sSpsj1V7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qsyycRE9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qsyycRE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CnwgBxz8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2AU56AYe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zi8tLLdN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3j66Pos2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cs5ufY6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8PHDKXBv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_E9COFy7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iwjmfoZW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_GFLxS763_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qNlOjcUm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ebYb3eZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h69tiZGS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VS9IjQ7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZZZvZC9A, 1, m, &cVar_ZZZvZC9A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W81kNYDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2ziHN9MQ, 0, m, &cVar_2ziHN9MQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iyVW25kG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZZZvZC9A, 0, m, &cVar_ZZZvZC9A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GOsJUsjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kqWGzasI, 0, m, &cVar_kqWGzasI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Zi8tLLdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E9COFy7p, HV_BINOP_MULTIPLY, 0, m, &cBinop_E9COFy7p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2AU56AYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GFLxS763, HV_BINOP_MULTIPLY, 0, m, &cBinop_GFLxS763_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3j66Pos2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cs5ufY6S, HV_BINOP_MULTIPLY, 0, m, &cBinop_cs5ufY6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CnwgBxz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ebYb3eZ5, HV_BINOP_MULTIPLY, 0, m, &cBinop_ebYb3eZ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_33qdf1gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0VrYZ8xX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bAvCcV4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0UCuwmzK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SCps3jTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o0diF5nh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_leGJ4vXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cExuYMbZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Tj6n0d8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SEB7NTLU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tdtt4l3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xviCy0nH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_xviCy0nH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bu8lhzeV, HV_BINOP_DIVIDE, 1, m, &cBinop_bu8lhzeV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KWvgZxup_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_7tuT9DL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_QX6CQ6Vk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Dfs906Eu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_7tuT9DL2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QX6CQ6Vk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bu8lhzeV, HV_BINOP_DIVIDE, 0, m, &cBinop_bu8lhzeV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KWvgZxup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dfs906Eu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_bu8lhzeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KDHbuEfo, HV_BINOP_MULTIPLY, 1, m, &cBinop_KDHbuEfo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KDHbuEfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bDZZRBKA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vYAQOPhp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ygdEc8vA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uu3cl2Lb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_3wTQCklw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZyIKnxMI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_shuC1IXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ZSab0UnH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZSab0UnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KDHbuEfo, HV_BINOP_MULTIPLY, 0, m, &cBinop_KDHbuEfo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0paF4gkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_inahngMp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_inahngMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2mihiXkr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Lm9jbdzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cIvyDbQx, HV_BINOP_MULTIPLY, 1, m, &cBinop_cIvyDbQx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NmaGrRyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JZHOOEqc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JZHOOEqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Lm9jbdzq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g4npYFxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zMxsScVT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zMxsScVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eZ7iWZPz, HV_BINOP_MULTIPLY, 1, m, &cBinop_eZ7iWZPz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aLzAGyCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jb5NzQ86, HV_BINOP_MULTIPLY, 1, m, &cBinop_jb5NzQ86_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XAYbn9eF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_X6kb4ZC4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X6kb4ZC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_aLzAGyCP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wjgui00o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4CzvuzxV, 1, m, &cVar_4CzvuzxV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5MkaYQWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p0cm5H6c, HV_BINOP_MULTIPLY, 1, m, &cBinop_p0cm5H6c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C0jI4Zkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ajC7mcxy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ajC7mcxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yUzISQNe, HV_BINOP_MULTIPLY, 1, m, &cBinop_yUzISQNe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_4CzvuzxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bUAqtw9p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_tcuoHVQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ihdrScYv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_shuC1IXZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q0iUEVLw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_LocnkqR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_0paF4gkj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bDZZRBKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ygdEc8vA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vYAQOPhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3wTQCklw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_uu3cl2Lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UYVGr75b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ZyIKnxMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GdyqTIqZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_IRnjaUIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_P6zLP9TL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2mihiXkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pbBitvnT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pbBitvnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gIuHThIv, HV_BINOP_MULTIPLY, 1, m, &cBinop_gIuHThIv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gIuHThIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pLIQKzc9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pLIQKzc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IRnjaUIZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bUAqtw9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aRvUEaxi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aRvUEaxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WCXtZGNL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JSn9gPJq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EA0DSGdS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tYmBh5s7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XRGsX96o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_90pchmw1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cIvyDbQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_33qdf1gh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_eZ7iWZPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bAvCcV4M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jb5NzQ86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SCps3jTe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_p0cm5H6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_leGJ4vXo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_yUzISQNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tj6n0d8p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ZK0LOQxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tcuoHVQc, 0, m, &cVar_tcuoHVQc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fYvzBiOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LocnkqR6, 1, m, &cVar_LocnkqR6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_90pchmw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cIvyDbQx, HV_BINOP_MULTIPLY, 0, m, &cBinop_cIvyDbQx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EA0DSGdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p0cm5H6c, HV_BINOP_MULTIPLY, 0, m, &cBinop_p0cm5H6c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XRGsX96o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eZ7iWZPz, HV_BINOP_MULTIPLY, 0, m, &cBinop_eZ7iWZPz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JSn9gPJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yUzISQNe, HV_BINOP_MULTIPLY, 0, m, &cBinop_yUzISQNe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tYmBh5s7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jb5NzQ86, HV_BINOP_MULTIPLY, 0, m, &cBinop_jb5NzQ86_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WCXtZGNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_Q0iUEVLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4CzvuzxV, 0, m, &cVar_4CzvuzxV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ihdrScYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LocnkqR6, 0, m, &cVar_LocnkqR6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cQn4Yw0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4FZrC2rE, 1, m, &cIf_4FZrC2rE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5HRvYFWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Yl59E52P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_9nX6FWDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5HRvYFWs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0DT92zdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4FZrC2rE, 0, m, &cIf_4FZrC2rE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MhzwaPk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sXuBoD6c, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Yl59E52P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4WAnl3Hx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iTy9pe6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XHZgqOJ8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QaJw03zH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cQn4Yw0V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9nX6FWDb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iYKkz2Ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_0DT92zdp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_YsgiZALf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wNXWm0Do, HV_BINOP_DIVIDE, 0, m, &cBinop_wNXWm0Do_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_gBS4qxmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rqUMnYef, HV_BINOP_DIVIDE, 1, m, &cBinop_rqUMnYef_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wNXWm0Do, HV_BINOP_DIVIDE, 1, m, &cBinop_wNXWm0Do_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_TQMZV4Nf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7T2nfac4, HV_BINOP_DIVIDE, 0, m, &cBinop_7T2nfac4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_l8UJ8DI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7T2nfac4, HV_BINOP_DIVIDE, 1, m, &cBinop_7T2nfac4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZRvSvtKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YsgiZALf, 0, m, &cVar_YsgiZALf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_spY2f1Hu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gBS4qxmU, 0, m, &cVar_gBS4qxmU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RVsRY7dF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rqUMnYef, HV_BINOP_DIVIDE, 0, m, &cBinop_rqUMnYef_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rqUMnYef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_TQMZV4Nf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wNXWm0Do_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_l8UJ8DI8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7T2nfac4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_tzFdTs4w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_Sk4z1cnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_cTLygUFn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1MZjEHXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_GEfA8hJj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tzFdTs4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1MZjEHXU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GEfA8hJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_Sk4z1cnc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cTLygUFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2sXkj5jA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_23rFsCkl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Vut5fofs, 0, m, &cSlice_Vut5fofs_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Vut5fofs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UAw2hcgS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UAw2hcgS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_uH5fYp4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UAw2hcgS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UAw2hcgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_s8UNzA4X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CPDMDkBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OVE82qV0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OVE82qV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_a0dgJskB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a0dgJskB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_2Pd35woM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2Pd35woM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1k1pVB5g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W3QVyFjz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W3QVyFjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bd2E7WZx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_1k1pVB5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_o2Wj0iRL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_o2Wj0iRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0NPUH1m3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bd2E7WZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XerqOjba_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XerqOjba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ncKbwBYE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0NPUH1m3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xmIkvKoy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ncKbwBYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h2bec5wY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xmIkvKoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0gEf2msG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_h2bec5wY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8zXmj8rJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_m8SLno88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3o3uA3NK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_46D9htXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BGDmnKw4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_A9ZCvkyy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uzbiBwxA_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SzaGGoOS_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_72yMC47Y_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sAaLOzPq_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BWDLqobt_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1NsijzRO_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_uzbiBwxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_odhCdQxQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SzaGGoOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2s77bT2S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_72yMC47Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_If4gcrXe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_sAaLOzPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MkmpsW3W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_BWDLqobt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I2mOL0wj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_1NsijzRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eehOsBHb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_ENRfbzcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SjUsIbSY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xaMhMUZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Nzv5KhC4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_470MPABL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wfWIwPr5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wfWIwPr5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_42N864Ww, 1, m, &cDelay_42N864Ww_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NLmXmmLd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_42N864Ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_42N864Ww, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ENRfbzcC, 0, m, &cIf_ENRfbzcC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wfWIwPr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_42N864Ww, 0, m, &cDelay_42N864Ww_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NLmXmmLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_42N864Ww, 0, m, &cDelay_42N864Ww_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bFsdEkrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6oFR6cG3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tiM5I0AO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qk2iSG2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L7QcasxM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XiSyMR4f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L7QcasxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ENRfbzcC, 1, m, &cIf_ENRfbzcC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XiSyMR4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_470MPABL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6oFR6cG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xaMhMUZf, 1, m, &cIf_xaMhMUZf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tiM5I0AO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xaMhMUZf, 0, m, &cIf_xaMhMUZf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Nzv5KhC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hf7uJsuR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SjUsIbSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hf7uJsuR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ui15WaF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3SnNjrlj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WfEw0arC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zgJoLHc3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YN9vbIvH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DZ1G8jgD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DZ1G8jgD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_3uWk24qq, 1, m, &cDelay_3uWk24qq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CWu4u0Qh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_3uWk24qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3uWk24qq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ui15WaF7, 0, m, &cIf_Ui15WaF7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DZ1G8jgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3uWk24qq, 0, m, &cDelay_3uWk24qq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CWu4u0Qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3uWk24qq, 0, m, &cDelay_3uWk24qq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xVUoRy8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9peSAtRq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cfaKede4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sHxzHbQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PIEia09V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6X1HLYVQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6X1HLYVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YN9vbIvH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_PIEia09V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ui15WaF7, 1, m, &cIf_Ui15WaF7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9peSAtRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WfEw0arC, 1, m, &cIf_WfEw0arC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cfaKede4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WfEw0arC, 0, m, &cIf_WfEw0arC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zgJoLHc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OcFYbir4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3SnNjrlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OcFYbir4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oLQKYXcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8TPEOxuj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_TC3VtfDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qcKPeGjI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hTb295RL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JKy8o1W9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JKy8o1W9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WTnNWNGH, 1, m, &cDelay_WTnNWNGH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNjmEhwh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WTnNWNGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WTnNWNGH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oLQKYXcP, 0, m, &cIf_oLQKYXcP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JKy8o1W9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WTnNWNGH, 0, m, &cDelay_WTnNWNGH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oNjmEhwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WTnNWNGH, 0, m, &cDelay_WTnNWNGH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9D8rKqeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bT3Ca1i7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y817XjPc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ns626ISA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QIhonzxa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ev0SclHv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ev0SclHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hTb295RL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QIhonzxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oLQKYXcP, 1, m, &cIf_oLQKYXcP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y817XjPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TC3VtfDJ, 0, m, &cIf_TC3VtfDJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bT3Ca1i7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TC3VtfDJ, 1, m, &cIf_TC3VtfDJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qcKPeGjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_22f0CTUb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8TPEOxuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_22f0CTUb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_v2N2FwEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tFd00L8e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KSrTsvto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NrICCrnb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3s0V8SM0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zZrP2lqI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zZrP2lqI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nnj1l1Kf, 1, m, &cDelay_nnj1l1Kf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ye8G8rQS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nnj1l1Kf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nnj1l1Kf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_v2N2FwEZ, 0, m, &cIf_v2N2FwEZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zZrP2lqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nnj1l1Kf, 0, m, &cDelay_nnj1l1Kf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ye8G8rQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nnj1l1Kf, 0, m, &cDelay_nnj1l1Kf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Dtv2Ho74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0gclRQrd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F9j9z12z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Jd3X59mi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4odAtFat_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qnjlGlF7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qnjlGlF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3s0V8SM0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4odAtFat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v2N2FwEZ, 1, m, &cIf_v2N2FwEZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F9j9z12z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KSrTsvto, 0, m, &cIf_KSrTsvto_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0gclRQrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KSrTsvto, 1, m, &cIf_KSrTsvto_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NrICCrnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_w4V333nZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tFd00L8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_w4V333nZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qEgEX7GH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GFQSNrZ4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_P8mwR9pl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nswWdG7W_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TwCifoDY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BlYbMBzu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BlYbMBzu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jh3ZWr9K, 1, m, &cDelay_jh3ZWr9K_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tKp6iqLi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jh3ZWr9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jh3ZWr9K, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qEgEX7GH, 0, m, &cIf_qEgEX7GH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BlYbMBzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jh3ZWr9K, 0, m, &cDelay_jh3ZWr9K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tKp6iqLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jh3ZWr9K, 0, m, &cDelay_jh3ZWr9K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uTpXWpBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CF8diOO3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gzz9ywsj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UkT1RSpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LHlMjMuh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8zm7aIkd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LHlMjMuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qEgEX7GH, 1, m, &cIf_qEgEX7GH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8zm7aIkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TwCifoDY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Gzz9ywsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P8mwR9pl, 0, m, &cIf_P8mwR9pl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CF8diOO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P8mwR9pl, 1, m, &cIf_P8mwR9pl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nswWdG7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u1uZ7Cgr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GFQSNrZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u1uZ7Cgr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2HtWsrz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VdzYCjoq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6iEnGsis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tk7TPxIf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zZMVQaJ1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_79ryWdzM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_79ryWdzM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UHi0oo0q, 1, m, &cDelay_UHi0oo0q_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9IIdU2DL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UHi0oo0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UHi0oo0q, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2HtWsrz1, 0, m, &cIf_2HtWsrz1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_79ryWdzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UHi0oo0q, 0, m, &cDelay_UHi0oo0q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9IIdU2DL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UHi0oo0q, 0, m, &cDelay_UHi0oo0q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zaiGC74N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_navhjHfM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YCrbf71g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OLTQHs2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ezeq4Q3t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T9ZYccsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ezeq4Q3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2HtWsrz1, 1, m, &cIf_2HtWsrz1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T9ZYccsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zZMVQaJ1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_navhjHfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6iEnGsis, 1, m, &cIf_6iEnGsis_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YCrbf71g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6iEnGsis, 0, m, &cIf_6iEnGsis_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tk7TPxIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WIf99Y4b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VdzYCjoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WIf99Y4b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_wChrShYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_io7E8Ne2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fDNVtOl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EtMmYuj5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dBsKryNx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WbttS3Zr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WbttS3Zr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7s2o6dfO, 1, m, &cDelay_7s2o6dfO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ygNQDLWl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7s2o6dfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7s2o6dfO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wChrShYp, 0, m, &cIf_wChrShYp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WbttS3Zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7s2o6dfO, 0, m, &cDelay_7s2o6dfO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ygNQDLWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7s2o6dfO, 0, m, &cDelay_7s2o6dfO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YJQTEJMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aeTkp0Ux_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p5tD1hX2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y8iTr7FO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WMnkOhhJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_opM8LnF9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WMnkOhhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wChrShYp, 1, m, &cIf_wChrShYp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_opM8LnF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dBsKryNx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_aeTkp0Ux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fDNVtOl9, 1, m, &cIf_fDNVtOl9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p5tD1hX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fDNVtOl9, 0, m, &cIf_fDNVtOl9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EtMmYuj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yVUS7KP2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_io7E8Ne2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yVUS7KP2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_pDnLTxFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pMGlchQR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_eTP5nbZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IoWRJZEx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_V0EkNwFp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Y1SAGFHK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Y1SAGFHK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FSbkEOCQ, 1, m, &cDelay_FSbkEOCQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XvIzUe3m_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FSbkEOCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FSbkEOCQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pDnLTxFr, 0, m, &cIf_pDnLTxFr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y1SAGFHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FSbkEOCQ, 0, m, &cDelay_FSbkEOCQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XvIzUe3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FSbkEOCQ, 0, m, &cDelay_FSbkEOCQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OTjvpxWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7UPUH5d0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XR5hL7Dj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QMUI2rks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v2pbuNVC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ehcKm82l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ehcKm82l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_V0EkNwFp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_v2pbuNVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pDnLTxFr, 1, m, &cIf_pDnLTxFr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7UPUH5d0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eTP5nbZw, 1, m, &cIf_eTP5nbZw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XR5hL7Dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eTP5nbZw, 0, m, &cIf_eTP5nbZw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IoWRJZEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FTM5Ho5H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pMGlchQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FTM5Ho5H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oQ4SvZ3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LGbWOUnr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oZ28SxDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_99rmlBFO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EmcOF5xz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sKoa1JO8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sKoa1JO8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FSVSWrnQ, 1, m, &cDelay_FSVSWrnQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qjnlNB3P_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FSVSWrnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FSVSWrnQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oQ4SvZ3T, 0, m, &cIf_oQ4SvZ3T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sKoa1JO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FSVSWrnQ, 0, m, &cDelay_FSVSWrnQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qjnlNB3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FSVSWrnQ, 0, m, &cDelay_FSVSWrnQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HTsAGeC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W0ytd8jk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VilCJBnP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ihC6HfCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uiys4dxr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IWp4BCoo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IWp4BCoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EmcOF5xz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Uiys4dxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oQ4SvZ3T, 1, m, &cIf_oQ4SvZ3T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VilCJBnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oZ28SxDU, 0, m, &cIf_oZ28SxDU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W0ytd8jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oZ28SxDU, 1, m, &cIf_oZ28SxDU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_99rmlBFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nvbsDWTO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LGbWOUnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nvbsDWTO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ifkYq70I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8KKCRFJL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ehNQ57td_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5w4ztsdZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VXf20WAn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4PBOW7Lt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4PBOW7Lt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xM4H2uXX, 1, m, &cDelay_xM4H2uXX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eK0b2O7W_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xM4H2uXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xM4H2uXX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ifkYq70I, 0, m, &cIf_ifkYq70I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4PBOW7Lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xM4H2uXX, 0, m, &cDelay_xM4H2uXX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eK0b2O7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xM4H2uXX, 0, m, &cDelay_xM4H2uXX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7BkrkYJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EbWjq8ge_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gTJ44LSi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kq1ABmbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_35sx5tPF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1H4OFyOF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_35sx5tPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ifkYq70I, 1, m, &cIf_ifkYq70I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1H4OFyOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VXf20WAn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EbWjq8ge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ehNQ57td, 1, m, &cIf_ehNQ57td_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gTJ44LSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ehNQ57td, 0, m, &cIf_ehNQ57td_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5w4ztsdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K3G1bTwJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8KKCRFJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K3G1bTwJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Lg2gIrJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iWqjlGpR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wJpbNtI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_joPDQSYJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VcBXasYY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VVLz6CWt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VVLz6CWt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2T473vZ8, 1, m, &cDelay_2T473vZ8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7UqUbsDu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2T473vZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2T473vZ8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Lg2gIrJU, 0, m, &cIf_Lg2gIrJU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VVLz6CWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2T473vZ8, 0, m, &cDelay_2T473vZ8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7UqUbsDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2T473vZ8, 0, m, &cDelay_2T473vZ8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IYFF73My_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lbPOB7kN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sMRZr4tX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jKg1ouLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8CFsteEc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7wdTRj9Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8CFsteEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Lg2gIrJU, 1, m, &cIf_Lg2gIrJU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7wdTRj9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VcBXasYY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lbPOB7kN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wJpbNtI9, 1, m, &cIf_wJpbNtI9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sMRZr4tX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wJpbNtI9, 0, m, &cIf_wJpbNtI9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_joPDQSYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VbmMV1Iv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iWqjlGpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VbmMV1Iv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lEcaDMO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ks0CFoZb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8tbs0tyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_u74mkjGX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BuTr18AJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_swA6WFwz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_swA6WFwz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_LcDUXHm4, 1, m, &cDelay_LcDUXHm4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PyqVnUVB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_LcDUXHm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LcDUXHm4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lEcaDMO2, 0, m, &cIf_lEcaDMO2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_swA6WFwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LcDUXHm4, 0, m, &cDelay_LcDUXHm4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PyqVnUVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LcDUXHm4, 0, m, &cDelay_LcDUXHm4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sTghlYjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xo1NaT4j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WVH1Tyyb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ElGy93xS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ii0PRnO1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GVYypXjb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GVYypXjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BuTr18AJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Ii0PRnO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lEcaDMO2, 1, m, &cIf_lEcaDMO2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xo1NaT4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8tbs0tyJ, 1, m, &cIf_8tbs0tyJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WVH1Tyyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8tbs0tyJ, 0, m, &cIf_8tbs0tyJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u74mkjGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s8lLMveo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ks0CFoZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s8lLMveo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_odhCdQxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_NYzULeqE_sendMessage(_c, 0, m);
  cMsg_JmHHANnn_sendMessage(_c, 0, m);
  cMsg_112bUCd9_sendMessage(_c, 0, m);
  cMsg_1F213qKw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2s77bT2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_NYzULeqE_sendMessage(_c, 0, m);
  cMsg_tIPEQKx6_sendMessage(_c, 0, m);
  cMsg_9VlsNZFD_sendMessage(_c, 0, m);
  cMsg_KBftgKSn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_If4gcrXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_ZYLC1Yt0_sendMessage(_c, 0, m);
  cMsg_tIPEQKx6_sendMessage(_c, 0, m);
  cMsg_1F213qKw_sendMessage(_c, 0, m);
  cMsg_6BLknM73_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MkmpsW3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_ZYLC1Yt0_sendMessage(_c, 0, m);
  cMsg_Ze8KRRPv_sendMessage(_c, 0, m);
  cMsg_112bUCd9_sendMessage(_c, 0, m);
  cMsg_yx8Yeo8T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_I2mOL0wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_uhtYZrBf_sendMessage(_c, 0, m);
  cMsg_KBftgKSn_sendMessage(_c, 0, m);
  cMsg_Jm9KUOv8_sendMessage(_c, 0, m);
  cMsg_112bUCd9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eehOsBHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_uhtYZrBf_sendMessage(_c, 0, m);
  cMsg_yx8Yeo8T_sendMessage(_c, 0, m);
  cMsg_tIPEQKx6_sendMessage(_c, 0, m);
  cMsg_7QS9720F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UtijTojr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qk2iSG2H_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bFsdEkrD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uHoEPB7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qk2iSG2H_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bFsdEkrD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Txr28J46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sHxzHbQm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xVUoRy8T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C6exXaZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sHxzHbQm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xVUoRy8T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1pSy4IhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ns626ISA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9D8rKqeC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u1MOufb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ns626ISA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9D8rKqeC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NYzULeqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_UtijTojr_sendMessage(_c, 0, m);
  cMsg_C6exXaZL_sendMessage(_c, 0, m);
  cMsg_u1MOufb4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZYLC1Yt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_uHoEPB7U_sendMessage(_c, 0, m);
  cMsg_Txr28J46_sendMessage(_c, 0, m);
  cMsg_u1MOufb4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uhtYZrBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_uHoEPB7U_sendMessage(_c, 0, m);
  cMsg_C6exXaZL_sendMessage(_c, 0, m);
  cMsg_1pSy4IhJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SCBvTb5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Jd3X59mi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Dtv2Ho74_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6A1LTQAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Jd3X59mi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Dtv2Ho74_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_X8KjkuVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UkT1RSpH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uTpXWpBa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bb0ZO0ZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UkT1RSpH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uTpXWpBa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qLbjncoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OLTQHs2R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zaiGC74N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NJd035zV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OLTQHs2R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zaiGC74N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tIPEQKx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_6A1LTQAl_sendMessage(_c, 0, m);
  cMsg_bb0ZO0ZF_sendMessage(_c, 0, m);
  cMsg_NJd035zV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JmHHANnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_6A1LTQAl_sendMessage(_c, 0, m);
  cMsg_X8KjkuVp_sendMessage(_c, 0, m);
  cMsg_qLbjncoI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ze8KRRPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_SCBvTb5c_sendMessage(_c, 0, m);
  cMsg_bb0ZO0ZF_sendMessage(_c, 0, m);
  cMsg_qLbjncoI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WoOHvrqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kq1ABmbP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7BkrkYJx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XbzvjoyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kq1ABmbP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7BkrkYJx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ip14WcMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jKg1ouLj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IYFF73My_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nEmAJik3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jKg1ouLj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IYFF73My_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KkFFUy2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ElGy93xS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sTghlYjE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cixGd1Wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ElGy93xS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sTghlYjE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yx8Yeo8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_WoOHvrqH_sendMessage(_c, 0, m);
  cMsg_nEmAJik3_sendMessage(_c, 0, m);
  cMsg_cixGd1Wj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KBftgKSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_XbzvjoyX_sendMessage(_c, 0, m);
  cMsg_Ip14WcMv_sendMessage(_c, 0, m);
  cMsg_cixGd1Wj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1F213qKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_XbzvjoyX_sendMessage(_c, 0, m);
  cMsg_nEmAJik3_sendMessage(_c, 0, m);
  cMsg_KkFFUy2Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JIe4bbEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y8iTr7FO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YJQTEJMA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PLNcYirh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y8iTr7FO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YJQTEJMA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VO5KMPsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QMUI2rks_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OTjvpxWm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1I2SPKdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QMUI2rks_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OTjvpxWm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zssgT1vp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ihC6HfCf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HTsAGeC2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1y4TaV87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ihC6HfCf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HTsAGeC2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_112bUCd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_PLNcYirh_sendMessage(_c, 0, m);
  cMsg_1I2SPKdJ_sendMessage(_c, 0, m);
  cMsg_1y4TaV87_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9VlsNZFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_PLNcYirh_sendMessage(_c, 0, m);
  cMsg_VO5KMPsK_sendMessage(_c, 0, m);
  cMsg_zssgT1vp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7QS9720F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_JIe4bbEr_sendMessage(_c, 0, m);
  cMsg_VO5KMPsK_sendMessage(_c, 0, m);
  cMsg_1y4TaV87_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Jm9KUOv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_SCBvTb5c_sendMessage(_c, 0, m);
  cMsg_X8KjkuVp_sendMessage(_c, 0, m);
  cMsg_NJd035zV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6BLknM73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_JIe4bbEr_sendMessage(_c, 0, m);
  cMsg_1I2SPKdJ_sendMessage(_c, 0, m);
  cMsg_zssgT1vp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_1OYbK3Za_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6yl0B42U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xiWX5Vvm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EprLPIT6, 0, m, &cSlice_EprLPIT6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IVl27fIp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_EprLPIT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DLjNrfn5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DLjNrfn5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_n7KYF9IL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DLjNrfn5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_DLjNrfn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ip7RFQQ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xOMJeIsz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yOZtJkXt, 0, m, &cSlice_yOZtJkXt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Xpovicyf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_yOZtJkXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dZjg23zj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dZjg23zj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ybdGSvBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dZjg23zj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dZjg23zj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Mv9ARQQk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Xpovicyf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XFeeicXS, 0, m, &cSlice_XFeeicXS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xiWX5Vvm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XFeeicXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AafI6H01_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AafI6H01_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_wuZwyb6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AafI6H01_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AafI6H01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PeZmQJGQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IVl27fIp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pjWKRQ1x, 0, m, &cSlice_pjWKRQ1x_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5S0xs08G_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pjWKRQ1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_npGrFIu3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_npGrFIu3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_x6DxKn5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_npGrFIu3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_npGrFIu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_G4sCJGlt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5S0xs08G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_trUsCBHO, 0, m, &cSlice_trUsCBHO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4p8rFA02_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_trUsCBHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_98FMWTIG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_98FMWTIG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_zI0NMDlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_98FMWTIG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_98FMWTIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_unKbfqMe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wBR5OH0Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_D4SviuV2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_D4SviuV2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NS0vrtyW, 1, m, &cDelay_NS0vrtyW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zgecxTGG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NS0vrtyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NS0vrtyW, m);
  cMsg_DusTPL5E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_D4SviuV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NS0vrtyW, 0, m, &cDelay_NS0vrtyW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zgecxTGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NS0vrtyW, 0, m, &cDelay_NS0vrtyW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_NHJLYtzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c6Dl3AsG, HV_BINOP_SUBTRACT, 0, m, &cBinop_c6Dl3AsG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_dem37pPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_osAmJZvT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1vN01NHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_osAmJZvT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_fwGqfIVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NHJLYtzy, 0, m, &cVar_NHJLYtzy_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_5U3DdtSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sf0Z2gho_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6FS9ksBo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UBS60eVZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c6Dl3AsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dldGEUUW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dldGEUUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HqFFFX1u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HqFFFX1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Leugx4dd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uJpYuYMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bzGBkNqL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NNkDfGEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NNkDfGEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ti0Yl5Je_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bzGBkNqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dem37pPp, 1, m, &cIf_dem37pPp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_83BvyeXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1vN01NHK, 1, m, &cIf_1vN01NHK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ti0Yl5Je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_dem37pPp, 0, m, &cIf_dem37pPp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Leugx4dd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1vN01NHK, 0, m, &cIf_1vN01NHK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6FS9ksBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c6Dl3AsG, HV_BINOP_SUBTRACT, 1, m, &cBinop_c6Dl3AsG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sf0Z2gho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_UBS60eVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NHJLYtzy, 0, m, &cVar_NHJLYtzy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_osAmJZvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b2EMDQkb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4p8rFA02_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_S9zh4Rti, 0, m, &cSlice_S9zh4Rti_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_S9zh4Rti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zCuYQlu6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zCuYQlu6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_SBfnnluA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zCuYQlu6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zCuYQlu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7H99QTeX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3o3uA3NK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h7V4ONbK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BGDmnKw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9tLdTX4g, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_XYaA3gON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_46D9htXF, 0, m, &cVar_46D9htXF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6yl0B42U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7N1NZmff, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_izbhOh7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wBR5OH0Q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ToKr2Fvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ekWoOBPv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DusTPL5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gMba23mZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ekWoOBPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gMba23mZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_d8B71qEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_BoADRgKB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BoADRgKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RMgfphan_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RMgfphan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KW4ZiQVx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_shOFBqeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BwGrh6xp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_XNBeVI8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VKYfHfC1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LtyWJRwf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TxMP2Uqr_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QkVvzmI8_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_odULusCC_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9gSp4e0A_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_81ceEUyf_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HJg1X3rK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_TxMP2Uqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GqK5dFwy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QkVvzmI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hdWExk8J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_odULusCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GRah8IiW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_9gSp4e0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LwM9ni2x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_81ceEUyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Oi6u4PMJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_HJg1X3rK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LiIhQaVd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_3hP11Upg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TsQpTXhZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6vwZpG7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4WRQoSCR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pO8c8Nn9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CWu5Jfle_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CWu5Jfle_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_a6ZbhPfx, 1, m, &cDelay_a6ZbhPfx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jTYAv4QD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_a6ZbhPfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_a6ZbhPfx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3hP11Upg, 0, m, &cIf_3hP11Upg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CWu5Jfle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_a6ZbhPfx, 0, m, &cDelay_a6ZbhPfx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jTYAv4QD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_a6ZbhPfx, 0, m, &cDelay_a6ZbhPfx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9ekpceS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_58YRX3UA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dSINhMUk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5siiRB97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AjgLbYI4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CtDBfqH7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AjgLbYI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3hP11Upg, 1, m, &cIf_3hP11Upg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CtDBfqH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pO8c8Nn9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_58YRX3UA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6vwZpG7M, 1, m, &cIf_6vwZpG7M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dSINhMUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6vwZpG7M, 0, m, &cIf_6vwZpG7M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4WRQoSCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FeQ0d7CC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TsQpTXhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FeQ0d7CC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vaYcTgsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_foIVq5qt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oqNWBPmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HvPeBgAI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_75J43uuI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HLIsNB8u_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HLIsNB8u_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qgg6xE3F, 1, m, &cDelay_qgg6xE3F_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ieekvs9W_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qgg6xE3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qgg6xE3F, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vaYcTgsx, 0, m, &cIf_vaYcTgsx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HLIsNB8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qgg6xE3F, 0, m, &cDelay_qgg6xE3F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ieekvs9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qgg6xE3F, 0, m, &cDelay_qgg6xE3F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FtdAWeOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fL4ckDWq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wCxlnKum_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fjHMhWBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9V9AEOx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aLiqHaC0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aLiqHaC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_75J43uuI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_X9V9AEOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vaYcTgsx, 1, m, &cIf_vaYcTgsx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fL4ckDWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oqNWBPmM, 1, m, &cIf_oqNWBPmM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wCxlnKum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oqNWBPmM, 0, m, &cIf_oqNWBPmM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HvPeBgAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r7GBlQrH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_foIVq5qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r7GBlQrH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BTxolB12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6Mj3wxAJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_t89eZYNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QM9Cnz6W_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5e9dMHLa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vZthydN8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vZthydN8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hoJhBmWw, 1, m, &cDelay_hoJhBmWw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WuBqL8Xf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hoJhBmWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hoJhBmWw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BTxolB12, 0, m, &cIf_BTxolB12_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vZthydN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hoJhBmWw, 0, m, &cDelay_hoJhBmWw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WuBqL8Xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hoJhBmWw, 0, m, &cDelay_hoJhBmWw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9NrOlr8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FlWLTsEo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PyW7ztdK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_grdpuOXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fZ2Urg8p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NLSxT71B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NLSxT71B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5e9dMHLa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fZ2Urg8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BTxolB12, 1, m, &cIf_BTxolB12_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PyW7ztdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t89eZYNF, 0, m, &cIf_t89eZYNF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FlWLTsEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t89eZYNF, 1, m, &cIf_t89eZYNF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QM9Cnz6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Nnu0GRXB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6Mj3wxAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Nnu0GRXB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ucT8B5HJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VGofIKZQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_x8qKmdCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EIyY1Roj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5ODnSsvj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_K73brHCv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_K73brHCv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EjbT7bLq, 1, m, &cDelay_EjbT7bLq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_agx2lekJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EjbT7bLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EjbT7bLq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ucT8B5HJ, 0, m, &cIf_ucT8B5HJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K73brHCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EjbT7bLq, 0, m, &cDelay_EjbT7bLq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_agx2lekJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EjbT7bLq, 0, m, &cDelay_EjbT7bLq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CJzY0wIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PO10RSme_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s8IlrlGu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZerX65Yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_or7cBIKV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jTjODlYh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jTjODlYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5ODnSsvj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_or7cBIKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ucT8B5HJ, 1, m, &cIf_ucT8B5HJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s8IlrlGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x8qKmdCQ, 0, m, &cIf_x8qKmdCQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PO10RSme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x8qKmdCQ, 1, m, &cIf_x8qKmdCQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EIyY1Roj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WyNQ0yrz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VGofIKZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WyNQ0yrz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_1W57zkFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XxJOlRQ7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2q04qET3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JD6CsSxT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eW4fkYB3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ovq67Bgh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ovq67Bgh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KcTeduk3, 1, m, &cDelay_KcTeduk3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EWPRQuDQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KcTeduk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KcTeduk3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1W57zkFo, 0, m, &cIf_1W57zkFo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ovq67Bgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KcTeduk3, 0, m, &cDelay_KcTeduk3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EWPRQuDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KcTeduk3, 0, m, &cDelay_KcTeduk3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_82fp5joK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WR0L3Eb4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lDX50OSJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ox24hHsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gi7czZSa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AiIu1reS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AiIu1reS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eW4fkYB3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Gi7czZSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1W57zkFo, 1, m, &cIf_1W57zkFo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lDX50OSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2q04qET3, 0, m, &cIf_2q04qET3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WR0L3Eb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2q04qET3, 1, m, &cIf_2q04qET3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JD6CsSxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ss9tz3IV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XxJOlRQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ss9tz3IV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_S8ltXv6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KIjc6c4c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kq1yJVCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HrqPWAhJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0eeUdpwN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kFgEeW2q_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kFgEeW2q_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mSpWDjZG, 1, m, &cDelay_mSpWDjZG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ERiu2HeW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mSpWDjZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mSpWDjZG, m);
  cIf_onMessage(_c, &Context(_c)->cIf_S8ltXv6a, 0, m, &cIf_S8ltXv6a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kFgEeW2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mSpWDjZG, 0, m, &cDelay_mSpWDjZG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ERiu2HeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mSpWDjZG, 0, m, &cDelay_mSpWDjZG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T6VHxG9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_96HkAUQL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lzNpzOXV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GR0Nh0ZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fJob202j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e6Ek7KCP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e6Ek7KCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0eeUdpwN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fJob202j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S8ltXv6a, 1, m, &cIf_S8ltXv6a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lzNpzOXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kq1yJVCU, 0, m, &cIf_kq1yJVCU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_96HkAUQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kq1yJVCU, 1, m, &cIf_kq1yJVCU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HrqPWAhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JymyE2bo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KIjc6c4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JymyE2bo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_pkmnnfmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tnUChVhg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LuK1vUl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_v1gVYkNF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JvDeiwxP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mLNJg7C9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mLNJg7C9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_G3x6Kd8s, 1, m, &cDelay_G3x6Kd8s_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5bMNQW36_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_G3x6Kd8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_G3x6Kd8s, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pkmnnfmI, 0, m, &cIf_pkmnnfmI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mLNJg7C9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_G3x6Kd8s, 0, m, &cDelay_G3x6Kd8s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5bMNQW36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_G3x6Kd8s, 0, m, &cDelay_G3x6Kd8s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_906ifFBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vP2A0BIU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sxagMFkV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tuSaT8Af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0pH49Df7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uMwEEmt3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0pH49Df7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pkmnnfmI, 1, m, &cIf_pkmnnfmI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uMwEEmt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JvDeiwxP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sxagMFkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LuK1vUl4, 0, m, &cIf_LuK1vUl4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vP2A0BIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LuK1vUl4, 1, m, &cIf_LuK1vUl4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_v1gVYkNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tqg3A58Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tnUChVhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tqg3A58Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9POSNZey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yBwjpWz3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_nARlVr7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JqlBvLJq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YQplv49I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0gTQTQse_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0gTQTQse_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_J46bAXiS, 1, m, &cDelay_J46bAXiS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x7VG9TTC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_J46bAXiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_J46bAXiS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9POSNZey, 0, m, &cIf_9POSNZey_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0gTQTQse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_J46bAXiS, 0, m, &cDelay_J46bAXiS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x7VG9TTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_J46bAXiS, 0, m, &cDelay_J46bAXiS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PDfvBJCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9svFpa0k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QLWefOkT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GxWEQ9qI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TuIzf0hP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BiomAsfU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TuIzf0hP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9POSNZey, 1, m, &cIf_9POSNZey_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BiomAsfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YQplv49I_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QLWefOkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nARlVr7H, 0, m, &cIf_nARlVr7H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9svFpa0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nARlVr7H, 1, m, &cIf_nARlVr7H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JqlBvLJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wYhs9SzC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yBwjpWz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wYhs9SzC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GQkgkWVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_30KufuJa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qw83NmZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qUFydaqP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JwiUizoX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IBkWD7sg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IBkWD7sg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TqUpXgUP, 1, m, &cDelay_TqUpXgUP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q3jEsCo8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TqUpXgUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TqUpXgUP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GQkgkWVF, 0, m, &cIf_GQkgkWVF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IBkWD7sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TqUpXgUP, 0, m, &cDelay_TqUpXgUP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q3jEsCo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TqUpXgUP, 0, m, &cDelay_TqUpXgUP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AB0cY7lW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xE75i0qp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pAgnZJ8A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O9EO61ae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iVtmiNRW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6o8BzunQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6o8BzunQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JwiUizoX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_iVtmiNRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GQkgkWVF, 1, m, &cIf_GQkgkWVF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pAgnZJ8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qw83NmZM, 0, m, &cIf_qw83NmZM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xE75i0qp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qw83NmZM, 1, m, &cIf_qw83NmZM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qUFydaqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a8iMNjYU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_30KufuJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a8iMNjYU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7lewKYqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sfU0YHuc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CUL5inN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xgnp4fmq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_516KMLqd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pmKLV5rf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pmKLV5rf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XDbXsScX, 1, m, &cDelay_XDbXsScX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fLH9jxVj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XDbXsScX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XDbXsScX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7lewKYqK, 0, m, &cIf_7lewKYqK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pmKLV5rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XDbXsScX, 0, m, &cDelay_XDbXsScX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fLH9jxVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XDbXsScX, 0, m, &cDelay_XDbXsScX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2Cjy1Lud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jmfBVF1V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pSHAmwiq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K5tvBWKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vDPMrKIu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6rLSmI6O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6rLSmI6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_516KMLqd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vDPMrKIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7lewKYqK, 1, m, &cIf_7lewKYqK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pSHAmwiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CUL5inN7, 0, m, &cIf_CUL5inN7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jmfBVF1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CUL5inN7, 1, m, &cIf_CUL5inN7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xgnp4fmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TbwI4MRu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sfU0YHuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TbwI4MRu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OexvmljB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zE0qrMoD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HvaoTYss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fIM4d41X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_r4PMbnow_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_iphJh65l_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_iphJh65l_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wO7ZJUAt, 1, m, &cDelay_wO7ZJUAt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pLbrw7yH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wO7ZJUAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wO7ZJUAt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OexvmljB, 0, m, &cIf_OexvmljB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iphJh65l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wO7ZJUAt, 0, m, &cDelay_wO7ZJUAt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pLbrw7yH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wO7ZJUAt, 0, m, &cDelay_wO7ZJUAt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y0NWsFX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bZRFCA75_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AFPPw2mn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wt3UX2we_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u9gNO46V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pAVpeDKX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u9gNO46V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OexvmljB, 1, m, &cIf_OexvmljB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pAVpeDKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_r4PMbnow_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AFPPw2mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HvaoTYss, 0, m, &cIf_HvaoTYss_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bZRFCA75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HvaoTYss, 1, m, &cIf_HvaoTYss_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fIM4d41X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cEcqeAWd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zE0qrMoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cEcqeAWd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9JL18D1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UpYkPG8Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Ke3Zd936_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ox7LJkoN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9zZzqk7C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MWGdtCtc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MWGdtCtc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hZojEqi1, 1, m, &cDelay_hZojEqi1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_63IV3r9s_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hZojEqi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hZojEqi1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9JL18D1s, 0, m, &cIf_9JL18D1s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MWGdtCtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hZojEqi1, 0, m, &cDelay_hZojEqi1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_63IV3r9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hZojEqi1, 0, m, &cDelay_hZojEqi1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5hW0ywhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R1hfqONj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x5oOzkRk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Wo7zytrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HAAPnT6A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nmJHDKCl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HAAPnT6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9JL18D1s, 1, m, &cIf_9JL18D1s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nmJHDKCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9zZzqk7C_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_R1hfqONj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ke3Zd936, 1, m, &cIf_Ke3Zd936_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x5oOzkRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ke3Zd936, 0, m, &cIf_Ke3Zd936_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ox7LJkoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JfvwGcRz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UpYkPG8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JfvwGcRz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GqK5dFwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_c27Txnjn_sendMessage(_c, 0, m);
  cMsg_JhC1JRx2_sendMessage(_c, 0, m);
  cMsg_iwqEJvpi_sendMessage(_c, 0, m);
  cMsg_JoI2q66n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hdWExk8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_c27Txnjn_sendMessage(_c, 0, m);
  cMsg_i4Ltkr8M_sendMessage(_c, 0, m);
  cMsg_5By03e3i_sendMessage(_c, 0, m);
  cMsg_SqsqYk5U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GRah8IiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_3QVzmcIr_sendMessage(_c, 0, m);
  cMsg_i4Ltkr8M_sendMessage(_c, 0, m);
  cMsg_JoI2q66n_sendMessage(_c, 0, m);
  cMsg_1MnPHNz0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LwM9ni2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_3QVzmcIr_sendMessage(_c, 0, m);
  cMsg_eX8OCANk_sendMessage(_c, 0, m);
  cMsg_iwqEJvpi_sendMessage(_c, 0, m);
  cMsg_16qyng6K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Oi6u4PMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_CVIzcyL1_sendMessage(_c, 0, m);
  cMsg_SqsqYk5U_sendMessage(_c, 0, m);
  cMsg_fhqaWsMZ_sendMessage(_c, 0, m);
  cMsg_iwqEJvpi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LiIhQaVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_CVIzcyL1_sendMessage(_c, 0, m);
  cMsg_16qyng6K_sendMessage(_c, 0, m);
  cMsg_i4Ltkr8M_sendMessage(_c, 0, m);
  cMsg_siapZm3F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ef6tPYNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5siiRB97_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9ekpceS4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mqz6YI75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5siiRB97_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9ekpceS4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OnF7DK45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fjHMhWBe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FtdAWeOb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TS4uY4Mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fjHMhWBe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FtdAWeOb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ivTOQzBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_grdpuOXi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9NrOlr8X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ufYzZTIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_grdpuOXi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9NrOlr8X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_c27Txnjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Ef6tPYNU_sendMessage(_c, 0, m);
  cMsg_TS4uY4Mu_sendMessage(_c, 0, m);
  cMsg_ufYzZTIi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3QVzmcIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_mqz6YI75_sendMessage(_c, 0, m);
  cMsg_OnF7DK45_sendMessage(_c, 0, m);
  cMsg_ufYzZTIi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CVIzcyL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_mqz6YI75_sendMessage(_c, 0, m);
  cMsg_TS4uY4Mu_sendMessage(_c, 0, m);
  cMsg_ivTOQzBJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_matnWph3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZerX65Yz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CJzY0wIy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i9N3lyBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZerX65Yz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CJzY0wIy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JfWOaM8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ox24hHsQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_82fp5joK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XcWx6YB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ox24hHsQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_82fp5joK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H7aSLfyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GR0Nh0ZS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T6VHxG9C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Mq5kNYuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GR0Nh0ZS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T6VHxG9C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i4Ltkr8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_i9N3lyBa_sendMessage(_c, 0, m);
  cMsg_XcWx6YB7_sendMessage(_c, 0, m);
  cMsg_Mq5kNYuE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JhC1JRx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_i9N3lyBa_sendMessage(_c, 0, m);
  cMsg_JfWOaM8c_sendMessage(_c, 0, m);
  cMsg_H7aSLfyr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eX8OCANk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_matnWph3_sendMessage(_c, 0, m);
  cMsg_XcWx6YB7_sendMessage(_c, 0, m);
  cMsg_H7aSLfyr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DCBHnV18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_K5tvBWKm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2Cjy1Lud_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Mkh9VaDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_K5tvBWKm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2Cjy1Lud_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XK26vvsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wt3UX2we_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y0NWsFX4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kZJ7TR4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wt3UX2we_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y0NWsFX4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ywfcoBB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Wo7zytrh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5hW0ywhF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cp56wGS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Wo7zytrh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5hW0ywhF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_16qyng6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_DCBHnV18_sendMessage(_c, 0, m);
  cMsg_kZJ7TR4A_sendMessage(_c, 0, m);
  cMsg_cp56wGS6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SqsqYk5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Mkh9VaDQ_sendMessage(_c, 0, m);
  cMsg_XK26vvsp_sendMessage(_c, 0, m);
  cMsg_cp56wGS6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JoI2q66n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Mkh9VaDQ_sendMessage(_c, 0, m);
  cMsg_kZJ7TR4A_sendMessage(_c, 0, m);
  cMsg_ywfcoBB3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_L64tsqVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tuSaT8Af_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_906ifFBf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_25RhLbwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tuSaT8Af_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_906ifFBf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_70PChvsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GxWEQ9qI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PDfvBJCQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8ISdInJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GxWEQ9qI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PDfvBJCQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HO60sJhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O9EO61ae_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AB0cY7lW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZtJzStXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O9EO61ae_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AB0cY7lW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iwqEJvpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_25RhLbwt_sendMessage(_c, 0, m);
  cMsg_8ISdInJ1_sendMessage(_c, 0, m);
  cMsg_ZtJzStXE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5By03e3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_25RhLbwt_sendMessage(_c, 0, m);
  cMsg_70PChvsX_sendMessage(_c, 0, m);
  cMsg_HO60sJhS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_siapZm3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_L64tsqVQ_sendMessage(_c, 0, m);
  cMsg_70PChvsX_sendMessage(_c, 0, m);
  cMsg_ZtJzStXE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fhqaWsMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_matnWph3_sendMessage(_c, 0, m);
  cMsg_JfWOaM8c_sendMessage(_c, 0, m);
  cMsg_Mq5kNYuE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1MnPHNz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_L64tsqVQ_sendMessage(_c, 0, m);
  cMsg_8ISdInJ1_sendMessage(_c, 0, m);
  cMsg_HO60sJhS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_FtliNFI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NCtRavaG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qfAmbRbD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_S8byrhRF, 0, m, &cSlice_S8byrhRF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_x0DqVRhS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_S8byrhRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_v0iX32TJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_v0iX32TJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MY5hBtkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_v0iX32TJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_v0iX32TJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xZeAMAN3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PaUxfxvp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CfQ7cJ8K, 0, m, &cSlice_CfQ7cJ8K_sendMessage);
      break;
    }
    default: {
      cSwitchcase_enQaNjIp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_CfQ7cJ8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hxNUwYzq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hxNUwYzq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ccMTpCna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hxNUwYzq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hxNUwYzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ASvittRc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_enQaNjIp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LwXl8hF3, 0, m, &cSlice_LwXl8hF3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qfAmbRbD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_LwXl8hF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zsniDJjp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zsniDJjp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_WatKAlu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zsniDJjp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zsniDJjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SDf24oUT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_x0DqVRhS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pIHegnmh, 0, m, &cSlice_pIHegnmh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OViEvGDP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pIHegnmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lqLANZ6O_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lqLANZ6O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Wj5vm2nC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lqLANZ6O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lqLANZ6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_C4JTyn9d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OViEvGDP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6fNjqRTS, 0, m, &cSlice_6fNjqRTS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zqOyO80E_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_6fNjqRTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_d0lilZdK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_d0lilZdK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_f9YSoTfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_d0lilZdK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_d0lilZdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_753h6qnf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fQo1GJSV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hcKdu5df_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hcKdu5df_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WPIwmLDK, 1, m, &cDelay_WPIwmLDK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2qOUEzAn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WPIwmLDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WPIwmLDK, m);
  cMsg_koq5Ru9a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hcKdu5df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WPIwmLDK, 0, m, &cDelay_WPIwmLDK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2qOUEzAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WPIwmLDK, 0, m, &cDelay_WPIwmLDK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_oW8gJadb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J7wIIjl7, HV_BINOP_SUBTRACT, 0, m, &cBinop_J7wIIjl7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_rDEMtS0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CgAxsOZ0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IAjkotbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CgAxsOZ0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_lHYVRI4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oW8gJadb, 0, m, &cVar_oW8gJadb_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_SAW8rJVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HCZIGulF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qaRMUnRc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D3kzkG6r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J7wIIjl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_danKhBaN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_danKhBaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Gl2wTvSU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Gl2wTvSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_JAgvtL0C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Tr3VYK4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_grjOzz2a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g7voDYPK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_grjOzz2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rDEMtS0R, 1, m, &cIf_rDEMtS0R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g7voDYPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j1WvUxlL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_k4J0YubE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IAjkotbY, 1, m, &cIf_IAjkotbY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j1WvUxlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_rDEMtS0R, 0, m, &cIf_rDEMtS0R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JAgvtL0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IAjkotbY, 0, m, &cIf_IAjkotbY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HCZIGulF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_D3kzkG6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oW8gJadb, 0, m, &cVar_oW8gJadb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qaRMUnRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J7wIIjl7, HV_BINOP_SUBTRACT, 1, m, &cBinop_J7wIIjl7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CgAxsOZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nQmEoeQV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zqOyO80E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7ywk3WBO, 0, m, &cSlice_7ywk3WBO_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_7ywk3WBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yTlUstFK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yTlUstFK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_LJu62tvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yTlUstFK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yTlUstFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ONeVoWBL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BwGrh6xp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UuUPUjID, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VKYfHfC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VBQxtuB7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_NZu7zZ0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XNBeVI8C, 0, m, &cVar_XNBeVI8C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NCtRavaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ciVf8Gqy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sEBqAppb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fQo1GJSV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_qTWDddGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qoyPpzD5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_koq5Ru9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WYYBFtrE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qoyPpzD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WYYBFtrE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sx2f2hJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_oIVGBs0Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oIVGBs0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RcsC9Qww_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RcsC9Qww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xudbDZz3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_TnA6SR3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UMnYXFyN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_TSE1mEHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uRTLmBhe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_PLK4lUSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iThumyVb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_dsBqXxEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9MvGZD6l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_EJbP2V0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q2GsYkUu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_MwNIuobt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bBdyWdwJ_sendMessage);
  cMsg_Ym41T08m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_bBdyWdwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MwNIuobt, 1, m, &cVar_MwNIuobt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fibQb4Ci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oDjOTx0N_sendMessage(_c, 0, m);
  cMsg_SWaRCREO_sendMessage(_c, 0, m);
  cMsg_jxrvZcnO_sendMessage(_c, 0, m);
  cMsg_LerDHdM8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6417DITn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_k7JCErlU, 0, m, &cSlice_k7JCErlU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_k7JCErlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UZBd5nzz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UZBd5nzz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_0lKiyXb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UZBd5nzz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UZBd5nzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZSQ6ciXo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_6fxfeSV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_y0LDXnt2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y0LDXnt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_NcaoeNpH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NcaoeNpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mTl9Ojce_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mTl9Ojce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L3KwZBi4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qLUKLc92_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qLUKLc92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xioianeW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_L3KwZBi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JVzzpAXr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JVzzpAXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_X6MG2Xfc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xioianeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ROC0ilLn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ROC0ilLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UvBZzkZ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X6MG2Xfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qJCfwItf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_UvBZzkZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oxCxs40g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qJCfwItf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EYFFW5nI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oxCxs40g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bkdFRWLX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_oyEJN1qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S5lWfAY2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_hzNZeEZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4OtwGGdL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KeowFIH2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sb1ckwQH_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v0coUB17_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qCzZ7jPY_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6kDF91AI_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J20HTUbr_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BdDSpDe8_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_sb1ckwQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5cbONP3e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_v0coUB17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hq1POFVV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_qCzZ7jPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4fy9kX88_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_6kDF91AI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kDWvNqCw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_J20HTUbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DV4yAZxX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_BdDSpDe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hWcrNLRq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_ugcNlgw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9B0qILbM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_omEaLMbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VKG3GaDJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gYcuMQkd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4uJems9g_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4uJems9g_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OyPwS8uu, 1, m, &cDelay_OyPwS8uu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yS67yibB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OyPwS8uu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OyPwS8uu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ugcNlgw0, 0, m, &cIf_ugcNlgw0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4uJems9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OyPwS8uu, 0, m, &cDelay_OyPwS8uu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yS67yibB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OyPwS8uu, 0, m, &cDelay_OyPwS8uu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ykUwaLNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YmKGca2h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ghxIAoBs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i1DVBjMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zhMOl6Bu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_axvCqiJV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_axvCqiJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gYcuMQkd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zhMOl6Bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ugcNlgw0, 1, m, &cIf_ugcNlgw0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ghxIAoBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_omEaLMbq, 0, m, &cIf_omEaLMbq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YmKGca2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_omEaLMbq, 1, m, &cIf_omEaLMbq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VKG3GaDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IsLPGIHF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9B0qILbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IsLPGIHF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7lPvEgvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6wTHBbQp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_48gq9M0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8QeNPgbT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6RXCZtUr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QeFAYVEc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QeFAYVEc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_127ffocM, 1, m, &cDelay_127ffocM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yqj2VbCo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_127ffocM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_127ffocM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7lPvEgvp, 0, m, &cIf_7lPvEgvp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QeFAYVEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_127ffocM, 0, m, &cDelay_127ffocM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Yqj2VbCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_127ffocM, 0, m, &cDelay_127ffocM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_auOkI1lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KOEKoUxz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GltNT8nG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kQf3hBn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RdPZQNE7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2y7xfySM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2y7xfySM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6RXCZtUr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RdPZQNE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7lPvEgvp, 1, m, &cIf_7lPvEgvp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GltNT8nG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_48gq9M0Y, 0, m, &cIf_48gq9M0Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KOEKoUxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_48gq9M0Y, 1, m, &cIf_48gq9M0Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8QeNPgbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lWMMjkRr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6wTHBbQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lWMMjkRr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KIwAOamE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GifkKKti_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3TKUhQ9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SCaCFRO7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_epfMBd7K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_U4cQCTrY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_U4cQCTrY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_luLKUPmu, 1, m, &cDelay_luLKUPmu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HdBwA7zb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_luLKUPmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_luLKUPmu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KIwAOamE, 0, m, &cIf_KIwAOamE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U4cQCTrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_luLKUPmu, 0, m, &cDelay_luLKUPmu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HdBwA7zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_luLKUPmu, 0, m, &cDelay_luLKUPmu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NI1OA3eb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_76V05uLb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xqjM8mbg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3lz3FDgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FzP4LSHR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VPSLVPqU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VPSLVPqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_epfMBd7K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FzP4LSHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KIwAOamE, 1, m, &cIf_KIwAOamE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xqjM8mbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3TKUhQ9i, 0, m, &cIf_3TKUhQ9i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_76V05uLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3TKUhQ9i, 1, m, &cIf_3TKUhQ9i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SCaCFRO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ibcsJeSC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GifkKKti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ibcsJeSC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mNlST4g1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Fg7qucp0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_u40RboFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_w2kuK63e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qx9VodFS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HOg15a95_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HOg15a95_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KsNwWZKM, 1, m, &cDelay_KsNwWZKM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TKSfs1DS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KsNwWZKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KsNwWZKM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mNlST4g1, 0, m, &cIf_mNlST4g1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HOg15a95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KsNwWZKM, 0, m, &cDelay_KsNwWZKM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TKSfs1DS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KsNwWZKM, 0, m, &cDelay_KsNwWZKM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TsG16MFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_69NAAvw4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LmHNNyHG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HUWRE9Lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FqkWZR2F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Z6AnUBA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2Z6AnUBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qx9VodFS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FqkWZR2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mNlST4g1, 1, m, &cIf_mNlST4g1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LmHNNyHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_u40RboFW, 0, m, &cIf_u40RboFW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_69NAAvw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_u40RboFW, 1, m, &cIf_u40RboFW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w2kuK63e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5roj2S4H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Fg7qucp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5roj2S4H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_15AqQrOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Xz8qSAph_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oETmUffi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xW4N2ato_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hWotsqRF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gYlKO8cG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gYlKO8cG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6FdXwlVA, 1, m, &cDelay_6FdXwlVA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cF5D1CWM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6FdXwlVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6FdXwlVA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_15AqQrOJ, 0, m, &cIf_15AqQrOJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gYlKO8cG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6FdXwlVA, 0, m, &cDelay_6FdXwlVA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cF5D1CWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6FdXwlVA, 0, m, &cDelay_6FdXwlVA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kLNv3nuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RER54YH0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_60yHCEYG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hOziyTEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZC9BjWrV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ADkaIQ03_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ADkaIQ03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hWotsqRF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZC9BjWrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_15AqQrOJ, 1, m, &cIf_15AqQrOJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_60yHCEYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oETmUffi, 0, m, &cIf_oETmUffi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RER54YH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oETmUffi, 1, m, &cIf_oETmUffi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xW4N2ato_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8Generv3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Xz8qSAph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8Generv3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gfCqCp1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Y1sWpUZv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_y870Iiem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I1osUSHw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_izgsxbn5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SGaMlFMz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SGaMlFMz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0bypsYNK, 1, m, &cDelay_0bypsYNK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xDXdqiAC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0bypsYNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0bypsYNK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gfCqCp1i, 0, m, &cIf_gfCqCp1i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SGaMlFMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0bypsYNK, 0, m, &cDelay_0bypsYNK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xDXdqiAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0bypsYNK, 0, m, &cDelay_0bypsYNK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VHrTxuoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DzejJaU1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3laFlQOb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EIKgqDdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sOuGKHG4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jP2cCg9y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jP2cCg9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_izgsxbn5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sOuGKHG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gfCqCp1i, 1, m, &cIf_gfCqCp1i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3laFlQOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y870Iiem, 0, m, &cIf_y870Iiem_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DzejJaU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y870Iiem, 1, m, &cIf_y870Iiem_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I1osUSHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4AfD4soT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Y1sWpUZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4AfD4soT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ce9kyjRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DMEPCc7X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6JXpFIwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_86B1hoZs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DKPTFKR2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Phf0Y8rg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Phf0Y8rg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4wvPuvas, 1, m, &cDelay_4wvPuvas_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xtirCbMu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4wvPuvas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4wvPuvas, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ce9kyjRL, 0, m, &cIf_Ce9kyjRL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Phf0Y8rg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4wvPuvas, 0, m, &cDelay_4wvPuvas_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xtirCbMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4wvPuvas, 0, m, &cDelay_4wvPuvas_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IucMl5Dq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vGuZ0eW0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6aWAIvp8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XIWDy9z5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WyYQOITv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wRU9ZnDD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wRU9ZnDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DKPTFKR2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WyYQOITv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ce9kyjRL, 1, m, &cIf_Ce9kyjRL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6aWAIvp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6JXpFIwk, 0, m, &cIf_6JXpFIwk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vGuZ0eW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6JXpFIwk, 1, m, &cIf_6JXpFIwk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_86B1hoZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PDYyPNjp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DMEPCc7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PDYyPNjp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mfgw6FTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mpzAKQC7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JGM0nAsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vNWnjEEe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Iebugydh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nTyDabPn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nTyDabPn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0iNS9f3A, 1, m, &cDelay_0iNS9f3A_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5CzIpQaR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0iNS9f3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0iNS9f3A, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mfgw6FTz, 0, m, &cIf_mfgw6FTz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nTyDabPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0iNS9f3A, 0, m, &cDelay_0iNS9f3A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5CzIpQaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0iNS9f3A, 0, m, &cDelay_0iNS9f3A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GFzg74gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LH0z9Tru_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IksYuiVR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tB30wg3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D3BdrxYr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RhjmOLIx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D3BdrxYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mfgw6FTz, 1, m, &cIf_mfgw6FTz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RhjmOLIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Iebugydh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_IksYuiVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JGM0nAsl, 0, m, &cIf_JGM0nAsl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LH0z9Tru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JGM0nAsl, 1, m, &cIf_JGM0nAsl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vNWnjEEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jIN8rqyT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mpzAKQC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jIN8rqyT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GcvVHEXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RA8txbm1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9SxSsJpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QWcbiPi9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Tn7boB5A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_If64GGsr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_If64GGsr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fhh2TBGF, 1, m, &cDelay_fhh2TBGF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZDcVw3z2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fhh2TBGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fhh2TBGF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GcvVHEXf, 0, m, &cIf_GcvVHEXf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_If64GGsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fhh2TBGF, 0, m, &cDelay_fhh2TBGF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZDcVw3z2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fhh2TBGF, 0, m, &cDelay_fhh2TBGF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PCiXHGNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vwSQzLOc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DGf6ujX8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CO73ADVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q43bgubx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z8nrmRog_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q43bgubx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GcvVHEXf, 1, m, &cIf_GcvVHEXf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z8nrmRog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Tn7boB5A_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vwSQzLOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9SxSsJpp, 1, m, &cIf_9SxSsJpp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DGf6ujX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9SxSsJpp, 0, m, &cIf_9SxSsJpp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QWcbiPi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GtenbnZ0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RA8txbm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GtenbnZ0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Oq64UPWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mkKBhFQy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_iL8mKSYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_U7d4aaN6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pqxYaglQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ga61kC5r_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ga61kC5r_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vqoQR9aU, 1, m, &cDelay_vqoQR9aU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vUdpPSl5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vqoQR9aU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vqoQR9aU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Oq64UPWw, 0, m, &cIf_Oq64UPWw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ga61kC5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vqoQR9aU, 0, m, &cDelay_vqoQR9aU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vUdpPSl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vqoQR9aU, 0, m, &cDelay_vqoQR9aU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jak73AoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0mqojDMV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SB7zyE0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RGQhUQ9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ILrHMfdU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ypHnNF8f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ILrHMfdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Oq64UPWw, 1, m, &cIf_Oq64UPWw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ypHnNF8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pqxYaglQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0mqojDMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iL8mKSYH, 1, m, &cIf_iL8mKSYH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SB7zyE0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iL8mKSYH, 0, m, &cIf_iL8mKSYH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U7d4aaN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3qCUGByJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mkKBhFQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3qCUGByJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_iOKr0WJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6OY48D2Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_q55xwr9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NNzO3cwl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_P0hYjSIF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Zav67tdL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Zav67tdL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_msO8IkLk, 1, m, &cDelay_msO8IkLk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4T7SA8g2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_msO8IkLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_msO8IkLk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iOKr0WJT, 0, m, &cIf_iOKr0WJT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Zav67tdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_msO8IkLk, 0, m, &cDelay_msO8IkLk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4T7SA8g2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_msO8IkLk, 0, m, &cDelay_msO8IkLk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dP0yuBlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r03bQbAR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_By1KIGMm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j0CHAqyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M4V162tV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pYMbMWAD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pYMbMWAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_P0hYjSIF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_M4V162tV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iOKr0WJT, 1, m, &cIf_iOKr0WJT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_By1KIGMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q55xwr9B, 0, m, &cIf_q55xwr9B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r03bQbAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q55xwr9B, 1, m, &cIf_q55xwr9B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NNzO3cwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wbsevmSD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6OY48D2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wbsevmSD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Rsu5Xms7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xNsw17uC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_TBJhVeRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZU4g573u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eJuJoOia_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_l9PLTMBq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_l9PLTMBq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yAPGZHrK, 1, m, &cDelay_yAPGZHrK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GNY8MVKH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yAPGZHrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yAPGZHrK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Rsu5Xms7, 0, m, &cIf_Rsu5Xms7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l9PLTMBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yAPGZHrK, 0, m, &cDelay_yAPGZHrK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GNY8MVKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yAPGZHrK, 0, m, &cDelay_yAPGZHrK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cRddUEm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vHzH0Tvv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VFd7JuYL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zun7WDML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uMyy8WR2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4Bh0stuG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uMyy8WR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rsu5Xms7, 1, m, &cIf_Rsu5Xms7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4Bh0stuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eJuJoOia_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VFd7JuYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TBJhVeRQ, 0, m, &cIf_TBJhVeRQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vHzH0Tvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TBJhVeRQ, 1, m, &cIf_TBJhVeRQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZU4g573u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dBuEizqD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xNsw17uC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dBuEizqD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5cbONP3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_BdT48OcW_sendMessage(_c, 0, m);
  cMsg_UVW0FqrU_sendMessage(_c, 0, m);
  cMsg_5CBwVt4l_sendMessage(_c, 0, m);
  cMsg_bCAcElYP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hq1POFVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_BdT48OcW_sendMessage(_c, 0, m);
  cMsg_Dk1sKzkj_sendMessage(_c, 0, m);
  cMsg_R2AYInB8_sendMessage(_c, 0, m);
  cMsg_1gPLBTgp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4fy9kX88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_wwPPE6mR_sendMessage(_c, 0, m);
  cMsg_Dk1sKzkj_sendMessage(_c, 0, m);
  cMsg_bCAcElYP_sendMessage(_c, 0, m);
  cMsg_AvkSo8Ce_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kDWvNqCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_wwPPE6mR_sendMessage(_c, 0, m);
  cMsg_eDNA12xg_sendMessage(_c, 0, m);
  cMsg_5CBwVt4l_sendMessage(_c, 0, m);
  cMsg_a1UmEIBF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DV4yAZxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_EdqAzOWM_sendMessage(_c, 0, m);
  cMsg_1gPLBTgp_sendMessage(_c, 0, m);
  cMsg_YzqBvyIJ_sendMessage(_c, 0, m);
  cMsg_5CBwVt4l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hWcrNLRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_EdqAzOWM_sendMessage(_c, 0, m);
  cMsg_a1UmEIBF_sendMessage(_c, 0, m);
  cMsg_Dk1sKzkj_sendMessage(_c, 0, m);
  cMsg_kMem1VWF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eAyBLKwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i1DVBjMy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ykUwaLNN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PUhGi0JK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i1DVBjMy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ykUwaLNN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SQca9a2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kQf3hBn4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_auOkI1lx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lGNt76Iz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kQf3hBn4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_auOkI1lx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eVAqGk7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3lz3FDgm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NI1OA3eb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IyCBKsUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3lz3FDgm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NI1OA3eb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BdT48OcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_eAyBLKwS_sendMessage(_c, 0, m);
  cMsg_lGNt76Iz_sendMessage(_c, 0, m);
  cMsg_IyCBKsUp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wwPPE6mR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_PUhGi0JK_sendMessage(_c, 0, m);
  cMsg_SQca9a2M_sendMessage(_c, 0, m);
  cMsg_IyCBKsUp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EdqAzOWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_PUhGi0JK_sendMessage(_c, 0, m);
  cMsg_lGNt76Iz_sendMessage(_c, 0, m);
  cMsg_eVAqGk7C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SoGfgh5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HUWRE9Lo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TsG16MFJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SROh9Olf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HUWRE9Lo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TsG16MFJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UADtzI9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hOziyTEe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kLNv3nuO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VLksvTXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hOziyTEe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kLNv3nuO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DI7s7ApT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EIKgqDdb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VHrTxuoQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XkxUidUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EIKgqDdb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VHrTxuoQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Dk1sKzkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_SROh9Olf_sendMessage(_c, 0, m);
  cMsg_VLksvTXK_sendMessage(_c, 0, m);
  cMsg_XkxUidUP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UVW0FqrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_SROh9Olf_sendMessage(_c, 0, m);
  cMsg_UADtzI9X_sendMessage(_c, 0, m);
  cMsg_DI7s7ApT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eDNA12xg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_SoGfgh5t_sendMessage(_c, 0, m);
  cMsg_VLksvTXK_sendMessage(_c, 0, m);
  cMsg_DI7s7ApT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZqfguDlH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RGQhUQ9O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jak73AoO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r0whAV8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RGQhUQ9O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jak73AoO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EH0TpghG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_j0CHAqyv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dP0yuBlN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8UieQYi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_j0CHAqyv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dP0yuBlN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BZovUcP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zun7WDML_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cRddUEm2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BvwcEMfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zun7WDML_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cRddUEm2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a1UmEIBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_ZqfguDlH_sendMessage(_c, 0, m);
  cMsg_8UieQYi7_sendMessage(_c, 0, m);
  cMsg_BvwcEMfJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1gPLBTgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_r0whAV8j_sendMessage(_c, 0, m);
  cMsg_EH0TpghG_sendMessage(_c, 0, m);
  cMsg_BvwcEMfJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bCAcElYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_r0whAV8j_sendMessage(_c, 0, m);
  cMsg_8UieQYi7_sendMessage(_c, 0, m);
  cMsg_BZovUcP5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TVlsoP27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XIWDy9z5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IucMl5Dq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_koPo19QW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XIWDy9z5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IucMl5Dq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4Le8tgP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tB30wg3Z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GFzg74gp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EVFyKN5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tB30wg3Z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GFzg74gp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vj10jbXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CO73ADVT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PCiXHGNt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6MJrOc89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CO73ADVT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PCiXHGNt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5CBwVt4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_koPo19QW_sendMessage(_c, 0, m);
  cMsg_EVFyKN5f_sendMessage(_c, 0, m);
  cMsg_6MJrOc89_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_R2AYInB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_koPo19QW_sendMessage(_c, 0, m);
  cMsg_4Le8tgP3_sendMessage(_c, 0, m);
  cMsg_vj10jbXa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kMem1VWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_TVlsoP27_sendMessage(_c, 0, m);
  cMsg_4Le8tgP3_sendMessage(_c, 0, m);
  cMsg_6MJrOc89_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YzqBvyIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_SoGfgh5t_sendMessage(_c, 0, m);
  cMsg_UADtzI9X_sendMessage(_c, 0, m);
  cMsg_XkxUidUP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AvkSo8Ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_TVlsoP27_sendMessage(_c, 0, m);
  cMsg_EVFyKN5f_sendMessage(_c, 0, m);
  cMsg_vj10jbXa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_qNuRGDTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uRM15gwt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZYr3c2Mv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oCethXBV, 0, m, &cSlice_oCethXBV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IiqavCD5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_oCethXBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wGwhUkLR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wGwhUkLR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_0P7w5x46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wGwhUkLR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_wGwhUkLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2mPmhFpz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_j4LuSiTI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZbctTepV, 0, m, &cSlice_ZbctTepV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_713MV7JS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ZbctTepV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UwZNDmzg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UwZNDmzg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_K6JJShFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UwZNDmzg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UwZNDmzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jcgkfum5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_713MV7JS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0hoT3EYB, 0, m, &cSlice_0hoT3EYB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZYr3c2Mv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0hoT3EYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eFtuXyA2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eFtuXyA2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_VD7UypTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eFtuXyA2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_eFtuXyA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_W4AKt57t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IiqavCD5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mG6ACncl, 0, m, &cSlice_mG6ACncl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fz1Xj4ga_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_mG6ACncl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9ZDP33FJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9ZDP33FJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_XUf14VmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9ZDP33FJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9ZDP33FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nZoVS2CI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fz1Xj4ga_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_V5CO36n1, 0, m, &cSlice_V5CO36n1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZZAEBoLr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_V5CO36n1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eZrdo7fS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eZrdo7fS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_WLNkwKVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eZrdo7fS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_eZrdo7fS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uDauMoqC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HXIF4Tla_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_K1CZZhdh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_K1CZZhdh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rWRuMW7n, 1, m, &cDelay_rWRuMW7n_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6ILGVC1U_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rWRuMW7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rWRuMW7n, m);
  cMsg_XEAEsEbq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_K1CZZhdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rWRuMW7n, 0, m, &cDelay_rWRuMW7n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6ILGVC1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rWRuMW7n, 0, m, &cDelay_rWRuMW7n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_ZWzOjBCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cvpD0Ddn, HV_BINOP_SUBTRACT, 0, m, &cBinop_cvpD0Ddn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_LtEjdbcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zwTsb0WG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5ihWf6lM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zwTsb0WG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_hfb8Vmlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZWzOjBCv, 0, m, &cVar_ZWzOjBCv_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_ePQ3NrNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I9GyVAR0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Ib8eMgJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PC4fNN9G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cvpD0Ddn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lLK4VXB9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lLK4VXB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_j0G7FY98_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j0G7FY98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_t88FtpYj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M0msl7Mt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0QNW9idq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qUyS4KY3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qUyS4KY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_alRkT3N8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_0QNW9idq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LtEjdbcl, 1, m, &cIf_LtEjdbcl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YdqFgGxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5ihWf6lM, 1, m, &cIf_5ihWf6lM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_alRkT3N8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LtEjdbcl, 0, m, &cIf_LtEjdbcl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t88FtpYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5ihWf6lM, 0, m, &cIf_5ihWf6lM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PC4fNN9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZWzOjBCv, 0, m, &cVar_ZWzOjBCv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2Ib8eMgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cvpD0Ddn, HV_BINOP_SUBTRACT, 1, m, &cBinop_cvpD0Ddn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I9GyVAR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_zwTsb0WG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PXf2kXQi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZZAEBoLr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Bd0zlBUw, 0, m, &cSlice_Bd0zlBUw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Bd0zlBUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mKyeCkQ1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mKyeCkQ1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_1SmD67xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mKyeCkQ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mKyeCkQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_q3ir8csx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_S5lWfAY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vd7R4LVj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4OtwGGdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J5jhes6r, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_Gk5zNZyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hzNZeEZ9, 0, m, &cVar_hzNZeEZ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uRM15gwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n4IeAp4t, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ysRaFhJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HXIF4Tla_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZHZK8uBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a5rmcrbd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XEAEsEbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YcKNbGC1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_a5rmcrbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YcKNbGC1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Z76CQjhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_JRfgb7o4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JRfgb7o4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K3EjGm9i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_K3EjGm9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uPBtGs0y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_jLvvWjc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XbOOm4Ny_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_FZWMwe0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kjUIIpkw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_93fZbX0R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9iyaA10w_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkzYnowV_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VzgD8edp_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GHFQV7VY_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_igbkHunk_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zHyunBkL_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_9iyaA10w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y7FXCOdb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_nkzYnowV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GBiIf39Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VzgD8edp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_odVNlOp9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_GHFQV7VY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZiAsB7oC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_igbkHunk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EwOWicWE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zHyunBkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SxBqlUNt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_ogkRG2WS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_od66vJ7o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HRwV4H6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8dpvU9aR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0qTWK2W1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HzORnTal_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HzORnTal_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IBk48Ow2, 1, m, &cDelay_IBk48Ow2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YMJCA9F6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IBk48Ow2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IBk48Ow2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ogkRG2WS, 0, m, &cIf_ogkRG2WS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HzORnTal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IBk48Ow2, 0, m, &cDelay_IBk48Ow2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YMJCA9F6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IBk48Ow2, 0, m, &cDelay_IBk48Ow2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Lz8UJE23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZUamdcwR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_79c6hbtZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IAzIVABd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ujWBUcy8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bJP0iJb9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bJP0iJb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0qTWK2W1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ujWBUcy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ogkRG2WS, 1, m, &cIf_ogkRG2WS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZUamdcwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HRwV4H6Z, 1, m, &cIf_HRwV4H6Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_79c6hbtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HRwV4H6Z, 0, m, &cIf_HRwV4H6Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8dpvU9aR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JkOsyvuP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_od66vJ7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JkOsyvuP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_U8OktDf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zt7fcQak_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Wkc95PbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XcJOCx6J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jXppEaig_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_N48826vT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_N48826vT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oCGhhUYe, 1, m, &cDelay_oCGhhUYe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UCkelxVR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oCGhhUYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oCGhhUYe, m);
  cIf_onMessage(_c, &Context(_c)->cIf_U8OktDf2, 0, m, &cIf_U8OktDf2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N48826vT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oCGhhUYe, 0, m, &cDelay_oCGhhUYe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UCkelxVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oCGhhUYe, 0, m, &cDelay_oCGhhUYe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d370VBQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zKY4f5TT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9gyC7GOZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pNCmE35x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SszXvQSX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y6LgGTh9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y6LgGTh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jXppEaig_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SszXvQSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U8OktDf2, 1, m, &cIf_U8OktDf2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9gyC7GOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wkc95PbG, 0, m, &cIf_Wkc95PbG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zKY4f5TT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wkc95PbG, 1, m, &cIf_Wkc95PbG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XcJOCx6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bg5yvH5n, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zt7fcQak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bg5yvH5n, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6dng4avu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ga8wUG4z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_L1aABtrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_y2FmD27C_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TKQCOMGb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IoVwMj1Z_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IoVwMj1Z_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QGRtkO1H, 1, m, &cDelay_QGRtkO1H_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gr1kLjkE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_QGRtkO1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QGRtkO1H, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6dng4avu, 0, m, &cIf_6dng4avu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IoVwMj1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QGRtkO1H, 0, m, &cDelay_QGRtkO1H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Gr1kLjkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QGRtkO1H, 0, m, &cDelay_QGRtkO1H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EabAqkaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rwb6on8J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zYHG34OO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UlLYCWo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sACUfwgV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mgjReqIw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sACUfwgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6dng4avu, 1, m, &cIf_6dng4avu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mgjReqIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TKQCOMGb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rwb6on8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L1aABtrQ, 1, m, &cIf_L1aABtrQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zYHG34OO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L1aABtrQ, 0, m, &cIf_L1aABtrQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y2FmD27C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RRiamckx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ga8wUG4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RRiamckx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ndh3Jl6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EyBBTwM6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Mo77ZnNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_j5QPw2W0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vQXrrecw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KzkYeBGA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KzkYeBGA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Cb9CrlpH, 1, m, &cDelay_Cb9CrlpH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_45QTu2Ax_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Cb9CrlpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cb9CrlpH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ndh3Jl6S, 0, m, &cIf_Ndh3Jl6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KzkYeBGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cb9CrlpH, 0, m, &cDelay_Cb9CrlpH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_45QTu2Ax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cb9CrlpH, 0, m, &cDelay_Cb9CrlpH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V8tt9Qzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rr1S97Tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MErU9UNm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TeFr9x5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NXLd9mDe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7cudre60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NXLd9mDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ndh3Jl6S, 1, m, &cIf_Ndh3Jl6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7cudre60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vQXrrecw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Rr1S97Tq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mo77ZnNy, 1, m, &cIf_Mo77ZnNy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MErU9UNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mo77ZnNy, 0, m, &cIf_Mo77ZnNy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j5QPw2W0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_opzxbEXA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EyBBTwM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_opzxbEXA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Zdl7ljyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EeoNs7Xs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EVR3lyN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0AEVL9S8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HKZ7OW0x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Wd9Qcdpz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Wd9Qcdpz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NkbkbB9m, 1, m, &cDelay_NkbkbB9m_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hAps0JZl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NkbkbB9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NkbkbB9m, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Zdl7ljyr, 0, m, &cIf_Zdl7ljyr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wd9Qcdpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NkbkbB9m, 0, m, &cDelay_NkbkbB9m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hAps0JZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NkbkbB9m, 0, m, &cDelay_NkbkbB9m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cj46J2TZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tDAbNU8Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NK3WfITY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pSSXujFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TELK4RWl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CKFvmiJ8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CKFvmiJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HKZ7OW0x_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_TELK4RWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zdl7ljyr, 1, m, &cIf_Zdl7ljyr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tDAbNU8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EVR3lyN1, 1, m, &cIf_EVR3lyN1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NK3WfITY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EVR3lyN1, 0, m, &cIf_EVR3lyN1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0AEVL9S8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1Nge6qYn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EeoNs7Xs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1Nge6qYn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LjNOMeLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nF1vbdHV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hn3C2vpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Zgxa5LEQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xNIynTQ8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Jxtvwcxu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Jxtvwcxu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zC26uYy1, 1, m, &cDelay_zC26uYy1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BhWthzws_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zC26uYy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zC26uYy1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LjNOMeLd, 0, m, &cIf_LjNOMeLd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Jxtvwcxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zC26uYy1, 0, m, &cDelay_zC26uYy1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BhWthzws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zC26uYy1, 0, m, &cDelay_zC26uYy1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EzU83PH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bRTqdmlF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oZGR7UGO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2c0frrYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HHLqQ8an_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gq7vzGQr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Gq7vzGQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xNIynTQ8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HHLqQ8an_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LjNOMeLd, 1, m, &cIf_LjNOMeLd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oZGR7UGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hn3C2vpj, 0, m, &cIf_hn3C2vpj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bRTqdmlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hn3C2vpj, 1, m, &cIf_hn3C2vpj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Zgxa5LEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vE4LH36i, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nF1vbdHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vE4LH36i, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_11FZQThS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0cjgJnC5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lAXbFng0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5QFR28Yn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_K3kr0rZX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4wAZIo6f_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4wAZIo6f_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_F4mNksB9, 1, m, &cDelay_F4mNksB9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YUzJDbw3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_F4mNksB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_F4mNksB9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_11FZQThS, 0, m, &cIf_11FZQThS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4wAZIo6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_F4mNksB9, 0, m, &cDelay_F4mNksB9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YUzJDbw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_F4mNksB9, 0, m, &cDelay_F4mNksB9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0cGba7hh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2wNlx4IE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xVC2tuUJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_80KRLXo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SVDTBfcA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fxdIQq7N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fxdIQq7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_K3kr0rZX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SVDTBfcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_11FZQThS, 1, m, &cIf_11FZQThS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xVC2tuUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lAXbFng0, 0, m, &cIf_lAXbFng0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2wNlx4IE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lAXbFng0, 1, m, &cIf_lAXbFng0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5QFR28Yn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4U8Kwxfx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0cjgJnC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4U8Kwxfx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vlvDfylu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ENjZs9FP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RGIrLcOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JIVcwtyL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NKqznmFX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7WSxnIam_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7WSxnIam_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JZjSwKTl, 1, m, &cDelay_JZjSwKTl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xepP0jK9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JZjSwKTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JZjSwKTl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vlvDfylu, 0, m, &cIf_vlvDfylu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7WSxnIam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JZjSwKTl, 0, m, &cDelay_JZjSwKTl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xepP0jK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JZjSwKTl, 0, m, &cDelay_JZjSwKTl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m0DZKFf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3B54Pnqk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eur87pG8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VPqPBY60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VJAx50YC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VD4SriJ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VD4SriJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NKqznmFX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VJAx50YC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vlvDfylu, 1, m, &cIf_vlvDfylu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eur87pG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RGIrLcOT, 0, m, &cIf_RGIrLcOT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3B54Pnqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RGIrLcOT, 1, m, &cIf_RGIrLcOT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JIVcwtyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xlOegA6O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ENjZs9FP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xlOegA6O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_deHFdqNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ygTVkJJd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Frf3Hve0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lDsd5H6l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3ZjnsabQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4r9nVj7W_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4r9nVj7W_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_k1Mppwyz, 1, m, &cDelay_k1Mppwyz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BSLuAS4o_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_k1Mppwyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_k1Mppwyz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_deHFdqNr, 0, m, &cIf_deHFdqNr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4r9nVj7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_k1Mppwyz, 0, m, &cDelay_k1Mppwyz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BSLuAS4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_k1Mppwyz, 0, m, &cDelay_k1Mppwyz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mFSL5sn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BrJeyFFi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rOvoFQpU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vo0DXpe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Es8ej4Hd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N9OMCsSP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N9OMCsSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3ZjnsabQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Es8ej4Hd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_deHFdqNr, 1, m, &cIf_deHFdqNr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BrJeyFFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Frf3Hve0, 1, m, &cIf_Frf3Hve0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rOvoFQpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Frf3Hve0, 0, m, &cIf_Frf3Hve0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lDsd5H6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zH77K0S2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ygTVkJJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zH77K0S2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RKFz05RX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eMIN1UT7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KUDfVX5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gYun8h9q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_clGuwx6L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_iX9BscpR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_iX9BscpR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6akhOx5e, 1, m, &cDelay_6akhOx5e_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YwpGVeSx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6akhOx5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6akhOx5e, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RKFz05RX, 0, m, &cIf_RKFz05RX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iX9BscpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6akhOx5e, 0, m, &cDelay_6akhOx5e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YwpGVeSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6akhOx5e, 0, m, &cDelay_6akhOx5e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dTEJPH1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2CGanr7b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hixRrIvH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O7BBtCG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oC3m6tpe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PkVEgGmT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PkVEgGmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_clGuwx6L_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oC3m6tpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RKFz05RX, 1, m, &cIf_RKFz05RX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hixRrIvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KUDfVX5h, 0, m, &cIf_KUDfVX5h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2CGanr7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KUDfVX5h, 1, m, &cIf_KUDfVX5h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gYun8h9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3DCXxmJd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eMIN1UT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3DCXxmJd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OUdsjLMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Tfzha0Mw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wKwufeBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qBut6JWD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wXwpawBS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_k55rDQJK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_k55rDQJK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Jhe9YFpN, 1, m, &cDelay_Jhe9YFpN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O5p9XG7Y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Jhe9YFpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Jhe9YFpN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OUdsjLMW, 0, m, &cIf_OUdsjLMW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k55rDQJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Jhe9YFpN, 0, m, &cDelay_Jhe9YFpN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O5p9XG7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Jhe9YFpN, 0, m, &cDelay_Jhe9YFpN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RUpIbY5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TDES6Mz8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TOWznFh7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MAiedsfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RbRdbXRf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fY4HulTf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fY4HulTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wXwpawBS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RbRdbXRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OUdsjLMW, 1, m, &cIf_OUdsjLMW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TOWznFh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wKwufeBE, 0, m, &cIf_wKwufeBE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TDES6Mz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wKwufeBE, 1, m, &cIf_wKwufeBE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qBut6JWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wtx2Sxvu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Tfzha0Mw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wtx2Sxvu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GBIfOTZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oZvP7fEJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NXLVBC0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eMejDOYz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wZqmqmW5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QiCarZDi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QiCarZDi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ajtykbrK, 1, m, &cDelay_ajtykbrK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TKOO6W5n_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ajtykbrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ajtykbrK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GBIfOTZJ, 0, m, &cIf_GBIfOTZJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QiCarZDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ajtykbrK, 0, m, &cDelay_ajtykbrK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TKOO6W5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ajtykbrK, 0, m, &cDelay_ajtykbrK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bTUgAAkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mf0M3Xg9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CYn7JKdx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rW8vxfxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s0HhxjGT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HIigSk4y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HIigSk4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wZqmqmW5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_s0HhxjGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GBIfOTZJ, 1, m, &cIf_GBIfOTZJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CYn7JKdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NXLVBC0u, 0, m, &cIf_NXLVBC0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mf0M3Xg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NXLVBC0u, 1, m, &cIf_NXLVBC0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eMejDOYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xSAGery4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oZvP7fEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xSAGery4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_y7FXCOdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_SB5XOkd2_sendMessage(_c, 0, m);
  cMsg_8XL0U2Ct_sendMessage(_c, 0, m);
  cMsg_a46ljPmk_sendMessage(_c, 0, m);
  cMsg_nzEez2PF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GBiIf39Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_SB5XOkd2_sendMessage(_c, 0, m);
  cMsg_b1Azazin_sendMessage(_c, 0, m);
  cMsg_J1KtumEE_sendMessage(_c, 0, m);
  cMsg_RLqVg8i9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_odVNlOp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_ys3cE0ZC_sendMessage(_c, 0, m);
  cMsg_b1Azazin_sendMessage(_c, 0, m);
  cMsg_nzEez2PF_sendMessage(_c, 0, m);
  cMsg_miJUbGCj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZiAsB7oC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_ys3cE0ZC_sendMessage(_c, 0, m);
  cMsg_rTgDJSnf_sendMessage(_c, 0, m);
  cMsg_a46ljPmk_sendMessage(_c, 0, m);
  cMsg_66L41fZR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EwOWicWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_jGsgAqZ1_sendMessage(_c, 0, m);
  cMsg_RLqVg8i9_sendMessage(_c, 0, m);
  cMsg_85MzrRLC_sendMessage(_c, 0, m);
  cMsg_a46ljPmk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SxBqlUNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_jGsgAqZ1_sendMessage(_c, 0, m);
  cMsg_66L41fZR_sendMessage(_c, 0, m);
  cMsg_b1Azazin_sendMessage(_c, 0, m);
  cMsg_Y3BVXn3J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nP02KqMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IAzIVABd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Lz8UJE23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HWECkIwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IAzIVABd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Lz8UJE23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7SkhYJw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pNCmE35x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d370VBQ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pVTVgiyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pNCmE35x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d370VBQ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mA99nuUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UlLYCWo0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EabAqkaY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mKTFPsNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UlLYCWo0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EabAqkaY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SB5XOkd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_nP02KqMW_sendMessage(_c, 0, m);
  cMsg_pVTVgiyO_sendMessage(_c, 0, m);
  cMsg_mKTFPsNq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ys3cE0ZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_HWECkIwj_sendMessage(_c, 0, m);
  cMsg_7SkhYJw7_sendMessage(_c, 0, m);
  cMsg_mKTFPsNq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jGsgAqZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_HWECkIwj_sendMessage(_c, 0, m);
  cMsg_pVTVgiyO_sendMessage(_c, 0, m);
  cMsg_mA99nuUb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Itzee6IN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TeFr9x5M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_V8tt9Qzv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pWD5EHem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TeFr9x5M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_V8tt9Qzv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_t86rrpJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pSSXujFv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cj46J2TZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TmaFwnhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pSSXujFv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cj46J2TZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1AIG1D5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2c0frrYA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EzU83PH7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n4AsSdg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2c0frrYA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EzU83PH7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b1Azazin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_pWD5EHem_sendMessage(_c, 0, m);
  cMsg_TmaFwnhl_sendMessage(_c, 0, m);
  cMsg_n4AsSdg7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8XL0U2Ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_pWD5EHem_sendMessage(_c, 0, m);
  cMsg_t86rrpJL_sendMessage(_c, 0, m);
  cMsg_1AIG1D5D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rTgDJSnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Itzee6IN_sendMessage(_c, 0, m);
  cMsg_TmaFwnhl_sendMessage(_c, 0, m);
  cMsg_1AIG1D5D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_b0rEhiMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O7BBtCG3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dTEJPH1e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GJfBJiD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O7BBtCG3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dTEJPH1e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kgMv2vJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MAiedsfd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RUpIbY5M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FNHK2Fu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MAiedsfd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RUpIbY5M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y6kvdawb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rW8vxfxG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bTUgAAkw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JDAbK6lc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rW8vxfxG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bTUgAAkw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_66L41fZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_b0rEhiMI_sendMessage(_c, 0, m);
  cMsg_FNHK2Fu3_sendMessage(_c, 0, m);
  cMsg_JDAbK6lc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RLqVg8i9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_GJfBJiD9_sendMessage(_c, 0, m);
  cMsg_kgMv2vJL_sendMessage(_c, 0, m);
  cMsg_JDAbK6lc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nzEez2PF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_GJfBJiD9_sendMessage(_c, 0, m);
  cMsg_FNHK2Fu3_sendMessage(_c, 0, m);
  cMsg_y6kvdawb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QwSzpei6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_80KRLXo6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0cGba7hh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gf9bywkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_80KRLXo6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0cGba7hh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6bI8O7J0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VPqPBY60_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m0DZKFf9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_guRIlkVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VPqPBY60_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m0DZKFf9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CWnRBFgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vo0DXpe4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mFSL5sn5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7pce5cX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vo0DXpe4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mFSL5sn5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a46ljPmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_gf9bywkF_sendMessage(_c, 0, m);
  cMsg_guRIlkVM_sendMessage(_c, 0, m);
  cMsg_7pce5cX9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_J1KtumEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_gf9bywkF_sendMessage(_c, 0, m);
  cMsg_6bI8O7J0_sendMessage(_c, 0, m);
  cMsg_CWnRBFgZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Y3BVXn3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_QwSzpei6_sendMessage(_c, 0, m);
  cMsg_6bI8O7J0_sendMessage(_c, 0, m);
  cMsg_7pce5cX9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_85MzrRLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Itzee6IN_sendMessage(_c, 0, m);
  cMsg_t86rrpJL_sendMessage(_c, 0, m);
  cMsg_n4AsSdg7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_miJUbGCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_QwSzpei6_sendMessage(_c, 0, m);
  cMsg_guRIlkVM_sendMessage(_c, 0, m);
  cMsg_CWnRBFgZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_bObBkbAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wFRK0b9H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VXR5CemV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kwDzAfgT, 0, m, &cSlice_kwDzAfgT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2F5g2Ya0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_kwDzAfgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UA9kqKY7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UA9kqKY7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_As6K0iEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UA9kqKY7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UA9kqKY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BPLV0Rg0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yp6dezsW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4Iwbhqfg, 0, m, &cSlice_4Iwbhqfg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KwY8ctJM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_4Iwbhqfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TQLLRFNt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TQLLRFNt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_URpaR4cz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TQLLRFNt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_TQLLRFNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KTfGHUYh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KwY8ctJM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RSoLGJDt, 0, m, &cSlice_RSoLGJDt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VXR5CemV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_RSoLGJDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FUIIcE78_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FUIIcE78_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_d2VfAk7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FUIIcE78_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FUIIcE78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JfdUasy4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2F5g2Ya0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5roeZKve, 0, m, &cSlice_5roeZKve_sendMessage);
      break;
    }
    default: {
      cSwitchcase_03XXpiIb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5roeZKve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FcEAZjC7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FcEAZjC7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_iV56wZN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FcEAZjC7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FcEAZjC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rsrY7WDX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_03XXpiIb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fiBOOZZF, 0, m, &cSlice_fiBOOZZF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qHD9VeuU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_fiBOOZZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_72Jybe6c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_72Jybe6c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_QG38e6Qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_72Jybe6c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_72Jybe6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NTTGZ7vc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7KOoziAD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RnyUUtDJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RnyUUtDJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5KrCYdJY, 1, m, &cDelay_5KrCYdJY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6reHFIt4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5KrCYdJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5KrCYdJY, m);
  cMsg_iuXKwvjN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RnyUUtDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5KrCYdJY, 0, m, &cDelay_5KrCYdJY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6reHFIt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5KrCYdJY, 0, m, &cDelay_5KrCYdJY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Zv6w88VD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KCiKCwsC, HV_BINOP_SUBTRACT, 0, m, &cBinop_KCiKCwsC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_9wQ4J2nC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NeuZKBej_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_G5Ur92py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NeuZKBej_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_gGYQkzT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zv6w88VD, 0, m, &cVar_Zv6w88VD_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_OgLlV1RM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kqAvJGmI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BJ5S8we8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zd0uPe7u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KCiKCwsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I8OBRNuN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_I8OBRNuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FThuMNvA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FThuMNvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_yVXNhuM1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ai6lmGyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fy3ksOFs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cr6OdCRK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Fy3ksOFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9wQ4J2nC, 1, m, &cIf_9wQ4J2nC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Cr6OdCRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qMSniPaQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WbkHYedX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G5Ur92py, 1, m, &cIf_G5Ur92py_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qMSniPaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_9wQ4J2nC, 0, m, &cIf_9wQ4J2nC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yVXNhuM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G5Ur92py, 0, m, &cIf_G5Ur92py_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kqAvJGmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_zd0uPe7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zv6w88VD, 0, m, &cVar_Zv6w88VD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BJ5S8we8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KCiKCwsC, HV_BINOP_SUBTRACT, 1, m, &cBinop_KCiKCwsC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NeuZKBej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PrOpt7jL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qHD9VeuU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PmE6BCWx, 0, m, &cSlice_PmE6BCWx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_PmE6BCWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jKAANSDf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jKAANSDf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_0fFTshLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jKAANSDf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jKAANSDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tyQxxXZ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XbOOm4Ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VjirR0Sb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kjUIIpkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ElEDNtg6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_Rn7TzMYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FZWMwe0B, 0, m, &cVar_FZWMwe0B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wFRK0b9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NtFbh7Rt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_K6pOVopX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i5Yjd8tb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_NYoyrgPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7KOoziAD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iuXKwvjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_35NR8fJK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_i5Yjd8tb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_35NR8fJK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GaOeKdY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_FXEqFxdw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FXEqFxdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G58LNNUV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_G58LNNUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gzmqTdB9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_DMMVT6q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MF9rH79S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CZOLYm3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HRh23Ela_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CkXPNf43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_br27yYLy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_YF7aIRrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t8cAb4E3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_NdrEkIMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eHICaf73_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pyPAyyiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WFkBtuSE_sendMessage);
  cMsg_DTvvZDz5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WFkBtuSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pyPAyyiK, 1, m, &cVar_pyPAyyiK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0f0ncwnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JvJ5HfRN_sendMessage(_c, 0, m);
  cMsg_KlmOV2gB_sendMessage(_c, 0, m);
  cMsg_kzRffJYg_sendMessage(_c, 0, m);
  cMsg_2lXOZZko_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KgM9AV6o_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_V3PusyTc, 0, m, &cSlice_V3PusyTc_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_V3PusyTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7wl1lwG0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7wl1lwG0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_XoMMzxdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7wl1lwG0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7wl1lwG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hN3eBD7G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Qf9taWjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Iw6PMrle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Iw6PMrle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_eUGs9ZEB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eUGs9ZEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_V0PDvp8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V0PDvp8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MD9umyFt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wq3Zraeo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MD9umyFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wQiodZlw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wq3Zraeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JFZAEQSv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wQiodZlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dT7hWM7M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JFZAEQSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ljBy3JeB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ljBy3JeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WgiTVTiU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dT7hWM7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m37U7EtF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WgiTVTiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5QsqNl6k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_m37U7EtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6Cgv9mK1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5QsqNl6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VFIrwsKV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_rmDwOSI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JgRiW3CW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Q5gKQuKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eaLhYiax_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0cts4bLp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KXoUEYvv_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QaNyh280_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k3jCCeWv_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WMNy1kAT_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k5ENLed6_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4CsC1FVP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_KXoUEYvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cjNyqC2s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QaNyh280_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vN0gQ9HA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_k3jCCeWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4IA6w0Ks_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_WMNy1kAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_neanlHRf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_k5ENLed6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RKnxydZs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_4CsC1FVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s1pVe9Eu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_laMYLRaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_seN0gnfx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ewVSuQLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o6jlOmmM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZNQIcms9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_V186mflk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_V186mflk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_P28vHGW0, 1, m, &cDelay_P28vHGW0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fhqdyi6w_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_P28vHGW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_P28vHGW0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_laMYLRaC, 0, m, &cIf_laMYLRaC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_V186mflk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_P28vHGW0, 0, m, &cDelay_P28vHGW0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fhqdyi6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_P28vHGW0, 0, m, &cDelay_P28vHGW0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EP6A7hqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zTbrLLzR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jxp0ydbD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5iC6I9y7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jqtwkOr7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lbfSVX0O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jqtwkOr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_laMYLRaC, 1, m, &cIf_laMYLRaC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lbfSVX0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZNQIcms9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zTbrLLzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ewVSuQLj, 1, m, &cIf_ewVSuQLj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Jxp0ydbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ewVSuQLj, 0, m, &cIf_ewVSuQLj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o6jlOmmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HK37Y5WI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_seN0gnfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HK37Y5WI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_wVsU10kP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GR0muqHJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AA80yc1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fTlIhdi5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BjUpLRJs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FvkfXvtd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FvkfXvtd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BDceR4Cz, 1, m, &cDelay_BDceR4Cz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AiIMsfQ1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BDceR4Cz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BDceR4Cz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wVsU10kP, 0, m, &cIf_wVsU10kP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FvkfXvtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BDceR4Cz, 0, m, &cDelay_BDceR4Cz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AiIMsfQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BDceR4Cz, 0, m, &cDelay_BDceR4Cz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3F9MfgYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mnnjqSS3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vmRhdaOu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oSe2AwVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PA91vPIm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ACbZQpGt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ACbZQpGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BjUpLRJs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_PA91vPIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wVsU10kP, 1, m, &cIf_wVsU10kP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mnnjqSS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AA80yc1h, 1, m, &cIf_AA80yc1h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vmRhdaOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AA80yc1h, 0, m, &cIf_AA80yc1h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fTlIhdi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_61lfxhjd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GR0muqHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_61lfxhjd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_N8d6vH6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XPVJ5pYQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Ea2ZswGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_56snb0YT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_T7nkUd7a_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IDvXSeRm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IDvXSeRm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ip1EbKMK, 1, m, &cDelay_Ip1EbKMK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pydZbdz5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Ip1EbKMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ip1EbKMK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_N8d6vH6d, 0, m, &cIf_N8d6vH6d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IDvXSeRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ip1EbKMK, 0, m, &cDelay_Ip1EbKMK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pydZbdz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ip1EbKMK, 0, m, &cDelay_Ip1EbKMK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uogtHj4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ht6KA6Vq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6HD5TK3X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QaBEotqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2TUOIMd3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LNTrsy5X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LNTrsy5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_T7nkUd7a_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2TUOIMd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N8d6vH6d, 1, m, &cIf_N8d6vH6d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6HD5TK3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ea2ZswGk, 0, m, &cIf_Ea2ZswGk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ht6KA6Vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ea2ZswGk, 1, m, &cIf_Ea2ZswGk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_56snb0YT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8hPoXvy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XPVJ5pYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8hPoXvy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_exd1ea98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WXpFBGDj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2wU3SwjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HaTgKtd6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fuwiSY9g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_du89h1Fl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_du89h1Fl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pIUgBQ8P, 1, m, &cDelay_pIUgBQ8P_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3rNsCamh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_pIUgBQ8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pIUgBQ8P, m);
  cIf_onMessage(_c, &Context(_c)->cIf_exd1ea98, 0, m, &cIf_exd1ea98_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_du89h1Fl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pIUgBQ8P, 0, m, &cDelay_pIUgBQ8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3rNsCamh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pIUgBQ8P, 0, m, &cDelay_pIUgBQ8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1wsj3AR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PdvtflFn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J39wt1bF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nFUfiWYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vcp4kpDp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r3JyXYMO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r3JyXYMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fuwiSY9g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vcp4kpDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_exd1ea98, 1, m, &cIf_exd1ea98_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J39wt1bF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2wU3SwjE, 0, m, &cIf_2wU3SwjE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PdvtflFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2wU3SwjE, 1, m, &cIf_2wU3SwjE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HaTgKtd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ww64HgsW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WXpFBGDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ww64HgsW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_q3bNZCvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aPNGf0V1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rL1xSIcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Wb4KzrPV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gdhQpdmI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VAJD55gi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VAJD55gi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QK0QLyJc, 1, m, &cDelay_QK0QLyJc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OTD8rx7r_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_QK0QLyJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QK0QLyJc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_q3bNZCvD, 0, m, &cIf_q3bNZCvD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VAJD55gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QK0QLyJc, 0, m, &cDelay_QK0QLyJc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OTD8rx7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QK0QLyJc, 0, m, &cDelay_QK0QLyJc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R6F7h7KP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8MPhqAQT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_77YPBm0O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XBOa73Ok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7hF4gDpa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jNAyeIRb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7hF4gDpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q3bNZCvD, 1, m, &cIf_q3bNZCvD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jNAyeIRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gdhQpdmI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8MPhqAQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rL1xSIcF, 1, m, &cIf_rL1xSIcF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_77YPBm0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rL1xSIcF, 0, m, &cIf_rL1xSIcF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wb4KzrPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mi0KELrd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aPNGf0V1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mi0KELrd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8LVfBznq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aPDsBNod_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vwnrCUkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EhhGFL3E_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_a3FacB7K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TS0ixsG4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TS0ixsG4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1Ef1bZtH, 1, m, &cDelay_1Ef1bZtH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uGoOvKXA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1Ef1bZtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1Ef1bZtH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8LVfBznq, 0, m, &cIf_8LVfBznq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TS0ixsG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Ef1bZtH, 0, m, &cDelay_1Ef1bZtH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uGoOvKXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Ef1bZtH, 0, m, &cDelay_1Ef1bZtH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x4N7PFuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4mXYylef_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VcqK5FL7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Kt4vptNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DjbIdj2w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hAGIpdwN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hAGIpdwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_a3FacB7K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_DjbIdj2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8LVfBznq, 1, m, &cIf_8LVfBznq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4mXYylef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vwnrCUkL, 1, m, &cIf_vwnrCUkL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VcqK5FL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vwnrCUkL, 0, m, &cIf_vwnrCUkL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EhhGFL3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fZZFBNFt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aPDsBNod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fZZFBNFt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_blarugeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_awjFnWgX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8i3U837r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_54PCQJ98_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qu3uViDx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ka3mR3wN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ka3mR3wN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rSNd7a3W, 1, m, &cDelay_rSNd7a3W_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V5kNgZH9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rSNd7a3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rSNd7a3W, m);
  cIf_onMessage(_c, &Context(_c)->cIf_blarugeb, 0, m, &cIf_blarugeb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ka3mR3wN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rSNd7a3W, 0, m, &cDelay_rSNd7a3W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V5kNgZH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rSNd7a3W, 0, m, &cDelay_rSNd7a3W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Kc1vJCSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p6hEjGYe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l2xIHsIL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iSYfggLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NKo0b7h2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6YK9s9Sw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6YK9s9Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qu3uViDx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NKo0b7h2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_blarugeb, 1, m, &cIf_blarugeb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l2xIHsIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8i3U837r, 0, m, &cIf_8i3U837r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p6hEjGYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8i3U837r, 1, m, &cIf_8i3U837r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_54PCQJ98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yt2CSue8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_awjFnWgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yt2CSue8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_p1Th6LHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JqDmE4xN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_iuieyYbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_36kN9tyi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MfEQ9IUd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zZNhy6qy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zZNhy6qy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JmEKGNIq, 1, m, &cDelay_JmEKGNIq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vx2awJeK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JmEKGNIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JmEKGNIq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_p1Th6LHP, 0, m, &cIf_p1Th6LHP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zZNhy6qy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JmEKGNIq, 0, m, &cDelay_JmEKGNIq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Vx2awJeK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JmEKGNIq, 0, m, &cDelay_JmEKGNIq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fHrd9QBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mY3kNwdP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9vfo649q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ymvOZLRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9OLzHko4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YwR3qcSm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YwR3qcSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MfEQ9IUd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9OLzHko4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_p1Th6LHP, 1, m, &cIf_p1Th6LHP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9vfo649q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iuieyYbQ, 0, m, &cIf_iuieyYbQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mY3kNwdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iuieyYbQ, 1, m, &cIf_iuieyYbQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_36kN9tyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CyP9rrdN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JqDmE4xN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CyP9rrdN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4MdDN4jN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z5TStUBW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rhKwTnFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5kog1M1w_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Hgo5PKPH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ctXjnWwa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ctXjnWwa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RPH4JvjB, 1, m, &cDelay_RPH4JvjB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rg3Vg8PR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RPH4JvjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RPH4JvjB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4MdDN4jN, 0, m, &cIf_4MdDN4jN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ctXjnWwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RPH4JvjB, 0, m, &cDelay_RPH4JvjB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Rg3Vg8PR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RPH4JvjB, 0, m, &cDelay_RPH4JvjB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YEmXTp1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o8VYV5oZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MQitnjLn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sRgYIFzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YraDci1A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S8srVRBO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S8srVRBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Hgo5PKPH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YraDci1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4MdDN4jN, 1, m, &cIf_4MdDN4jN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MQitnjLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rhKwTnFY, 0, m, &cIf_rhKwTnFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_o8VYV5oZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rhKwTnFY, 1, m, &cIf_rhKwTnFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5kog1M1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_60bvo7Bk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Z5TStUBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_60bvo7Bk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OH1QAg8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZZpYHKPI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_adWL0ogj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RZHVRDpG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KqcU9nJl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VF4kLe1n_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VF4kLe1n_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zk7erOSB, 1, m, &cDelay_zk7erOSB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fj6CVnUI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zk7erOSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zk7erOSB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OH1QAg8w, 0, m, &cIf_OH1QAg8w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VF4kLe1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zk7erOSB, 0, m, &cDelay_zk7erOSB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fj6CVnUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zk7erOSB, 0, m, &cDelay_zk7erOSB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GZBk7NzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XkjdHYUG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZmQPfQmj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5oPuwXOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YhhlNR89_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_68dFVEwj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_68dFVEwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KqcU9nJl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YhhlNR89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OH1QAg8w, 1, m, &cIf_OH1QAg8w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZmQPfQmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_adWL0ogj, 0, m, &cIf_adWL0ogj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XkjdHYUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_adWL0ogj, 1, m, &cIf_adWL0ogj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RZHVRDpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8QnHWCU7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZZpYHKPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8QnHWCU7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_iJwJt9jH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4YfZ3hje_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jI7Y9CT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3AYp0isQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kWlyAsXv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3qeqIYUQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3qeqIYUQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wdChK4Jb, 1, m, &cDelay_wdChK4Jb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vRwKsYRN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wdChK4Jb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wdChK4Jb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iJwJt9jH, 0, m, &cIf_iJwJt9jH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3qeqIYUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wdChK4Jb, 0, m, &cDelay_wdChK4Jb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vRwKsYRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wdChK4Jb, 0, m, &cDelay_wdChK4Jb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WEQ7C1JG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u1clP2aP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wgjb2XpM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TQcibgGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0mcVT4Nm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rsXUjGFK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0mcVT4Nm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iJwJt9jH, 1, m, &cIf_iJwJt9jH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rsXUjGFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kWlyAsXv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Wgjb2XpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jI7Y9CT4, 0, m, &cIf_jI7Y9CT4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u1clP2aP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jI7Y9CT4, 1, m, &cIf_jI7Y9CT4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3AYp0isQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sn4psQGu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4YfZ3hje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sn4psQGu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4IAhKwRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YyXKwYig_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fxCdLzQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I7N3cFCk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4nWp9wCh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KeIM6u6L_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KeIM6u6L_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2tHx3LpF, 1, m, &cDelay_2tHx3LpF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HEB6kiyk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2tHx3LpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2tHx3LpF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4IAhKwRp, 0, m, &cIf_4IAhKwRp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KeIM6u6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2tHx3LpF, 0, m, &cDelay_2tHx3LpF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HEB6kiyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2tHx3LpF, 0, m, &cDelay_2tHx3LpF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8h3Az23E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GCQpELw7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fff7scbG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yrLzawQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HJQkSL93_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oeQ3LRgi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oeQ3LRgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4nWp9wCh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HJQkSL93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4IAhKwRp, 1, m, &cIf_4IAhKwRp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fff7scbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fxCdLzQ2, 0, m, &cIf_fxCdLzQ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GCQpELw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fxCdLzQ2, 1, m, &cIf_fxCdLzQ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I7N3cFCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OOKxWJe5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YyXKwYig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OOKxWJe5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cjNyqC2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_Tddd3x2V_sendMessage(_c, 0, m);
  cMsg_lFKnNTZ7_sendMessage(_c, 0, m);
  cMsg_I8RVubB4_sendMessage(_c, 0, m);
  cMsg_Eg92QPFM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vN0gQ9HA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_Tddd3x2V_sendMessage(_c, 0, m);
  cMsg_PlnmIwCZ_sendMessage(_c, 0, m);
  cMsg_KLjkCtrR_sendMessage(_c, 0, m);
  cMsg_8jMyQam3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4IA6w0Ks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_qGHqrTbt_sendMessage(_c, 0, m);
  cMsg_PlnmIwCZ_sendMessage(_c, 0, m);
  cMsg_Eg92QPFM_sendMessage(_c, 0, m);
  cMsg_Sza2job3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_neanlHRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_qGHqrTbt_sendMessage(_c, 0, m);
  cMsg_6xhhUpo6_sendMessage(_c, 0, m);
  cMsg_I8RVubB4_sendMessage(_c, 0, m);
  cMsg_to2f8bvG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RKnxydZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_vE502vuI_sendMessage(_c, 0, m);
  cMsg_8jMyQam3_sendMessage(_c, 0, m);
  cMsg_wyCxB3Ip_sendMessage(_c, 0, m);
  cMsg_I8RVubB4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_s1pVe9Eu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_vE502vuI_sendMessage(_c, 0, m);
  cMsg_to2f8bvG_sendMessage(_c, 0, m);
  cMsg_PlnmIwCZ_sendMessage(_c, 0, m);
  cMsg_34tsNjsF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lqvVxJir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5iC6I9y7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EP6A7hqn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8ypAamhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5iC6I9y7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EP6A7hqn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C4QbMwbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oSe2AwVR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3F9MfgYh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rP1B26DE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oSe2AwVR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3F9MfgYh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d51Pc3lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QaBEotqL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uogtHj4R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yktN98sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QaBEotqL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uogtHj4R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Tddd3x2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_lqvVxJir_sendMessage(_c, 0, m);
  cMsg_rP1B26DE_sendMessage(_c, 0, m);
  cMsg_yktN98sW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qGHqrTbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_8ypAamhi_sendMessage(_c, 0, m);
  cMsg_C4QbMwbY_sendMessage(_c, 0, m);
  cMsg_yktN98sW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vE502vuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_8ypAamhi_sendMessage(_c, 0, m);
  cMsg_rP1B26DE_sendMessage(_c, 0, m);
  cMsg_d51Pc3lb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kF01LPyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nFUfiWYm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1wsj3AR0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4u8igqmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nFUfiWYm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1wsj3AR0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1x7fpFcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XBOa73Ok_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R6F7h7KP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_V7vq8Qnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XBOa73Ok_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R6F7h7KP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4FOUM0NP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Kt4vptNj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_x4N7PFuy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yvidleVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Kt4vptNj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_x4N7PFuy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PlnmIwCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_4u8igqmi_sendMessage(_c, 0, m);
  cMsg_V7vq8Qnp_sendMessage(_c, 0, m);
  cMsg_yvidleVX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lFKnNTZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_4u8igqmi_sendMessage(_c, 0, m);
  cMsg_1x7fpFcn_sendMessage(_c, 0, m);
  cMsg_4FOUM0NP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6xhhUpo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_kF01LPyV_sendMessage(_c, 0, m);
  cMsg_V7vq8Qnp_sendMessage(_c, 0, m);
  cMsg_4FOUM0NP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tj5ZEvjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5oPuwXOV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GZBk7NzV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4qRRjWb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5oPuwXOV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GZBk7NzV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aOF5agAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TQcibgGc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WEQ7C1JG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cyiLvfOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TQcibgGc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WEQ7C1JG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8SCPoY7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yrLzawQ1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8h3Az23E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tIDmiddG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yrLzawQ1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8h3Az23E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_to2f8bvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_tj5ZEvjd_sendMessage(_c, 0, m);
  cMsg_cyiLvfOg_sendMessage(_c, 0, m);
  cMsg_tIDmiddG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8jMyQam3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_4qRRjWb0_sendMessage(_c, 0, m);
  cMsg_aOF5agAy_sendMessage(_c, 0, m);
  cMsg_tIDmiddG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Eg92QPFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_4qRRjWb0_sendMessage(_c, 0, m);
  cMsg_cyiLvfOg_sendMessage(_c, 0, m);
  cMsg_8SCPoY7I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_G0gswhAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iSYfggLj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Kc1vJCSD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E9mBx7VA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iSYfggLj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Kc1vJCSD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_npxpHFvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ymvOZLRz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fHrd9QBe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Xqs8xxjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ymvOZLRz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fHrd9QBe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HemDZE6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sRgYIFzx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YEmXTp1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wmEAQai4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sRgYIFzx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YEmXTp1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I8RVubB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_E9mBx7VA_sendMessage(_c, 0, m);
  cMsg_Xqs8xxjq_sendMessage(_c, 0, m);
  cMsg_wmEAQai4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KLjkCtrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_E9mBx7VA_sendMessage(_c, 0, m);
  cMsg_npxpHFvQ_sendMessage(_c, 0, m);
  cMsg_HemDZE6l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_34tsNjsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_G0gswhAn_sendMessage(_c, 0, m);
  cMsg_npxpHFvQ_sendMessage(_c, 0, m);
  cMsg_wmEAQai4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wyCxB3Ip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_kF01LPyV_sendMessage(_c, 0, m);
  cMsg_1x7fpFcn_sendMessage(_c, 0, m);
  cMsg_yvidleVX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Sza2job3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_G0gswhAn_sendMessage(_c, 0, m);
  cMsg_Xqs8xxjq_sendMessage(_c, 0, m);
  cMsg_HemDZE6l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_6om5vrlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ooNHRJVQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lWzxFIg6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_X50qkm2F, 0, m, &cSlice_X50qkm2F_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qC0BUW3t_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_X50qkm2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nS4sTjY5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nS4sTjY5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lHHNFtke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nS4sTjY5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_nS4sTjY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rTuhpfA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Cf6LntbX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_50cjeODW, 0, m, &cSlice_50cjeODW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jz8D0SU9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_50cjeODW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fKiIkEfv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fKiIkEfv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_tPNKtmQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fKiIkEfv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fKiIkEfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Xo7au8FH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jz8D0SU9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5ix8r6ML, 0, m, &cSlice_5ix8r6ML_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lWzxFIg6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5ix8r6ML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yrGIJh1x_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yrGIJh1x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_1kgrorQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yrGIJh1x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yrGIJh1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jh2iWba3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qC0BUW3t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ftcCyCk2, 0, m, &cSlice_ftcCyCk2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1aIZQvt6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ftcCyCk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zmJtbnDz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zmJtbnDz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_y1GNFcy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zmJtbnDz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zmJtbnDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LH6njzcT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1aIZQvt6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NYnLm0sW, 0, m, &cSlice_NYnLm0sW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YLqQttdf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_NYnLm0sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ibRl6Sah_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ibRl6Sah_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_9BzGnXrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ibRl6Sah_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ibRl6Sah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5RYxy0hu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_brWau4Ik_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2OUWw6yG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2OUWw6yG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9WHYbWSG, 1, m, &cDelay_9WHYbWSG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bQ0BBh1S_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9WHYbWSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9WHYbWSG, m);
  cMsg_r0VaIPDd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2OUWw6yG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9WHYbWSG, 0, m, &cDelay_9WHYbWSG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bQ0BBh1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9WHYbWSG, 0, m, &cDelay_9WHYbWSG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Wjn1ZYak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5TMWnxl1, HV_BINOP_SUBTRACT, 0, m, &cBinop_5TMWnxl1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_HfnIOakb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nRwvn8yk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dgl2ygea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nRwvn8yk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_PAicXAbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wjn1ZYak, 0, m, &cVar_Wjn1ZYak_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_ZiSQeIXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I4bgMlAO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dUaMYvNb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U0YfpfPv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5TMWnxl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sBZCxNDL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sBZCxNDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YbVxkqgd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YbVxkqgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_DGli8ErY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Fa0IXMaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JgUTnkpc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_25Uy6x3C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_25Uy6x3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YcaiWui3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JgUTnkpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HfnIOakb, 1, m, &cIf_HfnIOakb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AAhHGehI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dgl2ygea, 1, m, &cIf_dgl2ygea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YcaiWui3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HfnIOakb, 0, m, &cIf_HfnIOakb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DGli8ErY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dgl2ygea, 0, m, &cIf_dgl2ygea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I4bgMlAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_U0YfpfPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wjn1ZYak, 0, m, &cVar_Wjn1ZYak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dUaMYvNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5TMWnxl1, HV_BINOP_SUBTRACT, 1, m, &cBinop_5TMWnxl1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nRwvn8yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jbqGS0i1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YLqQttdf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Oiq8vS25, 0, m, &cSlice_Oiq8vS25_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Oiq8vS25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xoizW8JC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xoizW8JC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_G992ZyYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xoizW8JC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xoizW8JC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DvNevAnj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JgRiW3CW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fgttbEnW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eaLhYiax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EvBwhjCX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_Fb6UVHhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q5gKQuKz, 0, m, &cVar_Q5gKQuKz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ooNHRJVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YSXuJS1z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_iMjKCS0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A0A2oAT7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bEnwF34A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_brWau4Ik_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_r0VaIPDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tbb4MeVw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_A0A2oAT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tbb4MeVw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_e77uBlcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_AfZHpfea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AfZHpfea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KaBiTEkR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KaBiTEkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m5UPqswg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_TEmWMDZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_USjm4zig_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ftvqs3Tl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rt3AC20T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_C3mCb27z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G2KkNcLa_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WdhJn2r2_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2d7Zx8OA_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gGLB4D8T_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6sRKOhnf_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_twaGfPyJ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_G2KkNcLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GRI5PbYj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_WdhJn2r2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DMpH8XPI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_2d7Zx8OA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7tXwrvEl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_gGLB4D8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1vU0i2Rj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_6sRKOhnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pdFZ8SRP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_twaGfPyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bl5nTH1b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_DD1Lr2Yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9iZVxszq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1bZO1Nwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MH5AB7ae_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mabh2ZAt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VnmhHshT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VnmhHshT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CDtlT6HU, 1, m, &cDelay_CDtlT6HU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VOH4pBnW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CDtlT6HU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CDtlT6HU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_DD1Lr2Yp, 0, m, &cIf_DD1Lr2Yp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VnmhHshT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CDtlT6HU, 0, m, &cDelay_CDtlT6HU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VOH4pBnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CDtlT6HU, 0, m, &cDelay_CDtlT6HU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9L9aDHeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bvNBrWdq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HXuSt041_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RCXRsqA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NsRdjeXM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ko914pg3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NsRdjeXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DD1Lr2Yp, 1, m, &cIf_DD1Lr2Yp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ko914pg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mabh2ZAt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HXuSt041_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1bZO1Nwz, 0, m, &cIf_1bZO1Nwz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bvNBrWdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1bZO1Nwz, 1, m, &cIf_1bZO1Nwz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MH5AB7ae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m61W8DWa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9iZVxszq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m61W8DWa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_1mbHZtwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3VPGswGn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yub2WM5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_98Aj9knv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FS5RSjMV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fXK7Txyd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fXK7Txyd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_whlmoQWJ, 1, m, &cDelay_whlmoQWJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5RlHTfBS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_whlmoQWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_whlmoQWJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1mbHZtwj, 0, m, &cIf_1mbHZtwj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fXK7Txyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_whlmoQWJ, 0, m, &cDelay_whlmoQWJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5RlHTfBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_whlmoQWJ, 0, m, &cDelay_whlmoQWJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KBxeH52b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_azySbRMM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cpA0KjjU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9NWpArYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nCoxGm4Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iGGF64b3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nCoxGm4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1mbHZtwj, 1, m, &cIf_1mbHZtwj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iGGF64b3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FS5RSjMV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_azySbRMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yub2WM5O, 1, m, &cIf_yub2WM5O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cpA0KjjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yub2WM5O, 0, m, &cIf_yub2WM5O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_98Aj9knv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ro7tp7N3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3VPGswGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ro7tp7N3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SHgi4gFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NXrvV7R0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XZCbU96q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2Mge1jjW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_luQILAKU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NNX7u3Yk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NNX7u3Yk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qel8iniW, 1, m, &cDelay_qel8iniW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sx6uNbx6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qel8iniW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qel8iniW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SHgi4gFh, 0, m, &cIf_SHgi4gFh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NNX7u3Yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qel8iniW, 0, m, &cDelay_qel8iniW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sx6uNbx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qel8iniW, 0, m, &cDelay_qel8iniW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xvJ0Dfkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K3ulyP40_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PgvWJBRf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qV6J5IeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YrKhK5v4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Kdtfi6d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2Kdtfi6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_luQILAKU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YrKhK5v4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SHgi4gFh, 1, m, &cIf_SHgi4gFh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PgvWJBRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XZCbU96q, 0, m, &cIf_XZCbU96q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K3ulyP40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XZCbU96q, 1, m, &cIf_XZCbU96q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2Mge1jjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MsBGlAfn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NXrvV7R0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MsBGlAfn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_D6xelNNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hsL1t2TE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2pn1pjsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uDR3AT98_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_37BYkDOG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aZVyJzIR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aZVyJzIR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZUGwqtVo, 1, m, &cDelay_ZUGwqtVo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KXjKlXuX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZUGwqtVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZUGwqtVo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_D6xelNNS, 0, m, &cIf_D6xelNNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aZVyJzIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZUGwqtVo, 0, m, &cDelay_ZUGwqtVo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KXjKlXuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZUGwqtVo, 0, m, &cDelay_ZUGwqtVo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MSoAAx4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_REWkwi3b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4MhokWi9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M9JLDvNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4ZAo4r9m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5HvUIb0i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5HvUIb0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_37BYkDOG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4ZAo4r9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D6xelNNS, 1, m, &cIf_D6xelNNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4MhokWi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2pn1pjsR, 0, m, &cIf_2pn1pjsR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_REWkwi3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2pn1pjsR, 1, m, &cIf_2pn1pjsR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uDR3AT98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rob0dCDQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hsL1t2TE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rob0dCDQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_iuwwq1Rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hUSMjs3K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_mLvdD550_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vfTQ3M62_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ic3HfX4s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EXNII8dW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EXNII8dW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9PWWFuk3, 1, m, &cDelay_9PWWFuk3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZPfDEGoP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9PWWFuk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9PWWFuk3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iuwwq1Rx, 0, m, &cIf_iuwwq1Rx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EXNII8dW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9PWWFuk3, 0, m, &cDelay_9PWWFuk3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZPfDEGoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9PWWFuk3, 0, m, &cDelay_9PWWFuk3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Rotx0mxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yo8aE97h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7bSBPpF3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G3zLf6BH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UaiKybJI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C16wgZsP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UaiKybJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iuwwq1Rx, 1, m, &cIf_iuwwq1Rx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C16wgZsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ic3HfX4s_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7bSBPpF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mLvdD550, 0, m, &cIf_mLvdD550_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yo8aE97h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mLvdD550, 1, m, &cIf_mLvdD550_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vfTQ3M62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IPkJlkUN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hUSMjs3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IPkJlkUN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Y2PlRAdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NjshM4u7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Lgdpkj0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kkhZF55u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3ZlX5BCy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zt7K9Z01_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zt7K9Z01_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TtLDTHu9, 1, m, &cDelay_TtLDTHu9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CZQ5ESdL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TtLDTHu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TtLDTHu9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Y2PlRAdX, 0, m, &cIf_Y2PlRAdX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zt7K9Z01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TtLDTHu9, 0, m, &cDelay_TtLDTHu9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CZQ5ESdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TtLDTHu9, 0, m, &cDelay_TtLDTHu9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xUjiSkzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5BpxVNpI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9dERgiw6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TxAOHFnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jNieW5Re_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DtzTdfkA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jNieW5Re_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y2PlRAdX, 1, m, &cIf_Y2PlRAdX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DtzTdfkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3ZlX5BCy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5BpxVNpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Lgdpkj0J, 1, m, &cIf_Lgdpkj0J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9dERgiw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Lgdpkj0J, 0, m, &cIf_Lgdpkj0J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kkhZF55u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UHwz50Br, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NjshM4u7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UHwz50Br, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_F48ZVWom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IqPr5dS6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_PdLACsZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UlDbCxjZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fhPlDoen_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ouctBfwY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ouctBfwY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Q7HCKE40, 1, m, &cDelay_Q7HCKE40_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xqgrgbZP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Q7HCKE40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q7HCKE40, m);
  cIf_onMessage(_c, &Context(_c)->cIf_F48ZVWom, 0, m, &cIf_F48ZVWom_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ouctBfwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q7HCKE40, 0, m, &cDelay_Q7HCKE40_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xqgrgbZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q7HCKE40, 0, m, &cDelay_Q7HCKE40_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NCYyAtGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NyKrx7hR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZRcGAcsQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UrwlVbX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AYMwD0en_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DUoHUtno_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AYMwD0en_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F48ZVWom, 1, m, &cIf_F48ZVWom_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DUoHUtno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fhPlDoen_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NyKrx7hR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PdLACsZT, 1, m, &cIf_PdLACsZT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZRcGAcsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PdLACsZT, 0, m, &cIf_PdLACsZT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UlDbCxjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0tOnRval, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IqPr5dS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0tOnRval, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SvK6tgjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KLKbIoWp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JbcaoR6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CCjctGtd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ffm3PqJH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_k5dpJCT6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_k5dpJCT6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1Osf4WFK, 1, m, &cDelay_1Osf4WFK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jqVgW6TU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1Osf4WFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1Osf4WFK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SvK6tgjN, 0, m, &cIf_SvK6tgjN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k5dpJCT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Osf4WFK, 0, m, &cDelay_1Osf4WFK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jqVgW6TU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Osf4WFK, 0, m, &cDelay_1Osf4WFK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a0YndlAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c6ZeV2Hr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a8VEKf9f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wPia8emF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jNli9eUn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qq6LkdQQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qq6LkdQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ffm3PqJH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jNli9eUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SvK6tgjN, 1, m, &cIf_SvK6tgjN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c6ZeV2Hr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JbcaoR6g, 1, m, &cIf_JbcaoR6g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a8VEKf9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JbcaoR6g, 0, m, &cIf_JbcaoR6g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CCjctGtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7zCp5iZm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KLKbIoWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7zCp5iZm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KoE42EuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O17VNI3S_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AmJfRLrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2HpfXxBj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rUxUON8C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xFAZa1RU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xFAZa1RU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_45gVs3UX, 1, m, &cDelay_45gVs3UX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z2dK3GGd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_45gVs3UX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_45gVs3UX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KoE42EuA, 0, m, &cIf_KoE42EuA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xFAZa1RU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_45gVs3UX, 0, m, &cDelay_45gVs3UX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z2dK3GGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_45gVs3UX, 0, m, &cDelay_45gVs3UX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y3BMRZVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2pNjJYgx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MlIDrtcW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Acv3ty7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aECEF10w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ynvUUjkL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ynvUUjkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rUxUON8C_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_aECEF10w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KoE42EuA, 1, m, &cIf_KoE42EuA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MlIDrtcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AmJfRLrT, 0, m, &cIf_AmJfRLrT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2pNjJYgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AmJfRLrT, 1, m, &cIf_AmJfRLrT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2HpfXxBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wTvVF7r4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_O17VNI3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wTvVF7r4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_k1UpkB5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_f6C7kBcN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kFsCOqMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ME1v9zJ4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WPrlM7QH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Iie1xR24_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Iie1xR24_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FohdJn1K, 1, m, &cDelay_FohdJn1K_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dCstiCwB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FohdJn1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FohdJn1K, m);
  cIf_onMessage(_c, &Context(_c)->cIf_k1UpkB5c, 0, m, &cIf_k1UpkB5c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Iie1xR24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FohdJn1K, 0, m, &cDelay_FohdJn1K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dCstiCwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FohdJn1K, 0, m, &cDelay_FohdJn1K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n17u2z3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IJhR3MTq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nWpeAkpT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hCoH7f8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8HpzMica_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ZqjoViw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8HpzMica_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k1UpkB5c, 1, m, &cIf_k1UpkB5c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8ZqjoViw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WPrlM7QH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_IJhR3MTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kFsCOqMA, 1, m, &cIf_kFsCOqMA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nWpeAkpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kFsCOqMA, 0, m, &cIf_kFsCOqMA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ME1v9zJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pJZ5lNYz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_f6C7kBcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pJZ5lNYz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_z5qSNv4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_smrRr2qs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9vAH2Itj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_q5aJSHJR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IGkCGxdB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aTrvGlB3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aTrvGlB3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uS77lI8X, 1, m, &cDelay_uS77lI8X_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1KJ538Cb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uS77lI8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uS77lI8X, m);
  cIf_onMessage(_c, &Context(_c)->cIf_z5qSNv4P, 0, m, &cIf_z5qSNv4P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aTrvGlB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uS77lI8X, 0, m, &cDelay_uS77lI8X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1KJ538Cb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uS77lI8X, 0, m, &cDelay_uS77lI8X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c2z7WHpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QIPhBd1L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IpgW4c9k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4Pgj982i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QM9YBSA9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iyGmKODv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QM9YBSA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z5qSNv4P, 1, m, &cIf_z5qSNv4P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iyGmKODv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IGkCGxdB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QIPhBd1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9vAH2Itj, 1, m, &cIf_9vAH2Itj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IpgW4c9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9vAH2Itj, 0, m, &cIf_9vAH2Itj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_q5aJSHJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4klrPboV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_smrRr2qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4klrPboV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_rQodkwrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RqGYS4Cy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5muQ7Oiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4uY75aYQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2mjym46X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Wu0yAZsP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Wu0yAZsP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dwN7IVu3, 1, m, &cDelay_dwN7IVu3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NFSeAlEu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dwN7IVu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dwN7IVu3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rQodkwrb, 0, m, &cIf_rQodkwrb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wu0yAZsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dwN7IVu3, 0, m, &cDelay_dwN7IVu3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NFSeAlEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dwN7IVu3, 0, m, &cDelay_dwN7IVu3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TL6J2u5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1JNYZ3Ty_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_psbB55DD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HpjUoKcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ylFGHajO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M9wy5Kj3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M9wy5Kj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2mjym46X_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ylFGHajO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rQodkwrb, 1, m, &cIf_rQodkwrb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1JNYZ3Ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5muQ7Oiu, 1, m, &cIf_5muQ7Oiu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_psbB55DD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5muQ7Oiu, 0, m, &cIf_5muQ7Oiu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4uY75aYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jt7xLKzT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RqGYS4Cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jt7xLKzT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GRI5PbYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_xoVigaiK_sendMessage(_c, 0, m);
  cMsg_4VnU2BQz_sendMessage(_c, 0, m);
  cMsg_YQG960jL_sendMessage(_c, 0, m);
  cMsg_DpCavsHk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DMpH8XPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_xoVigaiK_sendMessage(_c, 0, m);
  cMsg_INJxE4HM_sendMessage(_c, 0, m);
  cMsg_9FTRhTSO_sendMessage(_c, 0, m);
  cMsg_RwEjwK1N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7tXwrvEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_rKqfJkV7_sendMessage(_c, 0, m);
  cMsg_INJxE4HM_sendMessage(_c, 0, m);
  cMsg_DpCavsHk_sendMessage(_c, 0, m);
  cMsg_PYeDUQon_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1vU0i2Rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_rKqfJkV7_sendMessage(_c, 0, m);
  cMsg_qOsKLbt9_sendMessage(_c, 0, m);
  cMsg_YQG960jL_sendMessage(_c, 0, m);
  cMsg_afW0m5Wj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pdFZ8SRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_oiqDybzX_sendMessage(_c, 0, m);
  cMsg_RwEjwK1N_sendMessage(_c, 0, m);
  cMsg_y8upCB58_sendMessage(_c, 0, m);
  cMsg_YQG960jL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bl5nTH1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_oiqDybzX_sendMessage(_c, 0, m);
  cMsg_afW0m5Wj_sendMessage(_c, 0, m);
  cMsg_INJxE4HM_sendMessage(_c, 0, m);
  cMsg_TLiJ31fv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BeuaMWYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RCXRsqA7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9L9aDHeN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5MAyM4LC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RCXRsqA7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9L9aDHeN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oqGOQFAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9NWpArYs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KBxeH52b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0YZTFWGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9NWpArYs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KBxeH52b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y85SZYVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qV6J5IeF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xvJ0Dfkg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iWsRnlK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qV6J5IeF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xvJ0Dfkg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xoVigaiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_BeuaMWYO_sendMessage(_c, 0, m);
  cMsg_0YZTFWGp_sendMessage(_c, 0, m);
  cMsg_iWsRnlK8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rKqfJkV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_5MAyM4LC_sendMessage(_c, 0, m);
  cMsg_oqGOQFAD_sendMessage(_c, 0, m);
  cMsg_iWsRnlK8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oiqDybzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_5MAyM4LC_sendMessage(_c, 0, m);
  cMsg_0YZTFWGp_sendMessage(_c, 0, m);
  cMsg_Y85SZYVj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Dg8NPs3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_M9JLDvNk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MSoAAx4m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ycZwEqnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_M9JLDvNk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MSoAAx4m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ReT1Cbdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G3zLf6BH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Rotx0mxs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cgrlv5JA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G3zLf6BH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Rotx0mxs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_L0AjTfbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TxAOHFnm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xUjiSkzW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uVuotNfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TxAOHFnm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xUjiSkzW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_INJxE4HM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_ycZwEqnP_sendMessage(_c, 0, m);
  cMsg_cgrlv5JA_sendMessage(_c, 0, m);
  cMsg_uVuotNfi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4VnU2BQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_ycZwEqnP_sendMessage(_c, 0, m);
  cMsg_ReT1Cbdb_sendMessage(_c, 0, m);
  cMsg_L0AjTfbL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qOsKLbt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Dg8NPs3q_sendMessage(_c, 0, m);
  cMsg_cgrlv5JA_sendMessage(_c, 0, m);
  cMsg_L0AjTfbL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XPu3jB7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hCoH7f8x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_n17u2z3X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zfEDnENG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hCoH7f8x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_n17u2z3X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YMy92FfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4Pgj982i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_c2z7WHpW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fqFFqmvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4Pgj982i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_c2z7WHpW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qNuinC6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HpjUoKcs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TL6J2u5K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zm7Sojq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HpjUoKcs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TL6J2u5K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_afW0m5Wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_XPu3jB7D_sendMessage(_c, 0, m);
  cMsg_fqFFqmvA_sendMessage(_c, 0, m);
  cMsg_zm7Sojq0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RwEjwK1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_zfEDnENG_sendMessage(_c, 0, m);
  cMsg_YMy92FfW_sendMessage(_c, 0, m);
  cMsg_zm7Sojq0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DpCavsHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_zfEDnENG_sendMessage(_c, 0, m);
  cMsg_fqFFqmvA_sendMessage(_c, 0, m);
  cMsg_qNuinC6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2w0EsAaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UrwlVbX8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NCYyAtGY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OLxTJfLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UrwlVbX8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NCYyAtGY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7Kx2P79R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wPia8emF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a0YndlAc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yexJx2hN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wPia8emF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a0YndlAc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xoRDbWEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Acv3ty7s_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y3BMRZVA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TrkCjcwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Acv3ty7s_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y3BMRZVA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YQG960jL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_OLxTJfLv_sendMessage(_c, 0, m);
  cMsg_yexJx2hN_sendMessage(_c, 0, m);
  cMsg_TrkCjcwD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9FTRhTSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_OLxTJfLv_sendMessage(_c, 0, m);
  cMsg_7Kx2P79R_sendMessage(_c, 0, m);
  cMsg_xoRDbWEQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TLiJ31fv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_2w0EsAaG_sendMessage(_c, 0, m);
  cMsg_7Kx2P79R_sendMessage(_c, 0, m);
  cMsg_TrkCjcwD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y8upCB58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Dg8NPs3q_sendMessage(_c, 0, m);
  cMsg_ReT1Cbdb_sendMessage(_c, 0, m);
  cMsg_uVuotNfi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PYeDUQon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_2w0EsAaG_sendMessage(_c, 0, m);
  cMsg_yexJx2hN_sendMessage(_c, 0, m);
  cMsg_xoRDbWEQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_964FGDhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q7d6Ej0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rCgrdKeS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ooSk9xGv, 0, m, &cSlice_ooSk9xGv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bckfh2pe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ooSk9xGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rnO1kwgQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rnO1kwgQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_prEbvl3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rnO1kwgQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rnO1kwgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xqXC57aC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cwEuLm3T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Vlx6oEZv, 0, m, &cSlice_Vlx6oEZv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_e9pFT4OV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Vlx6oEZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xEkMvEGz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xEkMvEGz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_P1fYvbpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xEkMvEGz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xEkMvEGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AnjrXy6S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e9pFT4OV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yL2lVgfA, 0, m, &cSlice_yL2lVgfA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rCgrdKeS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_yL2lVgfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_f0wTdtrQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_f0wTdtrQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_aDmRIGLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f0wTdtrQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_f0wTdtrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HiCH4wKH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bckfh2pe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YsafdeN9, 0, m, &cSlice_YsafdeN9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PoeuFT6O_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_YsafdeN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jFm5wiFE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jFm5wiFE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Ffr61hlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jFm5wiFE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jFm5wiFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tkt9ZDz3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PoeuFT6O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JWu06Twb, 0, m, &cSlice_JWu06Twb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_P0eEkN5G_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_JWu06Twb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Xxy1liwA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Xxy1liwA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_VB6Polvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Xxy1liwA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Xxy1liwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_D6pz0zRc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_icBNpGNo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NaJIIbba_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NaJIIbba_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9FzsyDej, 1, m, &cDelay_9FzsyDej_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WLn7fZrY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9FzsyDej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9FzsyDej, m);
  cMsg_MerA6gEH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NaJIIbba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9FzsyDej, 0, m, &cDelay_9FzsyDej_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WLn7fZrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9FzsyDej, 0, m, &cDelay_9FzsyDej_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_yDZrzAo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CXiQZjsb, HV_BINOP_SUBTRACT, 0, m, &cBinop_CXiQZjsb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_4RGn0Vai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_afamHWpE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_mfabXTZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_afamHWpE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_KdHqRHC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yDZrzAo9, 0, m, &cVar_yDZrzAo9_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_I2XQ3xr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KFCwmIpB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AmcNK6xt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T4xe0tkt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CXiQZjsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Lj75kJU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9Lj75kJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Lhpx9QBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Lhpx9QBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_JsXikait_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xnKNfDe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L8hGT8Mw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uLcXCTU4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uLcXCTU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_54QBv3DY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_L8hGT8Mw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4RGn0Vai, 1, m, &cIf_4RGn0Vai_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PPoekHEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mfabXTZz, 1, m, &cIf_mfabXTZz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_54QBv3DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_4RGn0Vai, 0, m, &cIf_4RGn0Vai_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JsXikait_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mfabXTZz, 0, m, &cIf_mfabXTZz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AmcNK6xt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CXiQZjsb, HV_BINOP_SUBTRACT, 1, m, &cBinop_CXiQZjsb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KFCwmIpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_T4xe0tkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yDZrzAo9, 0, m, &cVar_yDZrzAo9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_afamHWpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qwbhzP3H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_P0eEkN5G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Qpdl5mDs, 0, m, &cSlice_Qpdl5mDs_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Qpdl5mDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_L2dTwRjh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_L2dTwRjh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lNkaGQ1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_L2dTwRjh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_L2dTwRjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0Q5E17Tc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_USjm4zig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O9n9XZy6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Rt3AC20T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_whUHAsJc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_uHFmtMjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ftvqs3Tl, 0, m, &cVar_ftvqs3Tl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_q7d6Ej0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QE5Y4KNf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RqTln5f1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_icBNpGNo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gZ7a35L8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fa60BKDS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MerA6gEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cIK03Gcc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Fa60BKDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cIK03Gcc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JFBbsUdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_oCoQ3oVe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oCoQ3oVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_udGKkxtO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_udGKkxtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gnqBl1vj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_kC0u7Ck0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P4QGQj9R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_r3ortZYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yZT8SWql_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_XW1ltRcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C06wDIPn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3OGHN7gD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_23rFsCkl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xOMJeIsz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PaUxfxvp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CY1WPkkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_23rFsCkl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xOMJeIsz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PaUxfxvp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_oeZ7Ygi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u3CzAdqn, 0, m, &cVar_u3CzAdqn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eLtKNQry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_23rFsCkl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xOMJeIsz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PaUxfxvp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5I88WBU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_23rFsCkl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xOMJeIsz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PaUxfxvp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aPzYtAAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_23rFsCkl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xOMJeIsz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PaUxfxvp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YdSJ2QU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_w7piIFlG, 0, m, &cVar_w7piIFlG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PTB6TTGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_aTbauSnr, 0, m, &cVar_aTbauSnr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ShTOKDsQ, 0, m, &cVar_ShTOKDsQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Veih56ng, 0, m, &cVar_Veih56ng_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P3r2k48C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_oeZ7Ygi2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_961TeZ2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zdJxsKPa_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VeFlXUHv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vqoAYv2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zdJxsKPa_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VeFlXUHv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pm68mk61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zdJxsKPa_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VeFlXUHv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mAaHVVfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zdJxsKPa_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VeFlXUHv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2sXkj5jA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zdJxsKPa_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VeFlXUHv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Pyv6b9H1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_hVJJcVIx, 0, m, &cVar_hVJJcVIx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DJAmcgjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_0v4LnZQk, 0, m, &cVar_0v4LnZQk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0lTxK1Qg, 0, m, &cVar_0lTxK1Qg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6nu1nRvW, 0, m, &cVar_6nu1nRvW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i6zcGL1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_23rFsCkl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xOMJeIsz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PaUxfxvp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UMnYXFyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6417DITn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_j4LuSiTI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yp6dezsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9MvGZD6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6417DITn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_j4LuSiTI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yp6dezsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_BHaN0FYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TSE1mEHZ, 0, m, &cVar_TSE1mEHZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iThumyVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6417DITn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_j4LuSiTI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yp6dezsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_q2GsYkUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6417DITn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_j4LuSiTI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yp6dezsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ym41T08m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6417DITn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_j4LuSiTI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yp6dezsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oDjOTx0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_dsBqXxEO, 0, m, &cVar_dsBqXxEO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SWaRCREO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_PLK4lUSu, 0, m, &cVar_PLK4lUSu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EJbP2V0E, 0, m, &cVar_EJbP2V0E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MwNIuobt, 0, m, &cVar_MwNIuobt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jxrvZcnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_BHaN0FYv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uRTLmBhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6417DITn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_j4LuSiTI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yp6dezsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MF9rH79S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KgM9AV6o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cf6LntbX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cwEuLm3T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_t8cAb4E3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KgM9AV6o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cf6LntbX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cwEuLm3T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_ErM1QAHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CZOLYm3G, 0, m, &cVar_CZOLYm3G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_br27yYLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KgM9AV6o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cf6LntbX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cwEuLm3T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eHICaf73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KgM9AV6o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cf6LntbX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cwEuLm3T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DTvvZDz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KgM9AV6o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cf6LntbX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cwEuLm3T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JvJ5HfRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_YF7aIRrU, 0, m, &cVar_YF7aIRrU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KlmOV2gB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_CkXPNf43, 0, m, &cVar_CkXPNf43_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NdrEkIMR, 0, m, &cVar_NdrEkIMR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pyPAyyiK, 0, m, &cVar_pyPAyyiK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kzRffJYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ErM1QAHs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HRh23Ela_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KgM9AV6o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cf6LntbX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cwEuLm3T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_I83fhgIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_kC0u7Ck0, 0, m, &cVar_kC0u7Ck0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P4QGQj9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_23rFsCkl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xOMJeIsz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PaUxfxvp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LerDHdM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_r3ortZYz, 0, m, &cVar_r3ortZYz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yZT8SWql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6417DITn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_j4LuSiTI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yp6dezsW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2lXOZZko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_XW1ltRcI, 0, m, &cVar_XW1ltRcI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C06wDIPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KgM9AV6o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cf6LntbX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cwEuLm3T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_C8pjt79n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jTfb5rvy_sendMessage(_c, 0, m);
  cMsg_H1B2UqwI_sendMessage(_c, 0, m);
  cMsg_WN2PyMvN_sendMessage(_c, 0, m);
  cMsg_SQp3YkRJ_sendMessage(_c, 0, m);
  cMsg_eoE5EaWf_sendMessage(_c, 0, m);
  cMsg_tdtt4l3k_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Fs4ctBVY, 0, m, &cVar_Fs4ctBVY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LkwdWRNS, 0, m, &cVar_LkwdWRNS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CqA03vsI, 0, m, &cVar_CqA03vsI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Q0ffxxGh, 0, m, &cVar_Q0ffxxGh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2ziHN9MQ, 0, m, &cVar_2ziHN9MQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tcuoHVQc, 0, m, &cVar_tcuoHVQc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xk72vv4L, 0, m, &cVar_xk72vv4L_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Pl9BVqQU, 0, m, &cVar_Pl9BVqQU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yQTGe0qr, 0, m, &cVar_yQTGe0qr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JAqz8kRJ, 0, m, &cVar_JAqz8kRJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JL4AfSmY, 0, m, &cVar_JL4AfSmY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iaZxQvAD, 0, m, &cVar_iaZxQvAD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GIBK4S1F, 0, m, &cVar_GIBK4S1F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ak3Yk9gO, 0, m, &cVar_Ak3Yk9gO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5aXuahu1, 0, m, &cVar_5aXuahu1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CE8LVBsg, 0, m, &cVar_CE8LVBsg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_joCiCLv9, 0, m, &cVar_joCiCLv9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6nIHGbXi, 0, m, &cVar_6nIHGbXi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PTPhYT7j, 0, m, &cVar_PTPhYT7j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yh524koF, 0, m, &cVar_yh524koF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m1N7CNDv, 0, m, &cVar_m1N7CNDv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Yv1S6gzQ, 0, m, &cVar_Yv1S6gzQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_n7KYF9IL, 0, m, &cVar_n7KYF9IL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ybdGSvBi, 0, m, &cVar_ybdGSvBi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wuZwyb6I, 0, m, &cVar_wuZwyb6I_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x6DxKn5R, 0, m, &cVar_x6DxKn5R_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zI0NMDlQ, 0, m, &cVar_zI0NMDlQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SBfnnluA, 0, m, &cVar_SBfnnluA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MY5hBtkR, 0, m, &cVar_MY5hBtkR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ccMTpCna, 0, m, &cVar_ccMTpCna_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WatKAlu4, 0, m, &cVar_WatKAlu4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Wj5vm2nC, 0, m, &cVar_Wj5vm2nC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_f9YSoTfk, 0, m, &cVar_f9YSoTfk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LJu62tvE, 0, m, &cVar_LJu62tvE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0P7w5x46, 0, m, &cVar_0P7w5x46_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K6JJShFY, 0, m, &cVar_K6JJShFY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VD7UypTz, 0, m, &cVar_VD7UypTz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XUf14VmT, 0, m, &cVar_XUf14VmT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WLNkwKVV, 0, m, &cVar_WLNkwKVV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1SmD67xd, 0, m, &cVar_1SmD67xd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_As6K0iEH, 0, m, &cVar_As6K0iEH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_URpaR4cz, 0, m, &cVar_URpaR4cz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_d2VfAk7u, 0, m, &cVar_d2VfAk7u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iV56wZN4, 0, m, &cVar_iV56wZN4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QG38e6Qb, 0, m, &cVar_QG38e6Qb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0fFTshLN, 0, m, &cVar_0fFTshLN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lHHNFtke, 0, m, &cVar_lHHNFtke_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tPNKtmQZ, 0, m, &cVar_tPNKtmQZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1kgrorQq, 0, m, &cVar_1kgrorQq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_y1GNFcy2, 0, m, &cVar_y1GNFcy2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9BzGnXrp, 0, m, &cVar_9BzGnXrp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_G992ZyYy, 0, m, &cVar_G992ZyYy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_prEbvl3L, 0, m, &cVar_prEbvl3L_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P1fYvbpk, 0, m, &cVar_P1fYvbpk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aDmRIGLh, 0, m, &cVar_aDmRIGLh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ffr61hlB, 0, m, &cVar_Ffr61hlB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VB6Polvp, 0, m, &cVar_VB6Polvp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lNkaGQ1k, 0, m, &cVar_lNkaGQ1k_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uH5fYp4o, 0, m, &cVar_uH5fYp4o_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0lKiyXb5, 0, m, &cVar_0lKiyXb5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XoMMzxdz, 0, m, &cVar_XoMMzxdz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CbHGeD8G_sendMessage);
  cMsg_DJAmcgjA_sendMessage(_c, 0, m);
  cMsg_Pyv6b9H1_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fibQb4Ci_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0f0ncwnB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_LJwJhpce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0v4LnZQk, 0, m, &cVar_0v4LnZQk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Q1wFhD0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0lTxK1Qg, 0, m, &cVar_0lTxK1Qg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_miBBBF7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6nu1nRvW, 0, m, &cVar_6nu1nRvW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Gyo4guRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LkwdWRNS, 0, m, &cVar_LkwdWRNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_BYwnWfME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nxzzrAi1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WKFb6lek_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_s6AEUeWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7weiVQ61_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tID2iJ9z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CXOZX4JE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kfaFe9xE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_XZdv6egh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cAw7GUl1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FNh3I6tA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GALiHuOi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_57MvdBca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_tpTVrZEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AIYHWR0Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JAJlqqng_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aV7gN6ns_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tkvmSR1U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eUuGSJP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vs40UCHC, HV_BINOP_MULTIPLY, 0, m, &cBinop_Vs40UCHC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_G6bOvfkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_12hsaxFc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MXvSBSs2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HKvVSvV9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Bnbc7TNL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GvSoWWm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NgcYkRYF_sendMessage);
  cMsg_JXqyQOCQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_hkzNvrWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L1rRr30S, HV_BINOP_MULTIPLY, 0, m, &cBinop_L1rRr30S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pUGILzS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_GNENqH0f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3tI8XwSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ArA8T6XR, HV_BINOP_MULTIPLY, 1, m, &cBinop_ArA8T6XR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NWPO0DuQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aBQAqoi1_sendMessage);
  cMsg_n2Zg4cx2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_8kKyuBTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6AHev5iw, HV_BINOP_MULTIPLY, 0, m, &cBinop_6AHev5iw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nQPued1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xU4egnS6_sendMessage(_c, 0, m);
  cMsg_hEno24NF_sendMessage(_c, 0, m);
  cMsg_K3w2xskc_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_TOTGI2o3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NaPTG91f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_liMjGLYC_sendMessage);
  cMsg_Hk941o6h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_qJJa2vsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2ziHN9MQ, 0, m, &cVar_2ziHN9MQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OJcrDhUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VS9IjQ7B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W81kNYDV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WvhvEmgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6hOUFyFj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ePpAPEEi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5aI34Nku_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IIbylrNm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Mypb7HuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XWvHweeg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B7HtuyLF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vDrRaeHU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jXvtqZVt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_po7AulnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xkeEelMi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0tHDID7K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lWXGtgRZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IphzJyZ8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KXFWF4p9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rs2uYjdu, HV_BINOP_MULTIPLY, 0, m, &cBinop_rs2uYjdu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jIyLfDSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qNYoFTzr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ywfstRiT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_I8tz3447_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_9nZxUnFZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qRxVtlNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ZtkmZOmE_sendMessage);
  cMsg_Iqw1nfJj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_cfx63P0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AX6KlDYp, HV_BINOP_MULTIPLY, 0, m, &cBinop_AX6KlDYp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qezK8EAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_LZcHG9B4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_mh5i2yIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cs5ufY6S, HV_BINOP_MULTIPLY, 1, m, &cBinop_cs5ufY6S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4sRYdz36_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6kFANchT_sendMessage);
  cMsg_7oyvTGYn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_UYVGr75b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gIuHThIv, HV_BINOP_MULTIPLY, 0, m, &cBinop_gIuHThIv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GdyqTIqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NmaGrRyM_sendMessage(_c, 0, m);
  cMsg_g4npYFxU_sendMessage(_c, 0, m);
  cMsg_XAYbn9eF_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5MkaYQWb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_P6zLP9TL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wjgui00o_sendMessage);
  cMsg_C0jI4Zkx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_bg2E6hot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hVJJcVIx, 0, m, &cVar_hVJJcVIx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hV2e27zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lkDRB3zx, 0, m, &cVar_lkDRB3zx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UhcmrRSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w7piIFlG, 0, m, &cVar_w7piIFlG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_BmqkODx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aTbauSnr, 0, m, &cVar_aTbauSnr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7pDg0QHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ShTOKDsQ, 0, m, &cVar_ShTOKDsQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MCH9rAV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Veih56ng, 0, m, &cVar_Veih56ng_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fUKGX24v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_oeZ7Ygi2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_s8UNzA4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CPDMDkBr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ip7RFQQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m8SLno88, 0, m, &cVar_m8SLno88_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_G4sCJGlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1OYbK3Za, 0, m, &cVar_1OYbK3Za_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PeZmQJGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_XYaA3gON_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Mv9ARQQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_A9ZCvkyy_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ToKr2Fvi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_izbhOh7B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_unKbfqMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uJpYuYMc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_83BvyeXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7H99QTeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d8B71qEV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_xZeAMAN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_shOFBqeA, 0, m, &cVar_shOFBqeA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_C4JTyn9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FtliNFI3, 0, m, &cVar_FtliNFI3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SDf24oUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_NZu7zZ0K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ASvittRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LtyWJRwf_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qTWDddGz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sEBqAppb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_753h6qnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Tr3VYK4v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k4J0YubE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ONeVoWBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sx2f2hJQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_ZSQ6ciXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6fxfeSV6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2mPmhFpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oyEJN1qq, 0, m, &cVar_oyEJN1qq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nZoVS2CI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qNuRGDTa, 0, m, &cVar_qNuRGDTa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_W4AKt57t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Gk5zNZyK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jcgkfum5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KeowFIH2_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZHZK8uBC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ysRaFhJj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uDauMoqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_M0msl7Mt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YdqFgGxX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_q3ir8csx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z76CQjhY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_BPLV0Rg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jLvvWjc6, 0, m, &cVar_jLvvWjc6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rsrY7WDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bObBkbAi, 0, m, &cVar_bObBkbAi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JfdUasy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Rn7TzMYz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KTfGHUYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_93fZbX0R_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K6pOVopX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NYoyrgPt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NTTGZ7vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ai6lmGyv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WbkHYedX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_tyQxxXZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GaOeKdY7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_AgFpWaVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TnA6SR3v, 0, m, &cVar_TnA6SR3v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pZYoNJns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dsBqXxEO, 0, m, &cVar_dsBqXxEO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AbeRlqnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PLK4lUSu, 0, m, &cVar_PLK4lUSu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_djYF8Qpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EJbP2V0E, 0, m, &cVar_EJbP2V0E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Ttp9x0xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MwNIuobt, 0, m, &cVar_MwNIuobt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OzfLAYZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_BHaN0FYv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hN3eBD7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Qf9taWjL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rTuhpfA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rmDwOSI4, 0, m, &cVar_rmDwOSI4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_LH6njzcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6om5vrlp, 0, m, &cVar_6om5vrlp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jh2iWba3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Fb6UVHhC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Xo7au8FH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0cts4bLp_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iMjKCS0I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bEnwF34A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5RYxy0hu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Fa0IXMaj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AAhHGehI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DvNevAnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e77uBlcZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_xqXC57aC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TEmWMDZf, 0, m, &cVar_TEmWMDZf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_tkt9ZDz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_964FGDhp, 0, m, &cVar_964FGDhp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HiCH4wKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_uHFmtMjK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AnjrXy6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_C3mCb27z_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gZ7a35L8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RqTln5f1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_D6pz0zRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xnKNfDe4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PPoekHEu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0Q5E17Tc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JFBbsUdR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_g5V82npg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DMMVT6q2, 0, m, &cVar_DMMVT6q2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uVTrAmst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YF7aIRrU, 0, m, &cVar_YF7aIRrU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_IddVvtSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CkXPNf43, 0, m, &cVar_CkXPNf43_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YsBTTITR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NdrEkIMR, 0, m, &cVar_NdrEkIMR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_FIuddjoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pyPAyyiK, 0, m, &cVar_pyPAyyiK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aimLbmKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ErM1QAHs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YICwSjSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kC0u7Ck0, 0, m, &cVar_kC0u7Ck0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2F6vh6Gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r3ortZYz, 0, m, &cVar_r3ortZYz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_W6E4QHQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XW1ltRcI, 0, m, &cVar_XW1ltRcI_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_nE7AjNBF, VOf(Bf0));
    __hv_line_f(&sLine_4UNF87Lg, VOf(Bf1));
    __hv_line_f(&sLine_pSiBzevn, VOf(Bf2));
    __hv_line_f(&sLine_6yswAXw4, VOf(Bf3));
    __hv_line_f(&sLine_kI36Lwhv, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_scOuQ7o3, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_mh28VfHe, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_6NjXB5JD, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_lGs2WsUy, VOf(Bf1));
    __hv_line_f(&sLine_OQTrxbYY, VOf(Bf0));
    __hv_line_f(&sLine_YQRLwJkl, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_EoWt5IRO, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_XPWVQZIl, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_lQnuE2xa, VOf(Bf5));
    __hv_line_f(&sLine_3cvV9DNX, VOf(Bf1));
    __hv_line_f(&sLine_Pj9ki11t, VOf(Bf2));
    __hv_line_f(&sLine_7FDlxWkq, VOf(Bf4));
    __hv_line_f(&sLine_rRjOaLSH, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_kfCumOV3, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_a8OO1WPc, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_FkAbMukd, VOf(Bf6));
    __hv_line_f(&sLine_ojzk8GYp, VOf(Bf2));
    __hv_line_f(&sLine_YlDfzkCJ, VOf(Bf1));
    __hv_line_f(&sLine_Sz4mQDbV, VOf(Bf5));
    __hv_line_f(&sLine_WYAkRqn3, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_4mV6cvbN, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_sXuBoD6c, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_7kYo4OEA, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_qvv0LIfe, VOf(Bf2));
    __hv_line_f(&sLine_pdBTayuu, VOf(Bf6));
    __hv_line_f(&sLine_j03RQ7Gd, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_zl0FEbSB, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_4WAnl3Hx, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_0VrYZ8xX, VOf(Bf8));
    __hv_line_f(&sLine_0UCuwmzK, VOf(Bf2));
    __hv_line_f(&sLine_o0diF5nh, VOf(Bf1));
    __hv_line_f(&sLine_cExuYMbZ, VOf(Bf7));
    __hv_line_f(&sLine_SEB7NTLU, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_MvMTKuxn, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_XHZgqOJ8, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_0sCGcYHg, VIf(Bf0));
    __hv_varwrite_f(&sVarf_HBdPgQ7P, VIf(Bf6));
    __hv_varwrite_f(&sVarf_wD1srm5P, VIf(Bf4));
    __hv_varwrite_f(&sVarf_ZClzWpid, VIf(Bf7));
    __hv_varread_f(&sVarf_uwy27Fe4, VOf(Bf7));
    __hv_varread_f(&sVarf_2K7bg1DA, VOf(Bf4));
    __hv_varread_f(&sVarf_EurM2HY5, VOf(Bf6));
    __hv_varread_f(&sVarf_TIQN5qto, VOf(Bf0));
    __hv_varread_f(&sVarf_jcBndMVu, VOf(Bf9));
    __hv_varread_f(&sVarf_wYLxCgfY, VOf(Bf1));
    __hv_line_f(&sLine_8zXmj8rJ, VOf(Bf2));
    __hv_line_f(&sLine_0gEf2msG, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_EurM2HY5, VIf(Bf7));
    __hv_varwrite_f(&sVarf_jcBndMVu, VIf(Bf4));
    __hv_varread_f(&sVarf_FQiKsjzf, VOf(Bf2));
    __hv_varread_f(&sVarf_s36A0CoR, VOf(Bf9));
    __hv_varread_f(&sVarf_jd7wSB2E, VOf(Bf1));
    __hv_varread_f(&sVarf_H30D3CpE, VOf(Bf6));
    __hv_varread_f(&sVarf_1AXl2uUE, VOf(Bf10));
    __hv_varread_f(&sVarf_sR6BjPDN, VOf(Bf11));
    __hv_varread_f(&sVarf_lSI7MdTb, VOf(Bf12));
    __hv_varwrite_f(&sVarf_8gTeE0e2, VIf(Bf7));
    __hv_varread_f(&sVarf_DkxqZB8w, VOf(Bf13));
    __hv_line_f(&sLine_K3G1bTwJ, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_Gxd3efmv, VOf(Bf15));
    __hv_line_f(&sLine_VbmMV1Iv, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_1Q9C7EFK, VOf(Bf14));
    __hv_line_f(&sLine_s8lLMveo, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_H30D3CpE, VIf(Bf17));
    __hv_varread_f(&sVarf_8gTeE0e2, VOf(Bf17));
    __hv_line_f(&sLine_hf7uJsuR, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_w4V333nZ, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_yVUS7KP2, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_1AXl2uUE, VIf(Bf16));
    __hv_line_f(&sLine_OcFYbir4, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_u1uZ7Cgr, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_FTM5Ho5H, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_sR6BjPDN, VIf(Bf16));
    __hv_line_f(&sLine_22f0CTUb, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_WIf99Y4b, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_nvbsDWTO, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_lSI7MdTb, VIf(Bf16));
    __hv_varwrite_f(&sVarf_DkxqZB8w, VIf(Bf2));
    __hv_varwrite_f(&sVarf_Gxd3efmv, VIf(Bf9));
    __hv_varwrite_f(&sVarf_1Q9C7EFK, VIf(Bf1));
    sEnv_process(this, &sEnv_fwGqfIVT, VIf(Bf6), &sEnv_fwGqfIVT_sendMessage);
    sEnv_process(this, &sEnv_5U3DdtSa, VIf(Bf7), &sEnv_5U3DdtSa_sendMessage);
    __hv_line_f(&sLine_b2EMDQkb, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_gMba23mZ, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_KW4ZiQVx, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_4UTRS53P, VOf(Bf6));
    __hv_line_f(&sLine_9tLdTX4g, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_FQiKsjzf, VIf(Bf9));
    __hv_varwrite_f(&sVarf_4UTRS53P, VIf(Bf10));
    __hv_varwrite_f(&sVarf_JUnKujUR, VIf(Bf11));
    __hv_varwrite_f(&sVarf_2SyL3deN, VIf(Bf12));
    __hv_varread_f(&sVarf_2SyL3deN, VOf(Bf12));
    __hv_line_f(&sLine_7N1NZmff, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_jd7wSB2E, VIf(Bf10));
    __hv_varread_f(&sVarf_JUnKujUR, VOf(Bf10));
    __hv_line_f(&sLine_h7V4ONbK, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_s36A0CoR, VIf(Bf10));
    __hv_varwrite_f(&sVarf_TIQN5qto, VIf(Bf7));
    __hv_varread_f(&sVarf_hFS9DBgK, VOf(Bf7));
    __hv_varread_f(&sVarf_js7jiul6, VOf(Bf10));
    __hv_varread_f(&sVarf_mvaw1tkC, VOf(Bf9));
    __hv_varread_f(&sVarf_nJwFUtvr, VOf(Bf11));
    __hv_varread_f(&sVarf_MHbehHQx, VOf(Bf6));
    __hv_varread_f(&sVarf_RB4oZln5, VOf(Bf12));
    __hv_varread_f(&sVarf_zgO57szG, VOf(Bf1));
    __hv_varwrite_f(&sVarf_1tiMbaWq, VIf(Bf4));
    __hv_varread_f(&sVarf_Wp1Z1EFL, VOf(Bf2));
    __hv_line_f(&sLine_TbwI4MRu, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_9HHnub7k, VOf(Bf17));
    __hv_line_f(&sLine_cEcqeAWd, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_sKCYWlvh, VOf(Bf16));
    __hv_line_f(&sLine_JfvwGcRz, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_nJwFUtvr, VIf(Bf15));
    __hv_varread_f(&sVarf_1tiMbaWq, VOf(Bf15));
    __hv_line_f(&sLine_FeQ0d7CC, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_WyNQ0yrz, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_tqg3A58Q, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_MHbehHQx, VIf(Bf13));
    __hv_line_f(&sLine_r7GBlQrH, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_Ss9tz3IV, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_wYhs9SzC, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_RB4oZln5, VIf(Bf13));
    __hv_line_f(&sLine_Nnu0GRXB, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_JymyE2bo, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_a8iMNjYU, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_zgO57szG, VIf(Bf13));
    __hv_varwrite_f(&sVarf_Wp1Z1EFL, VIf(Bf7));
    __hv_varwrite_f(&sVarf_9HHnub7k, VIf(Bf10));
    __hv_varwrite_f(&sVarf_sKCYWlvh, VIf(Bf9));
    sEnv_process(this, &sEnv_lHYVRI4m, VIf(Bf11), &sEnv_lHYVRI4m_sendMessage);
    sEnv_process(this, &sEnv_SAW8rJVa, VIf(Bf4), &sEnv_SAW8rJVa_sendMessage);
    __hv_line_f(&sLine_nQmEoeQV, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_WYYBFtrE, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_xudbDZz3, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_uQoNTnaJ, VOf(Bf11));
    __hv_line_f(&sLine_VBQxtuB7, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_hFS9DBgK, VIf(Bf10));
    __hv_varwrite_f(&sVarf_uQoNTnaJ, VIf(Bf6));
    __hv_varwrite_f(&sVarf_NnDpXMuU, VIf(Bf12));
    __hv_varwrite_f(&sVarf_gEZhPkav, VIf(Bf1));
    __hv_varread_f(&sVarf_gEZhPkav, VOf(Bf1));
    __hv_line_f(&sLine_ciVf8Gqy, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_mvaw1tkC, VIf(Bf6));
    __hv_varread_f(&sVarf_NnDpXMuU, VOf(Bf6));
    __hv_line_f(&sLine_UuUPUjID, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_js7jiul6, VIf(Bf6));
    __hv_varwrite_f(&sVarf_wYLxCgfY, VIf(Bf4));
    __hv_varwrite_f(&sVarf_wNL4VH2I, VIf(Bf0));
    __hv_varread_f(&sVarf_0sCGcYHg, VOf(Bf0));
    __hv_varread_f(&sVarf_HBdPgQ7P, VOf(Bf4));
    __hv_varread_f(&sVarf_LoRLgTd8, VOf(Bf6));
    __hv_varread_f(&sVarf_1yN8uM0h, VOf(Bf10));
    __hv_varread_f(&sVarf_AAojBTOx, VOf(Bf12));
    __hv_varread_f(&sVarf_82wNNzcg, VOf(Bf11));
    __hv_line_f(&sLine_bkdFRWLX, VOf(Bf1));
    __hv_line_f(&sLine_EYFFW5nI, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_LoRLgTd8, VIf(Bf0));
    __hv_varwrite_f(&sVarf_AAojBTOx, VIf(Bf4));
    __hv_varread_f(&sVarf_HTnyujC2, VOf(Bf1));
    __hv_varread_f(&sVarf_knDo5zE4, VOf(Bf12));
    __hv_varread_f(&sVarf_sGKgCfY9, VOf(Bf11));
    __hv_varread_f(&sVarf_ek2nhrhC, VOf(Bf6));
    __hv_varread_f(&sVarf_ohwNmO95, VOf(Bf7));
    __hv_varread_f(&sVarf_ZWdW6P3z, VOf(Bf13));
    __hv_varread_f(&sVarf_G4lUm0Ka, VOf(Bf15));
    __hv_varwrite_f(&sVarf_31ZxpuRu, VIf(Bf0));
    __hv_varread_f(&sVarf_KOVZ7bNP, VOf(Bf2));
    __hv_line_f(&sLine_3qCUGByJ, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_F1FSlOOp, VOf(Bf18));
    __hv_line_f(&sLine_wbsevmSD, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_oxdnJmEH, VOf(Bf17));
    __hv_line_f(&sLine_dBuEizqD, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_ek2nhrhC, VIf(Bf14));
    __hv_varread_f(&sVarf_31ZxpuRu, VOf(Bf14));
    __hv_line_f(&sLine_IsLPGIHF, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_5roj2S4H, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_PDYyPNjp, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_ohwNmO95, VIf(Bf16));
    __hv_line_f(&sLine_lWMMjkRr, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_8Generv3, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_jIN8rqyT, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_ZWdW6P3z, VIf(Bf16));
    __hv_line_f(&sLine_ibcsJeSC, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_4AfD4soT, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_GtenbnZ0, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_G4lUm0Ka, VIf(Bf16));
    __hv_varwrite_f(&sVarf_KOVZ7bNP, VIf(Bf1));
    __hv_varwrite_f(&sVarf_F1FSlOOp, VIf(Bf12));
    __hv_varwrite_f(&sVarf_oxdnJmEH, VIf(Bf11));
    sEnv_process(this, &sEnv_hfb8Vmlq, VIf(Bf6), &sEnv_hfb8Vmlq_sendMessage);
    sEnv_process(this, &sEnv_ePQ3NrNN, VIf(Bf0), &sEnv_ePQ3NrNN_sendMessage);
    __hv_line_f(&sLine_PXf2kXQi, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_YcKNbGC1, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_uPBtGs0y, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_cOoGl5UQ, VOf(Bf6));
    __hv_line_f(&sLine_J5jhes6r, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_HTnyujC2, VIf(Bf12));
    __hv_varwrite_f(&sVarf_cOoGl5UQ, VIf(Bf7));
    __hv_varwrite_f(&sVarf_vohM47Kn, VIf(Bf13));
    __hv_varwrite_f(&sVarf_az21Gie7, VIf(Bf15));
    __hv_varread_f(&sVarf_az21Gie7, VOf(Bf15));
    __hv_line_f(&sLine_n4IeAp4t, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_sGKgCfY9, VIf(Bf7));
    __hv_varread_f(&sVarf_vohM47Kn, VOf(Bf7));
    __hv_line_f(&sLine_Vd7R4LVj, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_knDo5zE4, VIf(Bf7));
    __hv_varwrite_f(&sVarf_1yN8uM0h, VIf(Bf0));
    __hv_varread_f(&sVarf_IWRSW32p, VOf(Bf0));
    __hv_varread_f(&sVarf_8YULn7tN, VOf(Bf7));
    __hv_varread_f(&sVarf_vmZZJ1Aj, VOf(Bf12));
    __hv_varread_f(&sVarf_Ns8VLpEf, VOf(Bf13));
    __hv_varread_f(&sVarf_3eUMrVRV, VOf(Bf6));
    __hv_varread_f(&sVarf_RYVZ87bm, VOf(Bf15));
    __hv_varread_f(&sVarf_5r2rRHTR, VOf(Bf11));
    __hv_varwrite_f(&sVarf_QMwirl53, VIf(Bf4));
    __hv_varread_f(&sVarf_SoApFxOH, VOf(Bf1));
    __hv_line_f(&sLine_3DCXxmJd, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_TBCrBYhl, VOf(Bf14));
    __hv_line_f(&sLine_Wtx2Sxvu, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_xmGbblEH, VOf(Bf16));
    __hv_line_f(&sLine_xSAGery4, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_Ns8VLpEf, VIf(Bf18));
    __hv_varread_f(&sVarf_QMwirl53, VOf(Bf18));
    __hv_line_f(&sLine_JkOsyvuP, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_opzxbEXA, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_4U8Kwxfx, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_3eUMrVRV, VIf(Bf2));
    __hv_line_f(&sLine_Bg5yvH5n, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_1Nge6qYn, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_xlOegA6O, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_RYVZ87bm, VIf(Bf2));
    __hv_line_f(&sLine_RRiamckx, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_vE4LH36i, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_zH77K0S2, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_5r2rRHTR, VIf(Bf2));
    __hv_varwrite_f(&sVarf_SoApFxOH, VIf(Bf0));
    __hv_varwrite_f(&sVarf_TBCrBYhl, VIf(Bf7));
    __hv_varwrite_f(&sVarf_xmGbblEH, VIf(Bf12));
    sEnv_process(this, &sEnv_gGYQkzT7, VIf(Bf13), &sEnv_gGYQkzT7_sendMessage);
    sEnv_process(this, &sEnv_OgLlV1RM, VIf(Bf4), &sEnv_OgLlV1RM_sendMessage);
    __hv_line_f(&sLine_PrOpt7jL, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_35NR8fJK, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_gzmqTdB9, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Xi7qWikw, VOf(Bf13));
    __hv_line_f(&sLine_ElEDNtg6, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_IWRSW32p, VIf(Bf7));
    __hv_varwrite_f(&sVarf_Xi7qWikw, VIf(Bf6));
    __hv_varwrite_f(&sVarf_nXND73cu, VIf(Bf15));
    __hv_varwrite_f(&sVarf_IEguGXWq, VIf(Bf11));
    __hv_varread_f(&sVarf_IEguGXWq, VOf(Bf11));
    __hv_line_f(&sLine_NtFbh7Rt, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_vmZZJ1Aj, VIf(Bf6));
    __hv_varread_f(&sVarf_nXND73cu, VOf(Bf6));
    __hv_line_f(&sLine_VjirR0Sb, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_8YULn7tN, VIf(Bf6));
    __hv_varwrite_f(&sVarf_82wNNzcg, VIf(Bf4));
    __hv_varwrite_f(&sVarf_vmicOfaC, VIf(Bf10));
    __hv_varread_f(&sVarf_wD1srm5P, VOf(Bf10));
    __hv_varread_f(&sVarf_ZClzWpid, VOf(Bf4));
    __hv_varread_f(&sVarf_vowBkgeo, VOf(Bf6));
    __hv_varread_f(&sVarf_WgcZepG2, VOf(Bf7));
    __hv_varread_f(&sVarf_sBbD1Bzf, VOf(Bf15));
    __hv_varread_f(&sVarf_rz3kvszM, VOf(Bf13));
    __hv_line_f(&sLine_VFIrwsKV, VOf(Bf11));
    __hv_line_f(&sLine_6Cgv9mK1, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_vowBkgeo, VIf(Bf10));
    __hv_varwrite_f(&sVarf_sBbD1Bzf, VIf(Bf4));
    __hv_varread_f(&sVarf_2wq2lcTl, VOf(Bf11));
    __hv_varread_f(&sVarf_WqCl0lIu, VOf(Bf15));
    __hv_varread_f(&sVarf_rDOSX2dN, VOf(Bf13));
    __hv_varread_f(&sVarf_MeqqWyN6, VOf(Bf6));
    __hv_varread_f(&sVarf_XiStgroB, VOf(Bf0));
    __hv_varread_f(&sVarf_jGccrMWG, VOf(Bf2));
    __hv_varread_f(&sVarf_YXtrraGw, VOf(Bf18));
    __hv_varwrite_f(&sVarf_iH1l6iI5, VIf(Bf10));
    __hv_varread_f(&sVarf_rp4bco1B, VOf(Bf1));
    __hv_line_f(&sLine_8QnHWCU7, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_gDgdUDu8, VOf(Bf19));
    __hv_line_f(&sLine_Sn4psQGu, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_WoEPFZYw, VOf(Bf14));
    __hv_line_f(&sLine_OOKxWJe5, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_MeqqWyN6, VIf(Bf17));
    __hv_varread_f(&sVarf_iH1l6iI5, VOf(Bf17));
    __hv_line_f(&sLine_HK37Y5WI, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_Ww64HgsW, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_yt2CSue8, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_XiStgroB, VIf(Bf16));
    __hv_line_f(&sLine_61lfxhjd, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_mi0KELrd, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_CyP9rrdN, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_jGccrMWG, VIf(Bf16));
    __hv_line_f(&sLine_q8hPoXvy, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_fZZFBNFt, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_60bvo7Bk, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_YXtrraGw, VIf(Bf16));
    __hv_varwrite_f(&sVarf_rp4bco1B, VIf(Bf11));
    __hv_varwrite_f(&sVarf_gDgdUDu8, VIf(Bf15));
    __hv_varwrite_f(&sVarf_WoEPFZYw, VIf(Bf13));
    sEnv_process(this, &sEnv_PAicXAbZ, VIf(Bf6), &sEnv_PAicXAbZ_sendMessage);
    sEnv_process(this, &sEnv_ZiSQeIXD, VIf(Bf10), &sEnv_ZiSQeIXD_sendMessage);
    __hv_line_f(&sLine_jbqGS0i1, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_Tbb4MeVw, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_m5UPqswg, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_15lCwsLK, VOf(Bf6));
    __hv_line_f(&sLine_EvBwhjCX, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_2wq2lcTl, VIf(Bf15));
    __hv_varwrite_f(&sVarf_15lCwsLK, VIf(Bf0));
    __hv_varwrite_f(&sVarf_4wpipFqQ, VIf(Bf2));
    __hv_varwrite_f(&sVarf_PEYIFgAF, VIf(Bf18));
    __hv_varread_f(&sVarf_PEYIFgAF, VOf(Bf18));
    __hv_line_f(&sLine_YSXuJS1z, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_rDOSX2dN, VIf(Bf0));
    __hv_varread_f(&sVarf_4wpipFqQ, VOf(Bf0));
    __hv_line_f(&sLine_fgttbEnW, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_WqCl0lIu, VIf(Bf0));
    __hv_varwrite_f(&sVarf_WgcZepG2, VIf(Bf10));
    __hv_varread_f(&sVarf_F1ZUW2jn, VOf(Bf10));
    __hv_varread_f(&sVarf_4yn6nuf5, VOf(Bf0));
    __hv_varread_f(&sVarf_fiSmhAu7, VOf(Bf15));
    __hv_varread_f(&sVarf_HQHOy7tg, VOf(Bf2));
    __hv_varread_f(&sVarf_PxIR2b5Z, VOf(Bf6));
    __hv_varread_f(&sVarf_kEO67BgH, VOf(Bf18));
    __hv_varread_f(&sVarf_Suli7oE6, VOf(Bf13));
    __hv_varwrite_f(&sVarf_MTLWkihA, VIf(Bf4));
    __hv_varread_f(&sVarf_GyFxNo2C, VOf(Bf11));
    __hv_line_f(&sLine_pJZ5lNYz, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_PnIh6N2j, VOf(Bf17));
    __hv_line_f(&sLine_4klrPboV, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_5BB5mEQ0, VOf(Bf16));
    __hv_line_f(&sLine_jt7xLKzT, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_HQHOy7tg, VIf(Bf19));
    __hv_varread_f(&sVarf_MTLWkihA, VOf(Bf19));
    __hv_line_f(&sLine_m61W8DWa, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_rob0dCDQ, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_0tOnRval, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_PxIR2b5Z, VIf(Bf1));
    __hv_line_f(&sLine_ro7tp7N3, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_IPkJlkUN, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_7zCp5iZm, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_kEO67BgH, VIf(Bf1));
    __hv_line_f(&sLine_MsBGlAfn, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_UHwz50Br, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_wTvVF7r4, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_Suli7oE6, VIf(Bf1));
    __hv_varwrite_f(&sVarf_GyFxNo2C, VIf(Bf10));
    __hv_varwrite_f(&sVarf_PnIh6N2j, VIf(Bf0));
    __hv_varwrite_f(&sVarf_5BB5mEQ0, VIf(Bf15));
    sEnv_process(this, &sEnv_KdHqRHC6, VIf(Bf2), &sEnv_KdHqRHC6_sendMessage);
    sEnv_process(this, &sEnv_I2XQ3xr7, VIf(Bf4), &sEnv_I2XQ3xr7_sendMessage);
    __hv_line_f(&sLine_qwbhzP3H, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_cIK03Gcc, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_gnqBl1vj, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_0F2j2sB2, VOf(Bf2));
    __hv_line_f(&sLine_whUHAsJc, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_F1ZUW2jn, VIf(Bf0));
    __hv_varwrite_f(&sVarf_0F2j2sB2, VIf(Bf6));
    __hv_varwrite_f(&sVarf_yj5bdqqy, VIf(Bf18));
    __hv_varwrite_f(&sVarf_om5JlOx7, VIf(Bf13));
    __hv_varread_f(&sVarf_om5JlOx7, VOf(Bf13));
    __hv_line_f(&sLine_QE5Y4KNf, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_fiSmhAu7, VIf(Bf6));
    __hv_varread_f(&sVarf_yj5bdqqy, VOf(Bf6));
    __hv_line_f(&sLine_O9n9XZy6, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_4yn6nuf5, VIf(Bf6));
    __hv_varwrite_f(&sVarf_rz3kvszM, VIf(Bf4));
    __hv_varwrite_f(&sVarf_unhT3bxQ, VIf(Bf7));
    __hv_varwrite_f(&sVarf_pbj8ZtwH, VIf(Bf8));
    __hv_varwrite_f(&sVarf_udpZHkm9, VIf(Bf9));
    __hv_varwrite_f(&sVarf_WSycRcH3, VIf(Bf12));
    __hv_varwrite_f(&sVarf_uwy27Fe4, VIf(Bf3));
    __hv_varwrite_f(&sVarf_2K7bg1DA, VIf(Bf5));
    __hv_varread_f(&sVarf_pbj8ZtwH, VOf(Bf5));
    __hv_varread_f(&sVarf_udpZHkm9, VOf(Bf3));
    __hv_varread_f(&sVarf_WSycRcH3, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_wNL4VH2I, VOf(Bf12));
    __hv_varread_f(&sVarf_vmicOfaC, VOf(Bf5));
    __hv_varread_f(&sVarf_unhT3bxQ, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
